@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -87,7 +87,7 @@ namespace iAnimatorScript_Private
 	DEFINE_WORKER_ABS(Animator,SetStyle,int);
 	DEFINE_WORKER_ABS(Animator,SetNumberOfTitlePageFrames,int);
 	DEFINE_WORKER_ABS(Animator,SetNumberOfTitlePageBlendedFrames,int);
-	DEFINE_WORKER_ABS(Animator,SetLogoPosition,int);
+	DEFINE_WORKER_ABS(Animator,SetLogoLocation,int);
 	DEFINE_WORKER_ABS(Camera,SetParallelScale,double);
 	DEFINE_WORKER_ABS(Camera,SetParallelProjection,bool);
 	DEFINE_WORKER_ABS(Visual,ShowLabel,bool); 
@@ -247,6 +247,7 @@ iAnimatorScript::iAnimatorScript(iAnimator *an) : iBasicScript(an->GetViewModule
 	this->CreateAliasWord("upper-right-corner","urcorner");
 	this->CreateAliasWord("lower-left-corner","llcorner");
 	this->CreateAliasWord("lower-right-corner","lrcorner");
+	this->CreateAliasWord("logo-position","logo-location");
 #endif
 
 	//
@@ -281,9 +282,7 @@ iAnimatorScript::iAnimatorScript(iAnimator *an) : iBasicScript(an->GetViewModule
 	this->AddPrototype< iScriptKit::FunctionCallAssignmentStatement<int> >("render-all",RenderAll);
 	this->AddPrototype< iScriptKit::FunctionCallAssignmentStatement<int> >("render-set",RenderSet);
 	this->AddPrototype< iScriptKit::FunctionCallAssignmentStatement<int> >("load",Load);
-
-	this->AddPrototype< iScriptKit::SimpleStatement >("reset",Reset);
-		
+	
 	this->AddPrototype< iScriptKit::FunctionCallStatement >("execute control-script",ExecuteControlScript);
 	this->AddPrototype< iScriptKit::FunctionCallStatement >("embed control-script",EmbedControlScript);
 
@@ -318,7 +317,7 @@ iAnimatorScript::iAnimatorScript(iAnimator *an) : iBasicScript(an->GetViewModule
 	this->AddPrototype< iScriptKit::FunctionCallAssignmentStatement<int> >("title-page-number-of-frames",AnimatorSetNumberOfTitlePageFrames);
 	this->AddPrototype< iScriptKit::FunctionCallAssignmentStatement<int> >("title-page-number-of-blended-frames",AnimatorSetNumberOfTitlePageBlendedFrames);
 	this->AddPrototype< iScriptKit::FunctionCallAssignmentStatement<float> >("logo-opacity",AnimatorSetLogoOpacity);
-	this->AddPrototype< iScriptKit::FunctionCallAssignmentStatement<int> >("logo-position",AnimatorSetLogoPosition);
+	this->AddPrototype< iScriptKit::FunctionCallAssignmentStatement<int> >("logo-location",AnimatorSetLogoLocation);
 
 	this->AddPrototype< iScriptKit::FunctionCallAssignmentStatement<bool> >("surface",SurfaceShow);
 	this->AddPrototype< iScriptKit::FunctionCallAssignmentStatement<bool> >("cross-section",CrossSectionShow);
@@ -376,18 +375,6 @@ bool iAnimatorScript::IsCommandWordLetter(char c) const
 }
 
 
-//
-//  Reset Animator settings
-//
-bool iAnimatorScript::Reset(iScript *self)
-{
-	curAnimator->ResetState();
-	curAnimator->Reset();
-	curVisual->GetRenderTool()->GetCamera()->Reset();
-	return true;
-}
-
-
 //
 //  Render scene
 //
@@ -401,7 +388,7 @@ bool iAnimatorScript::Render(iScript *self, short, int n)
 	self->GetErrorStatus()->Monitor(curAnimator->GetErrorStatus(),true);
 	for(i=0; i<n && !self->CheckAbort(i,n,1) && self->GetErrorStatus()->NoError(); i++) 
 	{
-		if(!curAnimator->RenderImages()) self->GetErrorStatus()->Set("Animation finished.",-1);
+		if(!curAnimator->Frame()) self->GetErrorStatus()->Set("Animation finished.",-1);
 	}
 
 	curScript->SetInRender(false);
@@ -424,12 +411,12 @@ bool iAnimatorScript::RenderAll(iScript *self, short, int n)
 			//
 			//  Force other animators to continue, even if they are done
 			//
-			curControl->GetViewModule(k)->GetAnimator()->RenderImages(false);
+			curControl->GetViewModule(k)->GetAnimator()->Frame(false);
 		}
 		if(self->GetErrorStatus()->NoError())
 		{
 			self->GetErrorStatus()->Monitor(curAnimator->GetErrorStatus(),true);
-			if(!curAnimator->RenderImages()) self->GetErrorStatus()->Set("Animation finished.",-1);
+			if(!curAnimator->Frame()) self->GetErrorStatus()->Set("Animation finished.",-1);
 		}
 	}
 
@@ -455,12 +442,12 @@ bool iAnimatorScript::RenderSet(iScript *self, short, int num, const int *v, int
 	for(i=0; self->GetErrorStatus()->NoError() && !self->CheckAbort(i,num,1) && i<num; i++) if(v[i]>0 && v[i]<=curControl->GetNumberOfViewModules() && v[i]!=1+curControl->GetCurrentViewModuleIndex())
 	{
 		self->GetErrorStatus()->Monitor(curControl->GetViewModule(v[i]-1)->GetAnimator()->GetErrorStatus(),true);
-		curControl->GetViewModule(v[i]-1)->GetAnimator()->RenderImages(false);
+		curControl->GetViewModule(v[i]-1)->GetAnimator()->Frame(false);
 	}
 	for(i=0; self->GetErrorStatus()->NoError() && !self->CheckAbort(i,num,1) && i<num; i++) if(v[i] == 1+curControl->GetCurrentViewModuleIndex())
 	{
 		self->GetErrorStatus()->Monitor(curAnimator->GetErrorStatus(),true);
-		if(!curAnimator->RenderImages()) self->GetErrorStatus()->Set("Animation finished.",-1);
+		if(!curAnimator->Frame()) self->GetErrorStatus()->Set("Animation finished.",-1);
 		break;
 	}
 
