@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -55,7 +55,7 @@ public:
 	typedef iCalculatorKit::ptr<T,0> real_ptr;
 	typedef iCalculatorKit::ptr<T,1> bool_ptr;
 
-	iCalculator(const iCalculatorBase *driver = 0);
+	iCalculator();
 
 	inline const result_t* GetResult() { return static_cast<result_t*>(this->Result()); }
 
