@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -43,14 +43,12 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iCalculatorKit;
 
 
-iCalculatorBase::iCalculatorBase(const iCalculatorBase *driver) : mVariables(driver==0 ? mVariableData : driver->mVariables)
+iCalculatorBase::iCalculatorBase()
 {
 	mParser = 0;
 	mErrorPosition = -1;
 
-	mTrapFPE = (driver == 0) ? false : driver->GetTrapFPE();
-
-	mAllowUndeterministicCalls = false;
+	mTrapFPE = false;
 
 	mResult = 0;
 	mStatus = 0;
@@ -95,19 +93,6 @@ void iCalculatorBase::SetResultVariable(iCalculatorKit::Variable &var)
 }
 
 
-void iCalculatorBase::CopyVariables(const iCalculatorBase *other)
-{
-	if(other != 0)
-	{
-		int i;
-		for(i=0; i<other->mVariables.Size(); i++)
-		{
-			mVariableData.Add(other->mVariables[i]);  //  this insures the correct name scope resolution
-		}
-	}
-}
-
-
 void iCalculatorBase::SetTrapFPE(bool s)
 {
 	if(mTrapFPE != s)
@@ -122,7 +107,7 @@ void iCalculatorBase::AddVariable(const iCalculatorKit::Variable *var)
 {
 	if(var!=0 && !var->Name().IsEmpty())
 	{
-		mVariableData.Add(var);
+		mVariables.Add(var);
 	}
 }
 
@@ -132,11 +117,11 @@ void iCalculatorBase::RemoveVariable(const iString &name)
 	if(!name.IsEmpty())
 	{
 		int i;
-		for(i=mVariableData.MaxIndex(); i>=0; i--)  // variables are always looped over in the reverse order to insure proper name resolution
+		for(i=mVariables.MaxIndex(); i>=0; i--)  // variables are always looped over in the reverse order to insure proper name resolution
 		{
-			if(mVariableData[i]->Name() == name)
+			if(mVariables[i]->Name() == name)
 			{
-				mVariableData.Remove(i);
+				mVariables.Remove(i);
 				return;  //  remove one at a time
 			}
 		}
@@ -456,6 +441,31 @@ bool iCalculatorBase::CompileToken(int &index)
 }
 
 
+//
+//  This is for extending (used in scripts)
+//
+const Variable* iCalculatorBase::FindExternalVariable(const iString &) const
+{
+	return 0;
+}
+
+
+const Variable* iCalculatorBase::FindVariable(const iString &name) const
+{
+	int i;
+
+	for(i=mVariables.MaxIndex(); i>=0; i--)  // variables are always looped over in the reverse order to insure proper name resolution
+	{
+		if(mVariables[i]->Name() == name) return mVariables[i];
+	}
+
+	//
+	//  If we don't own this variable, check external variables (used if we are used inside a script)
+	//
+	return this->FindExternalVariable(name);
+}
+
+
 bool iCalculatorBase::Link()
 {
 	if(mStatus < 1)
@@ -473,11 +483,7 @@ bool iCalculatorBase::Link()
 	const Variable *var;
 	for(id=0; id<mDataStack.Size(); id++) if(mDataStack[id]->Self() == 0)
 	{
-		var = 0;
-		for(i=mVariables.MaxIndex(); var==0 && i>=0; i--)  // variables are always looped over in the reverse order to insure proper name resolution
-		{
-			if(mVariables[i]->Name() == mDataStack[id]->Name()) var = mVariables[i];
-		}
+		var = this->FindVariable(mDataStack[id]->Name());
 		if(var == 0)
 		{
 			this->SetError("Link error: variable {"+mDataStack[id]->Name()+"} has not been defined.",-1);
@@ -575,8 +581,6 @@ bool iCalculatorBase::Execute()
 		return false;
 	}
 
-	if(mStatus==3 && !mAllowUndeterministicCalls && mVariables.Size()==0) return true;  //  the expression has not been changed, we dot not permit non-deterministic calls (like rand()), and we have no variables, so the result can not change
-
 	//
 	//  Create the run-time stack.
 	//
