@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -48,7 +48,7 @@ class iCalculatorBase
 
 public:
 	
-	iCalculatorBase(const iCalculatorBase *driver = 0);
+	iCalculatorBase();
 	virtual ~iCalculatorBase();
 
 	//
@@ -76,11 +76,6 @@ public:
 	//
 	inline const iString& ListUsedVariables() const { return mUsedVars; }
 
-	//
-	//  Useful for script work; has no effect if the driver argument was specified in the constructor
-	//
-	void CopyVariables(const iCalculatorBase *other);
-
 	//
 	//  Floating-point exceptions
 	//
@@ -140,12 +135,12 @@ protected:
 	virtual iCalculatorKit::Variable* CreateLiteral(const iString &str) const = 0;
 	virtual iCalculatorKit::Function* CreateFunction(const iString &str, int loc) const = 0;
 
+	virtual const iCalculatorKit::Variable* FindExternalVariable(const iString &name) const;
+
 #ifdef I_DEBUG
 	virtual void PrintStack(int iptr, int narg, int jmax, iCalculatorKit::Variable** stack) = 0;
 #endif
 
-	bool mAllowUndeterministicCalls;
-
 private:
 
 	void ReportRunTimeError(int ierr, const iCalculatorKit::Function *caller);
@@ -153,6 +148,8 @@ private:
 	bool CompileToken(int &index);
 	bool CheckFunction(int index, int &stackptr);
 
+	const iCalculatorKit::Variable* FindVariable(const iString &name) const;
+
 	int mErrorPosition;
 	iString mErrorMessage;
 
@@ -167,10 +164,8 @@ private:
 
 	iBuffer<iCalculatorKit::Variable*> mBuffer, mSavedBuffer; // pre-allocated buffers to avoid memory allocation during execution
 
-	iArray<const iCalculatorKit::Variable*> mVariableData;
-
+	iArray<const iCalculatorKit::Variable*> mVariables;
 	iArray<iCalculatorKit::Variable*> mLiterals;
-	const iArray<const iCalculatorKit::Variable*> &mVariables;
 };
 
 #endif  // ICALCULATORBASE_H
