@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -986,7 +986,7 @@ namespace iCalculatorKit
 //  **********************************************************************
 //
 template<class T>
-iCalculator<T>::iCalculator(const iCalculatorBase *driver) : iCalculatorBase(driver)
+iCalculator<T>::iCalculator() : iCalculatorBase()
 {
 }
 
