@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -609,7 +609,7 @@ void iControlModule::ExecuteForViewModule(iViewModule *module, const iString &co
 	{
 		this->GetErrorStatus()->Monitor(object->GetErrorStatus());
 		object->UnPackState(command);
-		mExecuteOk = object->UnPackedSomething();
+		mExecuteOk = object->UnPackedSomething() && this->GetErrorStatus()->NoError();
 		if(renOption == RenderOption::Auto) renOption = RenderOption::One;
 
 		if(ptype->IsMatch(iDataReader::Type()) || ptype->IsMatch(iDataSubject::Type()))
