@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -145,7 +145,7 @@ namespace iControlScript_Private
 		const iObjectType *tmp = iObjectTypeRegistry::FindType(arg);
 		if(tmp != 0)
 		{
-			curControl->Show(*tmp,true,curRender);
+			curControl->Show(*tmp,true,true);
 			return true;
 		}
 		else
@@ -390,7 +390,7 @@ iControlScript::~iControlScript()
 }
 
 
-iScriptKit::Calculator* iControlScript::CreateCalculator()
+iScriptKit::Calculator* iControlScript::CreateCalculatorBody()
 {
 	return new Calculator(this);
 }
@@ -691,7 +691,8 @@ bool iControlScript::Print(iScript *self, const iString &arg)
 		//
 		if(w.EndsWith(iObjectKey::PrefixSeparator()))
 		{
-			const iObjectType *type = iObjectTypeRegistry::FindType(w.Part(0,w.Length()-iObjectKey::PrefixSeparator().Length()));
+			w = w.Part(0,w.Length()-iObjectKey::PrefixSeparator().Length());
+			const iObjectType *type = iObjectTypeRegistry::FindType(w);
 			if(type != 0)
 			{
 				int i, lmax = 0;
@@ -824,7 +825,6 @@ bool iControlScript::Animate(iScript *self, const iString &arg)
 		f.Close();
 
 		curVisual->GetAnimator()->GetScript()->SetText(st);
-		curVisual->GetAnimator()->SetUseScript(true);
 	}
 
 	if(arg == all)
@@ -872,7 +872,6 @@ bool iControlScript::EmbedAnimatorScript(iScript *self, const iString &arg)
 
 	self->GetErrorStatus()->Monitor(curVisual->GetAnimator()->GetErrorStatus());
 	curVisual->GetAnimator()->GetScript()->SetText(v);
-	curVisual->GetAnimator()->SetUseScript(true);
 	curScript->mAllowChildAccess = true;
 	curVisual->GetAnimator()->Animate();
 	curScript->mAllowChildAccess = false;
@@ -1126,7 +1125,7 @@ const iString& iControlScript::GetHelpString(_HelpId id) const
 			//
 			"Format:<br><blockquote>"
 			"    <code><b>print</b> &lt;<i>query</i>&gt;</code><br></blockquote>"
-			"This command prints the value of <code>&lt;<i>query</i>&gt;</code>, which can be a script expression or a property in the form <code>&lt;<i>object-name</i>&gt;<b>:</b>&lt;<i>property-name</i>&gt;</code>. Use <code><b>list objects</b></code> to get the list of all available objects and <code><b>list properties</b> &lt;<i>object-name</i>&gt;</code> to get the list of all available properties for a given object <code>&lt;<i>object-name</i>&gt;</code>.<br>",
+			"This command prints the value of <code>&lt;<i>query</i>&gt;</code>, which can be a script expression, a property in the form <code>&lt;<i>object-name</i>&gt;<b>:</b>&lt;<i>property-name</i>&gt;</code>, or the whole object <code>&lt;<i>object-name</i>&gt;<b>:</b></code> (the semi-colon at the end is required, to separate an object from a regular variable). Use <code><b>list objects</b></code> to get the list of all available objects and <code><b>list properties</b> &lt;<i>object-name</i>&gt;</code> to get the list of all available properties for a given object <code>&lt;<i>object-name</i>&gt;</code>.<br>",
 			//
 			"Format:<br><blockquote>"
 			"    <code><b>create</b> &lt;<i>object-name</i>&gt;</code><br>"
