@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -75,7 +75,7 @@ protected:
 	//
 	//  Factory method: replace the calculator with the one that understands key values
 	//
-	virtual iScriptKit::Calculator* CreateCalculator();
+	virtual iScriptKit::Calculator* CreateCalculatorBody();
 
 	//
 	//  Convert keys into calculator variables
