@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -55,7 +55,7 @@ public:
 
 	static const iDataType& Null();
 
-	iDataType(int id, const iString& tname, const iString& sname, const iString &keywords, const iString &environment = "");
+	iDataType(int id, const iString& tname, const iString& sname, int rank, const iString &keywords, const iString &environment = "");
 	~iDataType();
 
 	bool operator==(const iDataType &type) const;
@@ -68,6 +68,8 @@ public:
 	inline const iString& GetTextName() const { return mTextName; }
 	inline const iString& GetShortName() const { return mShortName; }
 
+	inline int GetRank() const { return mRank; }
+
 	iString GetEnvironment(iShell *shell) const;
 
 	inline bool IsOfType(const iString &name) const { return name==mName || name==mShortName; }
@@ -79,7 +81,7 @@ public:
 
 private:
 
-	const int mId;
+	const int mId, mRank;
 	const iString mTextName, mShortName, mKeywords;
 	iString mName, mEnv;
 
