@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -30,7 +30,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "idata.h"
-#include "idatahelper.h"
 #include "idatalimits.h"
 #include "idatareader.h"
 #include "idatasubject.h"
@@ -106,7 +105,7 @@ void iDataExplorer::UpdateDataType(int prev)
 }
 
 
-const iDataExplorer::Info& iDataExplorer::GetInfo(bool rangeonly, int rank)
+const iDataExplorer::Info& iDataExplorer::GetInfo(bool rangeonly, float start, float length)
 {
 	if(mHistogramMaker == 0)
 	{
@@ -117,10 +116,10 @@ const iDataExplorer::Info& iDataExplorer::GetInfo(bool rangeonly, int rank)
 
 	if(this->IsThereData())
 	{
-		iDataHelper h(this->GetData());
-		mHistogramMaker->SetDataRank((rank == -1) ? h.GetDataRank() : rank);
+		mHistogramMaker->SetDataRank(this->GetDataType().GetRank());
 		mHistogramMaker->SetInput(this->GetData(),mComponent);
 		mHistogramMaker->SetStretch(mStretch);
+		mHistogramMaker->SetProgressRange(start,length);
 		mHistogramMaker->GetInput()->Update();
 		if(mHistogramMaker->GetInput()->GetMTime() > mMTime)
 		{
