@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -66,7 +66,7 @@ public:
 	//
 	//  using a struct, only one Update is needed to bring everything up to date
 	//
-	const Info& GetInfo(bool rangeonly = false, int rank = -1);
+	const Info& GetInfo(bool rangeonly = false, float start = 0.0, float length = 1.0);
 
 	void SetStretch(int v);
 	void SetInputComponent(int c);
