@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -57,7 +57,7 @@ public:
 	void AddOneLine(const iString &name, const iString &data, const iString &unit);
 
 	void ClearReport();
-	void FormatScalarData(iDataLimits *lim, int n, float *v, bool useClass = false);
+	void FormatScalarData(iDataLimits *lim, int n, float *v, bool useRank = false);
 	void FormatVectorData(iDataLimits *lim, int ivar, float *v, float *div = 0, float *vort = 0);
 	void FormatTensorData(iDataLimits *lim, int ivar, float *v, bool compressed = false);
 
