@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -134,7 +134,7 @@ void iDataLimits::Configure(int num)
 			tmp.Min = 0.1f;
 			tmp.Max = 10.0f;
 			tmp.FixedStretch = false;
-			tmp.Class = 0;
+			tmp.Rank = 0;
 			this->Initialize(tmp);
 			mListedVars.Add(tmp);
 		}
