@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -148,10 +148,10 @@ private:
 	virtual const iObjectType& GetObjectType() const; \
 	virtual const iDataType& GetDataType() const
 
-#define IDATASUBJECT_DEFINE_TYPE(_object_,_id_,_fname_,_sname_,_keywords_,_environment_) \
+#define IDATASUBJECT_DEFINE_TYPE(_object_,_id_,_fname_,_sname_,_rank_,_keywords_,_environment_) \
 	const iDataType& _object_::DataType() \
 	{ \
-		static const iDataType tmp(_id_,_fname_,_sname_,_keywords_,_environment_); \
+		static const iDataType tmp(_id_,_fname_,_sname_,_rank_,_keywords_,_environment_); \
 		return tmp; \
 	} \
 	const iObjectType& _object_::Type() \
@@ -188,8 +188,8 @@ public: \
 	IDATASUBJECT_DECLARE_INHERITED_MEMBERS; \
 }
 
-#define IDATASUBJECT_DEFINE_CLASS(_prefix_,_name_,_fname_,_sname_,_keywords_,_environment_) \
-IDATASUBJECT_DEFINE_TYPE(_prefix_##_name_##DataSubject,_prefix_##Extension::SubjectId(),_fname_,_sname_,_keywords_,_environment_); \
+#define IDATASUBJECT_DEFINE_CLASS(_prefix_,_name_,_fname_,_sname_,_rank_,_keywords_,_environment_) \
+IDATASUBJECT_DEFINE_TYPE(_prefix_##_name_##DataSubject,_prefix_##Extension::SubjectId(),_fname_,_sname_,_rank_,_keywords_,_environment_); \
 IDATASUBJECT_DEFINE_INHERITED_KEYS(_prefix_##_name_##DataSubject); \
 _prefix_##_name_##DataSubject::_prefix_##_name_##DataSubject(iFileLoader *fl) : iDataSubject(fl,_prefix_##_name_##DataSubject::Type().FullName()){}
 
