@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -74,8 +74,8 @@ private:
 #define IFIELDDATASUBJECT_DECLARE_INHERITED_KEYS \
 	IDATASUBJECT_DECLARE_INHERITED_KEYS
 
-#define IFIELDDATASUBJECT_DEFINE_TYPE(_object_,_id_,_fname_,_sname_,_keywords_,_environment_) \
-	IDATASUBJECT_DEFINE_TYPE(_object_,_id_,_fname_,_sname_,_keywords_,_environment_)
+#define IFIELDDATASUBJECT_DEFINE_TYPE(_object_,_id_,_fname_,_sname_,_rank_,_keywords_,_environment_) \
+	IDATASUBJECT_DEFINE_TYPE(_object_,_id_,_fname_,_sname_,_rank_,_keywords_,_environment_)
 
 #define IFIELDDATASUBJECT_DEFINE_INHERITED_KEYS(_type_) \
 	IDATASUBJECT_DEFINE_INHERITED_KEYS(_type_)
@@ -90,8 +90,8 @@ public: \
 	IFIELDDATASUBJECT_DECLARE_INHERITED_MEMBERS; \
 }
 
-#define IFIELDDATASUBJECT_DEFINE_CLASS(_prefix_,_name_,_fname_,_sname_,_keywords_,_environment_) \
-IFIELDDATASUBJECT_DEFINE_TYPE(_prefix_##_name_##DataSubject,_prefix_##Extension::SubjectId(),_fname_,_sname_,_keywords_,_environment_); \
+#define IFIELDDATASUBJECT_DEFINE_CLASS(_prefix_,_name_,_fname_,_sname_,_rank_,_keywords_,_environment_) \
+IFIELDDATASUBJECT_DEFINE_TYPE(_prefix_##_name_##DataSubject,_prefix_##Extension::SubjectId(),_fname_,_sname_,_rank_,_keywords_,_environment_); \
 IFIELDDATASUBJECT_DEFINE_INHERITED_KEYS(_prefix_##_name_##DataSubject); \
 _prefix_##_name_##DataSubject::_prefix_##_name_##DataSubject(iFieldFileLoader *fl) : iFieldDataSubject(fl,_prefix_##_name_##DataSubject::Type().FullName()){}
 
