@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -66,15 +66,15 @@ iFile::iFile(const iString &n)
 {
 	mName = n;
 	mStream = new fstream(); IERROR_ASSERT(mStream);
-	mMaxMarker = 100;
+	mMaxMarker = 0;
 	mNumMarker = 0;
-	mMarker = new iFilePosition[mMaxMarker]; IERROR_ASSERT(mMarker);
+	mMarker = 0;
 }
 
 iFile::~iFile()
 {
 	delete mStream;
-	delete mMarker;
+	if(mMarker != 0) delete mMarker;
 }
 
 
@@ -232,11 +232,11 @@ int iFile::SetMarker()
 	{
 		mMaxMarker += 100;
 		iFilePosition *tmp = new iFilePosition[mMaxMarker]; IERROR_ASSERT(tmp);
-		for(int i=0; i<mNumMarker; i++) 
+		if(mMarker != 0)
 		{
-			tmp[i] = mMarker[i];
+			for(int i=0; i<mNumMarker; i++) tmp[i] = mMarker[i];
+			delete [] mMarker;
 		}
-		delete [] mMarker;
 		mMarker = tmp;
 	}
 	mMarker[mNumMarker].Value = mStream->tellg();
