@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -61,13 +61,16 @@ iHistogramMaker::iHistogramMaker(iViewModule *vm) : iParallelWorker(vm->GetParal
 
 	mNumProcs = mNumBins = 0;
 
-	mDataRank = 0U;
+	mDataRank = 0;
 	mFullResolution = mSupportsFullResolution = false;
 
 	mRanges = 0;
 	mValues = 0;
 	mComponent = -1;
 
+	mProgressStart = 0.0;
+	mProgressLength = 1.0;
+
 	mAttached = true;
 
 	this->SetNumberOfInputConnections(0,1);
@@ -80,7 +83,7 @@ iHistogramMaker::iHistogramMaker(iViewModule *vm) : iParallelWorker(vm->GetParal
 
 iHistogramMaker::~iHistogramMaker()
 {
-	if(mAttached) mHisto->Delete();;
+	if(mAttached) mHisto->Delete();
 	if(mRanges != 0) 
 	{
 		delete [] mRanges;
@@ -131,9 +134,9 @@ vtkDataSet* iHistogramMaker::GetInput()
 }
 
 
-void iHistogramMaker::SetDataRank(unsigned int r)
+void iHistogramMaker::SetDataRank(int r)
 {
-	if(r<=2U && r!=mDataRank)
+	if(r>=0 && r<=2 && r!=mDataRank)
 	{
 		mDataRank = r;
 		this->Modified();
@@ -172,6 +175,14 @@ int iHistogramMaker::GetEstimatedNumberOfBins()
 }
 
 
+void iHistogramMaker::SetProgressRange(float start, float length)
+{
+	if(start>=0.0 && start<1.0) mProgressStart = start;
+	if(length > 0.0) mProgressLength = length;
+
+	if(mProgressStart+mProgressLength > 1.0) mProgressLength = 1.0 - mProgressStart;
+
+}
 void iHistogramMaker::Update()
 {
 	//
@@ -190,11 +201,6 @@ bool iHistogramMaker::ComputeRange()
 	//
 	if(this->GetInput()->GetMTime()>mComputeRangeTime || this->GetMTime()>mComputeRangeTime)
 	{
-		//
-		//  Must recompute
-		//
-		mComputeRangeTime.Modified();
-
 		//	
 		//  Recompute the limits
 		//
@@ -251,6 +257,11 @@ bool iHistogramMaker::ComputeRange()
 			if(mHisto->mValMin < 0) mHisto->mValMin *= 1.001; else mHisto->mValMin *= 0.999;
 			if(mHisto->mValMax < 0) mHisto->mValMax *= 0.999; else mHisto->mValMax *= 1.001;
 		}
+
+		//
+		//  Update the time
+		//
+		mComputeRangeTime.Modified();
 	}
 
 	return true;
@@ -312,11 +323,6 @@ const iHistogram* iHistogramMaker::GetHistogram(int nBins, float vMin, float vMa
 		return mHisto;
 	}
 
-	//
-	//  Must recompute
-	//
-	mComputeTime.Modified();
-
 	//
 	//  Check if we need to re-create the helper data 
 	//
@@ -367,6 +373,11 @@ const iHistogram* iHistogramMaker::GetHistogram(int nBins, float vMin, float vMa
 	mHisto->SetData(mNumBins,tmp);
 	delete [] tmp;
 
+	//
+	//  Update the time
+	//
+	mComputeTime.Modified();
+
 	return mHisto;
 }
 
@@ -419,7 +430,7 @@ int iHistogramMaker::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 			{
 				if(mFullResolution && this->IsMaster(p))
 				{
-					double p = double(l-lbeg)/(lend-lbeg);
+					double p = mProgressStart + 0.2*mProgressLength*double(l-lbeg)/(lend-lbeg);
 					this->InvokeEvent(vtkCommand::ProgressEvent,&p);
 				}
 				if(this->GetAbortExecute()) break;
@@ -466,7 +477,7 @@ int iHistogramMaker::ExecuteStep(int step, iParallel::ProcessorInfo &p)
 			{
 				if(mFullResolution && this->IsMaster(p))
 				{
-					double p = double(l-lbeg)/(lend-lbeg);
+					double p = mProgressStart + 0.2*mProgressLength + 0.8*mProgressLength*double(l-lbeg)/(lend-lbeg);
 					this->InvokeEvent(vtkCommand::ProgressEvent,&p);
 				}
 				if(this->GetAbortExecute()) break;
@@ -549,17 +560,17 @@ bool iHistogramMaker::IsDataPresent()
 	
 	switch(mDataRank)
 	{
-	case 0U:
+	case 0:
 		{
 			if(input->GetPointData()->GetScalars() == 0) return false;
 			break;
 		}
-	case 1U:
+	case 1:
 		{
 			if(input->GetPointData()->GetVectors() == 0) return false;
 			break;
 		}
-	case 2U:
+	case 2:
 		{
 			if(input->GetPointData()->GetTensors() == 0) return false;
 			break;
@@ -582,7 +593,7 @@ bool iHistogramMaker::PrepareForPass()
 	wDataPtr = 0;
 	switch(mDataRank)
 	{
-	case 0U:
+	case 0:
 		{
 			if(input->GetPointData()->GetScalars() == 0) return false;
 			//
@@ -595,7 +606,7 @@ bool iHistogramMaker::PrepareForPass()
 			if(mComponent<0 || mComponent>=wNumCom) return false;
 			break;
 		}
-	case 1U:
+	case 1:
 		{
 			if(input->GetPointData()->GetVectors() == 0) return false;
 			//
@@ -608,7 +619,7 @@ bool iHistogramMaker::PrepareForPass()
 			if(mComponent!=0 || wNumCom!=3) return false;
 			break;
 		}
-	case 2U:
+	case 2:
 		{
 			if(input->GetPointData()->GetTensors() == 0) return false;
 			//
