@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -996,7 +996,10 @@ bool iObject::UnPackValue(const iString &s, const iObjectKey &key, bool* val, in
 		{
 			v[i] = (tmp.Section(key.FieldSeparator(),i+1-i1,i+1-i1).ToInt(ok) != 0);
 		}
-		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(bool)); else IERROR_LOW("Invalid key value.");
+		if(ok) memcpy(val+i1,v+i1,(i2-i1)*sizeof(bool)); else
+		{
+			IERROR_LOW("Invalid key value.");
+		}
 		delete [] v;
 	}
 	else ok = false;
