@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -175,32 +175,36 @@ void iOrthoSlicer::ProduceOutput()
 	//
 	int ijk[3], ijk1[3], ijk2[3];
     float ht = (mPos[mDir]-orgIn[mDir])/spaIn[mDir];	//Normalized height
-	if(input->GetVoxelLocation() == VoxelLocation::Center) ht -= 0.5;
-    ijk[mDir] = int(ht);								//Grid Point below
-	if(ht < ijk[mDir]) ijk[mDir]--;
-    float ss1, ss2 = (ht-ijk[mDir]);					//interpolation factor
-
-	//
-	//  Add a little bit of a cushion
-	//
-	if(ijk[mDir]==-1 && ss2>0.99)
-	{
-		ijk[mDir] = 0;
-		ss2 = 0.0;
-	}
-
-	if(ijk[mDir]==numCellsIn[mDir] && ss2<0.01)
-	{
-		ijk[mDir] = numCellsIn[mDir] - 1;
-		ss2 = 1.0;
-	}
-	ss1 = 1.0 - ss2;
 
 	//
 	//  Must do that for parallel work
 	//
-	if(ijk[mDir]<0 || ijk[mDir]>=numCellsIn[mDir]) return;
+	if(ht<-0.01 || ht>numCellsIn[mDir]+0.01)
+	{
+		return;
+	}
 	
+	if(input->GetVoxelLocation() == VoxelLocation::Center) ht -= 0.5;
+
+	//
+	//  Add a little bit of a cushion
+	//
+	if(ht < 0.01) ht = 0.01;
+	if(ht > numCellsIn[mDir]-0.01) ht = numCellsIn[mDir] - 0.01;
+
+    ijk1[mDir] = ijk2[mDir] = int(ht); //Grid Point below
+	if(ijk2[mDir] < dimsIn[mDir]-1) ijk2[mDir]++;
+
+#ifdef I_CHECK1
+	if(ijk1[mDir]<0 || ijk2[mDir]>=dimsIn[mDir])
+	{
+		IERROR_REPORT_BUG;
+	}
+#endif
+
+    float ss2 = ht - ijk1[mDir];
+	float ss1 = 1.0 - ss2;
+
 	output->SetDimensions(dimsOut);
 	output->SetOrigin(orgOut);
 	output->SetSpacing(spaOut);
@@ -214,9 +218,6 @@ void iOrthoSlicer::ProduceOutput()
 	wScalarPtrIn += mCurVar;
 
 	vtkIdType loffOut, loffIn1, loffIn2;
-
-	ijk1[mDir] = ijk[mDir];
-	ijk2[mDir] = ijk[mDir] + 1;
 	for(ijk[v]=0; ijk[v]<dimsOut[v]; ijk[v]++)
 	{
 		this->UpdateProgress((float)ijk[v]/dimsOut[v]);
