@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -148,7 +148,7 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 	//
 	if(mOffX==0 && mOffY==0)
 	{
-		float tc[2];
+		float tc[2], pad;
 		static vtkIdType pts[4]={0,1,2,3};
 
 		int dimU, dimV;
@@ -156,11 +156,13 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 		{
 			dimU = mGlobalDims[u] - 1;
 			dimV = mGlobalDims[v] - 1;
+			pad = 0.0;
 		}
 		else
 		{
-			dimU = mGlobalDims[u];
-			dimV = mGlobalDims[v];
+			dimU = mGlobalDims[u] - 1;
+			dimV = mGlobalDims[v] - 1;
+			pad = 0.5;
 		}
 		//
 		// We'll create the building blocks of polydata including data attributes.
@@ -191,8 +193,8 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 		//
 		//  LL point 
 		//
-		x1[u] = mGlobalOrg[u];
-		x1[v] = mGlobalOrg[v];
+		x1[u] = mGlobalOrg[u] - pad*spa[u];
+		x1[v] = mGlobalOrg[v] - pad*spa[v];
 		points->SetPoint(0,x1);
 		tc[0] = 0.0;
 		tc[1] = 0.0;
@@ -200,8 +202,8 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 		//
 		//  LR point 
 		//
-		x1[u] = mGlobalOrg[u] + spa[u]*dimU;
-		x1[v] = mGlobalOrg[v];
+		x1[u] = mGlobalOrg[u] - pad*spa[u] + spa[u]*dimU;
+		x1[v] = mGlobalOrg[v] - pad*spa[v];
 		points->SetPoint(1,x1);
 		tc[0] = float(dimU)/dimsTexture[0];
 		tc[1] = 0.0;
@@ -209,8 +211,8 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 		//
 		//  UR point 
 		//
-		x1[u] = mGlobalOrg[u] + spa[u]*dimU;
-		x1[v] = mGlobalOrg[v] + spa[v]*dimV;
+		x1[u] = mGlobalOrg[u] - pad*spa[u] + spa[u]*dimU;
+		x1[v] = mGlobalOrg[v] - pad*spa[v] + spa[v]*dimV;
 		points->SetPoint(2,x1);
 		tc[0] = float(dimU)/dimsTexture[0];
 		tc[1] = float(dimV)/dimsTexture[1];
@@ -218,8 +220,8 @@ void iOrthoTexturePlaneFilter::ProduceOutput()
 		//
 		//  UL point 
 		//
-		x1[u] = mGlobalOrg[u];
-		x1[v] = mGlobalOrg[v] + spa[v]*dimV;
+		x1[u] = mGlobalOrg[u] - pad*spa[u];
+		x1[v] = mGlobalOrg[v] - pad*spa[v] + spa[v]*dimV;
 		points->SetPoint(3,x1);
 		tc[0] = 0.0;
 		tc[1] = float(dimV)/dimsTexture[1];
