@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -426,6 +426,10 @@ iRenderTool::~iRenderTool()
 
 	mMainRen->SetRenderWindow(0);
 	mMainWin->RemoveRenderer(mMainRen);
+	mMainWin->RemoveRenderer(mMainBkg->GetRenderer());
+
+	mMainBkg->Delete();
+	mDualBkg->Delete();
 
 	mDualRen->Delete();
 
