@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -54,6 +54,8 @@ iScript::iScript(iScript *parent) : mErrorStatus("Script")
 
 	mBlock = mIsCompiled = false;
 	
+	mErrorLine = mErrorPosition = -1;
+
 	//mText = "";
 	mThisEntry = mNextEntry = -1;
 
@@ -132,6 +134,19 @@ void iScript::AddConstant(iScriptKit::Value *value)
 
 
 iScriptKit::Calculator* iScript::CreateCalculator()
+{
+	int i;
+
+	iScriptKit::Calculator* calc = this->CreateCalculatorBody(); IERROR_ASSERT(calc);
+
+	for(i=0; i<mConstants.Size(); i++) calc->AddVariable(mConstants[i]->CalculatorValue());
+	//for(i=0; i<mVariables.Size(); i++) calc->AddVariable(mVariables[i]->CalculatorValue());
+
+	return calc;
+}
+
+
+iScriptKit::Calculator* iScript::CreateCalculatorBody()
 {
 	return new iScriptKit::Calculator(this);
 }
@@ -287,6 +302,7 @@ void iScript::RemoveVariables()
 	//
 	while(mVariables.Size() > 0)
 	{
+		if(mCalculator != 0) mCalculator->RemoveVariable(mVariables.Last()->Name());
 		delete mVariables.RemoveLast();
 	}
 	mIsCompiled = false;
@@ -298,6 +314,7 @@ void iScript::ReportError(const iString &message, int pos, int line)
 	this->GetErrorStatus()->Set(message);
 	mErrorPosition = pos;
 	if(line == -1) line = this->GetThisLine();
+	mErrorLine = line;
 }
 
 
@@ -444,13 +461,8 @@ bool iScript::Compile()
 
 	if(mCalculator == 0)
 	{
-		mCalculator = this->CreateCalculator(); IERROR_ASSERT(mCalculator);
-		if(mParent!=0 && mParent->mAllowChildAccess) mCalculator->CopyVariables(mParent->mCalculator); // this ensures correct name resolution
-
-		int i;
-		for(i=0; i<mConstants.Size(); i++) mCalculator->AddVariable(mConstants[i]->CalculatorValue());
+		mCalculator = this->CreateCalculator();
 	}
-
 	this->Reset();
 
 	int headLen = mHeadOfLineContinuationString.Length();
@@ -619,6 +631,7 @@ void iScript::AddVariable(iScriptKit::Value *value)
 			int ooo = 0;
 		}
 #endif
+		//if(mCalculator != 0) mCalculator->AddVariable(value->CalculatorValue());
 		mVariables.Add(value);
 	}
 }
@@ -633,6 +646,7 @@ void iScript::RemoveVariable(const iString &name)
 		{
 			if(mVariables[i]->Name() == name)
 			{
+				if(mCalculator != 0) mCalculator->RemoveVariable(mVariables[i]->Name());
 				delete mVariables[i];
 				mVariables.Remove(i);
 				return;  //  remove one at a time
