@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -120,6 +120,7 @@ public:
 
 	void QueryVariables(iArray<const iScriptKit::Value*> &list) const;
 
+	inline int GetErrorLine() const { return mErrorLine; }
 	inline int GetErrorPosition() const { return mErrorPosition; }
 	
 	//
@@ -164,6 +165,8 @@ protected:
 	
 	void AddConstant(iScriptKit::Value *value);
 
+	iScriptKit::Calculator* CreateCalculator();
+
 	//
 	//  Prototypes
 	//
@@ -178,7 +181,7 @@ protected:
 	//  Factory method: a calculator can be replaced by a child. It is non-const so that a child's
 	//  calculator can add new variables and constants.
 	//
-	virtual iScriptKit::Calculator* CreateCalculator();
+	virtual iScriptKit::Calculator* CreateCalculatorBody();
 
 	//
 	//  Overwrite this to create special non-algebraic variables
@@ -227,7 +230,7 @@ private:
 	void RemoveObserver(iScriptObserver *obs);
 
 	bool mBlock, mIsCompiled;
-	int mErrorPosition;
+	int mErrorLine, mErrorPosition;
 
 	iArray<AliasWord> mAliasWords;
 	iSearchableArray<iString> mDummyWords;
