@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -50,7 +50,7 @@ namespace iScriptKit
 	//
 	//  Calculator
 	//
-	Calculator::Calculator(iScript *script) : iCalculator<double>(script==0?0:script->GetCalculator()), mScript(script)
+	Calculator::Calculator(iScript *script) : iCalculator<double>(), mScript(script)
 	{
 		IERROR_ASSERT(mScript);
 		this->SetTrapFPE(true);
@@ -85,6 +85,13 @@ namespace iScriptKit
 	}
 
 
+	const iCalculatorKit::Variable* Calculator::FindExternalVariable(const iString &name) const
+	{
+		Value *var = mScript->FindVariable(name);
+		if(var != 0) return var->CalculatorValue(); else return 0;
+	}
+
+
 	//
 	//  Base class for values (variables and parameters)
 	//
@@ -329,7 +336,7 @@ namespace iScriptKit
 		if(c!=0 && !c->GetErrorMessage().IsEmpty())
 		{
 			int i = mArgument.FindIgnoringWhiteSpace(mOperand);
-			mScript->ReportError(c->GetErrorMessage(),mCommand.Length()+(i>-1?i+c->GetErrorPosition():0),-1);
+			mScript->ReportError(c->GetErrorMessage(),mCommand.Length()+(i>-1?i+c->GetErrorPosition():0),mLineInScript);
 		}
 	}
 
