@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -42,6 +42,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ishellfactory.h"
 #include "iversion.h"
 #include "iviewmodule.h"
+#include "ivolumeviewsubject.h"
 
 #include <vtkRenderWindow.h>
 #include <vtkTimerLog.h>
@@ -145,6 +146,8 @@ iShell::iShell(const iString &type, int, char **) : mType(type)
 	this->AddCommandLineOption("b",true,"execute a control script from a file <arg> in the screenless mode");
 	this->AddCommandLineOption("np",true,"set the number of processors to use to <arg>");
 	this->AddCommandLineOption("test",false,"test performance and exit (must be the first and only option)");
+	this->AddCommandLineOption("GPU",false,"try to use GPU even if VTK does not find it");
+	this->AddCommandLineOption("no-GPU",false,"do not use GPU even if it is present on the system (useful for running IFrIT remotely)");
 
 	//
 	//  Set environment variables
@@ -615,6 +618,16 @@ bool iShell::AnalyseOneCommandLineOption(const struct Option &o)
 		}
 	}
 
+	if(o.Name == "GPU")
+	{
+		iVolumeViewSubject::SetGPUMode(1);
+	}
+
+	if(o.Name == "no-GPU")
+	{
+		iVolumeViewSubject::SetGPUMode(-1);
+	}
+
 	return this->AnalyseOneExtendedCommandLineOption(o);
 }
 
