@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -38,6 +38,18 @@ iStereoImage::iStereoImage()
 }
 
 
+iStereoImage::iStereoImage(const iImage &img)
+{
+	this->operator=(img);
+}
+
+
+iStereoImage::iStereoImage(const iStereoImage &img)
+{
+	this->operator=(img);
+}
+
+
 iStereoImage& iStereoImage::operator=(const iStereoImage &img)
 {
 	mEyeImage[0] = img.mEyeImage[0];
