@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -41,6 +41,8 @@ class iStereoImage
 public:
 
 	iStereoImage();
+	iStereoImage(const iImage &img);
+	iStereoImage(const iStereoImage &img);
 
 	const iImage& Eye(int n) const;
 	const iImage& LeftEye() const;
