@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -118,6 +118,15 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iParameter;
 
 
+//
+//  Declare static members
+//
+int iViewModule::mSnapshotIndex = 1;
+int iViewModule::mAnimationIndex = 1;
+iString iViewModule::mSnapshotRootName;
+iString iViewModule::mAnimationRootName;
+
+
 //
 //  Define keys
 //
@@ -128,6 +137,7 @@ IOBJECT_DEFINE_KEY(iViewModule,ArtifactCorrection,ac,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,AxesBoxLabels,abl,String,3);
 IOBJECT_DEFINE_KEY(iViewModule,AxesBoxRanges,abr,Float,6);
 IOBJECT_DEFINE_KEY(iViewModule,AnimationOutput,ao,Int,1);
+IOBJECT_DEFINE_KEY(iViewModule,AnimationRootName,an,String,1);
 IOBJECT_DEFINE_KEY(iViewModule,BoundingBox,bb,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,BoundingBoxType,bbt,Int,1);
 IOBJECT_DEFINE_KEY(iViewModule,BackgroundColor,bg,Color,1);
@@ -178,6 +188,7 @@ IOBJECT_DEFINE_KEY(iViewModule,Ruler,rl,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,RulerScale,rs,Float,1);
 IOBJECT_DEFINE_KEY(iViewModule,RulerTitle,rt,String,1);
 IOBJECT_DEFINE_KEY(iViewModule,Size,s,Int,2);
+IOBJECT_DEFINE_KEY(iViewModule,SnapshotRootName,sn,String,1);
 IOBJECT_DEFINE_KEY(iViewModule,UpdateRate,r,Int,1);
 IOBJECT_DEFINE_KEY(iViewModule,StereoAlignmentMarks,sam,Bool,1);
 IOBJECT_DEFINE_KEY(iViewModule,StereoMode,sm,Int,1);
@@ -241,6 +252,9 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 {
 	int i;
 	
+	if(mSnapshotRootName.IsEmpty()) this->SetSnapshotRootName("+image");
+	if(mAnimationRootName.IsEmpty()) this->SetAnimationRootName("+anim");
+
 	mBoxType = -1; // needs to be reset
 	mImageMagnification = 1;
 	mSavedProjection = 0;
@@ -251,6 +265,7 @@ iViewModule::iViewModule(iControlModule *cm) : iExtendableObject("View Module"),
 	mAntialiasing = true;
 	mInImageRender = false;
 	mBackgroundImageFixedAspect = false;
+	mInAnimation = false;
 
 	mRate = 10;
 	mBoxSize = -1.0;
@@ -1084,7 +1099,6 @@ void iViewModule::SetBackgroundColor(const iColor &bg)
 	mRenderTool->SetBackground(mBackgroundColor);
 	mMeasuringBox->SetColor(fg);
 	mBox1Actor->GetProperty()->SetColor(fg.ToVTK());
-	mAnimator->SetCameraPathColor(fg);
 	mMarkerFamily->SetHandlesColor(fg);
 	this->ClearCache();
 }
@@ -1331,7 +1345,24 @@ void iViewModule::DumpImages(const iStereoImageArray &images, int m)
 	if(this->GetErrorStatus()->NoError())
 	{
 		mObsProgress->SetMode(iProgressEventObserver::_Writing);  // auto-driven
-		mWriter->WriteFrame(tmp,m);
+
+		switch(m)
+		{
+		case ImageType::Snapshot:
+			{
+				mWriter->WriteImageFrame(tmp,this->GetSnapshotFileName());
+				mSnapshotIndex++;
+				break;
+			}
+		case ImageType::AnimationFrame:
+			{
+				if(mInAnimation) mWriter->WriteMovieFrame(tmp,this->GetAnimationFileName()); else
+				{
+					IERROR_LOW("Trying to write a frame for an animation that has not started.");
+				}
+				break;
+			}
+		}
 	}
 	else
 	{
@@ -1376,6 +1407,9 @@ void iViewModule::ExtendableObjectPackStateBody(iString &s) const
 	this->PackValue(s,KeyLabelOffset(),mLabelOffset);
 	this->PackValue(s,KeyLabelDigits(),mLabelDigits);
 
+	this->PackValue(s,KeySnapshotRootName(),this->GetSnapshotRootName());
+	this->PackValue(s,KeyAnimationRootName(),this->GetAnimationRootName());
+
 	this->PackValue(s,KeyFontScale(),this->GetFontScale());
 	this->PackValue(s,KeyFontType(),this->GetFontType());
 	this->PackValue(s,KeyBoundingBoxType(),mBoxType);
@@ -1474,6 +1508,9 @@ void iViewModule::ExtendableObjectUnPackStateBody(const iString &s)
 	if(this->UnPackValue(s,KeyArtifactCorrection(),b)) this->SetArtifactCorrection(b);
 	if(this->UnPackValue(s,KeyBackgroundImageFixedAspect(),b)) this->SetBackgroundImageFixedAspect(b);
 
+	if(this->UnPackValue(s,KeySnapshotRootName(),w)) this->SetSnapshotRootName(w);
+	if(this->UnPackValue(s,KeyAnimationRootName(),w)) this->SetAnimationRootName(w);
+
 	iObject::ReportMissingKeys(false);
 	if(this->UnPackValue(s,KeyFontSize(),i)) this->SetFontScale(round(log(i/16.0)/0.3)); // for backward compatibility only
 	iObject::ReportMissingKeys(true);
@@ -1763,6 +1800,113 @@ int iViewModule::GetFontType() const
 }
 
 
+void iViewModule::SetSnapshotRootName(const iString &name)
+{
+	if(!name.IsEmpty() && name!=mSnapshotRootName)
+	{
+		mSnapshotIndex = 1;
+		mSnapshotRootName = name;
+
+		if(mSnapshotRootName[0] == '+')
+		{
+			mSnapshotRootName = this->GetControlModule()->GetShell()->GetEnvironment(Environment::Image) + mSnapshotRootName.Part(1);
+		}
+
+#ifdef _WIN32
+		mSnapshotRootName.Replace("\\","/");
+#endif		
+		this->ClearCache();
+	}
+}
+
+
+const iString& iViewModule::GetSnapshotRootName() const
+{
+	return mSnapshotRootName;
+}
+
+
+const iString& iViewModule::GetSnapshotFileName()
+{
+	static iString root;
+
+	root = mSnapshotRootName + "-" + iString::FromNumber(mSnapshotIndex,"%05d");
+
+	return root;
+}
+
+
+void iViewModule::SetAnimationRootName(const iString &name)
+{
+	if(!name.IsEmpty() && name!=mAnimationRootName)
+	{
+		mAnimationIndex = 1; 
+		mAnimationRootName = name;
+
+		if(mAnimationRootName[0] == '+')
+		{
+			mAnimationRootName = this->GetControlModule()->GetShell()->GetEnvironment(Environment::Image) + mAnimationRootName.Part(1);
+		}
+
+#ifdef _WIN32
+		mAnimationRootName.Replace("\\","/");
+#endif
+		this->ClearCache();
+	}
+}
+
+
+const iString& iViewModule::GetAnimationRootName() const
+{
+	return mAnimationRootName;
+}
+
+
+const iString& iViewModule::GetAnimationFileName()
+{
+	static iString root;
+
+	root = mAnimationRootName;
+	
+	if(mAnimationIndex > 1)
+	{
+		iString tail;
+		if(root[root.Length()-1] == '-')
+		{
+			tail = "-";
+			root = root.Part(0,root.Length()-1);
+		}
+		root += iString::FromNumber(mAnimationIndex) + tail;
+	}
+
+	return root;
+}
+
+
+void iViewModule::StartAnimation()
+{
+	if(mInAnimation)
+	{
+		IERROR_LOW("Previous animation has not completed properly.");
+	}
+
+	mWriter->StartMovie();
+	mInAnimation = true;
+}
+
+
+void iViewModule::FinishAnimation()
+{
+	if(!mInAnimation)
+	{
+		IERROR_LOW("Animation is finishing without starting.");
+	}
+
+	mAnimationIndex++;
+	mInAnimation = false;
+}
+
+
 //
 //  Access to RenderTool components
 //
