@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -114,6 +114,9 @@ IVIEWSUBJECT_DEFINE_INHERITED_KEYS_SHADING(iVolumeViewSubject);
 IVIEWSUBJECT_DEFINE_INHERITED_KEYS_REPLICATING(iVolumeViewSubject);
 
 
+int iVolumeViewSubject::mGPUMode = 0;  // auto
+
+
 namespace iVolumeViewSubject_Private
 {
 	class UniformGridVolumeRenderingHelper : public iVolumeRenderingHelper
@@ -380,6 +383,8 @@ namespace iVolumeViewSubject_Private
 
 		virtual bool IsAvailable()
 		{
+			if(iVolumeViewSubject::GPUMode() < 0) return false;
+			if(iVolumeViewSubject::GPUMode() > 0) return true;
 			return (mMapper->IsRenderSupported(mParent->GetViewModule()->GetRenderWindow(),mParent->GetVolume()->GetProperty()) != 0);
 		}
 
@@ -400,67 +405,6 @@ namespace iVolumeViewSubject_Private
 	};
 #endif
 
-
-/*
-	class ShearWarpRayCastHelper : public UniformGridVolumeRenderingHelper
-	{
-
-	public:
-
-		ShearWarpRayCastHelper(iVolumeViewSubject *parent, vtkImageData *input) : UniformGridVolumeRenderingHelper(parent,"Shear warp ray casting")
-		{
-			mMapper = vtkVolumeShearWarpMapper::New(); IERROR_ASSERT(mMapper);
-			mMapper->AddObserver(vtkCommand::ProgressEvent,parent->GetViewModule()->GetAbortRenderEventObserver());
-			mMapper->IntermixIntersectingGeometryOn();
-			mMapper->AutoAdjustSampleDistancesOn();
-			mMapper->SetInput(input);
-			mMapper->SetFunctionTypeToComposite();
-		}
-
-		virtual ~ShearWarpRayCastHelper()
-		{
-			mMapper->Delete();
-		}
-
-		virtual vtkAbstractVolumeMapper* GetMapper()
-		{
-			return mMapper;
-		}
-
-		virtual void SetBlendMode(int m)
-		{
-			switch(m)
-			{
-			case 0:
-				{
-					mMapper->SetFunctionTypeToComposite();
-					break;
-				}
-			case 1:
-				{
-					mMapper->SetFunctionTypeToMIP();
-					break;
-				}
-			}
-		}
-
-	protected:
-
-		virtual void AdjustSpacing()
-		{
-			if(mMapper->GetAutoAdjustSampleDistances() == 0)
-			{
-				mMapper->SetImageSampleDistance(mImageDownsampleFactor);
-			}
-		}
-
-	private:
-
-		vtkVolumeShearWarpMapper *mMapper;
-	};
-*/
-
-
 #ifdef VTK_USE_VOLUMEPRO
 	class VolumeProHelper : public UniformGridVolumeRenderingHelper
 	{
@@ -961,6 +905,12 @@ void iVolumeViewSubject::ViewSubjectSyncWithData(const iDataSyncRequest &)
 }
 
 
+void iVolumeViewSubject::SetGPUMode(int m)
+{
+	mGPUMode = m;
+}
+
+
 //
 //  Helper class
 //
