@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -148,6 +148,9 @@ public:
 	IVIEWSUBJECT_DECLARE_INHERITED_KEYS;
 	IVIEWSUBJECT_DECLARE_INHERITED_MEMBERS;
 
+	static void SetGPUMode(int m);
+	static int GPUMode(){ return mGPUMode; }
+
 protected:
 	
 	iVolumeViewSubject(iViewModule *vm, const iDataType &type, const iString &name);
@@ -164,6 +167,8 @@ protected:
 	int mBlendMode, mInterpolationType; 
 	float mImageDownsampleFactor, mDepthDownsampleFactor;
 
+	static int mGPUMode;
+
 	//
 	//  VTK members
 	//
