@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -37,15 +37,16 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iviewmodule.h"
 #include "ivtk.h"
 
-#include <vtkBMPWriter.h>
+#include <vtkDirectory.h>
+#include <vtkGenericMovieWriter.h>
 #include <vtkImageData.h>
+
+#include <vtkBMPWriter.h>
 #include <vtkJPEGWriter.h>
 #include <vtkPNGWriter.h>
 #include <vtkPNMWriter.h>
 #include <vtkTIFFWriter.h>
 
-#include <vtkGenericMovieWriter.h>
-
 #ifdef IVTK_SUPPORTS_AVI
 #include <vtkAVIWriter.h>
 #endif
@@ -64,15 +65,6 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iParameter;
 
 
-//
-//  Declare static members
-//
-int iWriter::mCurrentSnapshotImageIndex = 1;
-int iWriter::mCurrentAnimationImageIndex = 1;
-iString iWriter::mCurrentSnapshotImageFilePrefix = "ifrit-im";
-iString iWriter::mCurrentAnimationImageFilePrefix = "ifrit-an";
-
-
 //
 //  Helper class
 //
@@ -90,7 +82,7 @@ public:
 		mStarted = true;
 	}
 
-	void WriteFrame(const iStereoImageArray& images, const iString &path, const iString &root);
+	void WriteFrame(const iStereoImageArray& images, const iString &root);
 
 	void Finish()
 	{
@@ -110,10 +102,11 @@ public:
 
 protected:
 
-	iGenericMultiImageMovieWriter(iViewModule *vm) : mViewModule(vm)
+	iGenericMultiImageMovieWriter(iViewModule *vm, vtkImageWriter *writer) : mViewModule(vm)
 	{
 		IERROR_ASSERT(vm);
 		mStarted = false;
+		mParentWriter = writer;
 	}
 
 	virtual ~iGenericMultiImageMovieWriter()
@@ -126,33 +119,107 @@ protected:
 
 	bool mStarted;
 	iArray<vtkGenericMovieWriter*> mImageWriters;
+	vtkImageWriter *mParentWriter;
 };
 
 
 namespace iWriter_Private
 {
+	class FileSetMovieWriter : public vtkGenericMovieWriter
+	{
+	public:
+
+		static FileSetMovieWriter* New(vtkImageWriter *writer)
+		{
+			return new FileSetMovieWriter(writer);
+		}
+
+		virtual void Start()
+		{
+			mRoot = iString(FileName);
+			if(mRoot[mRoot.Length()-1] != '-')
+			{
+				vtkDirectory *d = vtkDirectory::New(); IERROR_ASSERT(d);
+				if(d->Open(mRoot.ToCharPointer()) == 0)
+				{
+					if(vtkDirectory::MakeDirectory(mRoot.ToCharPointer())==0 || d->Open(mRoot.ToCharPointer())==0)
+					{
+						mRoot += "-";
+					}
+					else
+					{
+						mRoot += "/frame-";
+					}
+				}
+				else
+				{
+					mRoot += "/frame-";
+				}
+			}
+			else
+			{
+			}
+
+			mFrame = 0;
+		}
+
+		virtual void Write()
+		{
+			iString suf = ".png";
+
+			if(mWriter->IsA("vtkJPEGWriter") != 0) suf = ".jpg";
+			if(mWriter->IsA("vtkPNMWriter")  != 0) suf = ".ppm";
+			if(mWriter->IsA("vtkBMPWriter")  != 0) suf = ".bmp";
+			if(mWriter->IsA("vtkTIFFWriter") != 0) suf = ".tif";
+			if(mWriter->IsA("vtkEPSWriter")  != 0) suf = ".eps";
+
+			mWriter->SetInput(this->GetInput());
+			mWriter->SetFileName((mRoot+iString::FromNumber(mFrame,"%05d")+suf).ToCharPointer());
+			mWriter->Write();
+			mFrame++;
+		}
+
+		virtual void End()
+		{
+		}
+
+	protected:
+
+		FileSetMovieWriter(vtkImageWriter *writer)
+		{
+			mWriter = writer; IERROR_ASSERT(mWriter);
+			mWriter->Register(this);
+		}
+
+		~FileSetMovieWriter()
+		{
+			mWriter->Delete();
+		}
+
+		int mFrame;
+		iString mRoot;
+		vtkImageWriter *mWriter;
+	};
+
 	template <class T>
 	class MultiImageMovieWriter : public iGenericMultiImageMovieWriter
 	{
 
 	public:
 
-		static MultiImageMovieWriter<T>* New(iViewModule *vm, const iString &suf)
+		static MultiImageMovieWriter<T>* New(iViewModule *vm, const iString &suf, vtkImageWriter *writer = 0)
 		{
-			return new MultiImageMovieWriter<T>(vm,suf);
+			return new MultiImageMovieWriter<T>(vm,suf,writer);
 		}
 
 	protected:
 
-		MultiImageMovieWriter(iViewModule *vm, const iString &suf) : iGenericMultiImageMovieWriter(vm)
+		MultiImageMovieWriter(iViewModule *vm, const iString &suf, vtkImageWriter *writer) : iGenericMultiImageMovieWriter(vm,writer)
 		{
-			mSuffix = suf;
+			if(!suf.IsEmpty()) mSuffix = "." + suf;
 		}
 
-		virtual vtkGenericMovieWriter* CreateWriter() const
-		{
-			return T::New();
-		}
+		virtual vtkGenericMovieWriter* CreateWriter() const;
 
 		virtual const iString& GetFileSuffix() const
 		{
@@ -162,6 +229,20 @@ namespace iWriter_Private
 		iString mSuffix;
 	};
 
+	
+	template <>
+	vtkGenericMovieWriter* MultiImageMovieWriter<FileSetMovieWriter>::CreateWriter() const
+	{
+		return FileSetMovieWriter::New(mParentWriter);
+	}
+
+
+	template <class T>
+	vtkGenericMovieWriter* MultiImageMovieWriter<T>::CreateWriter() const
+	{
+		return T::New();
+	}
+
 
 	iString FrameFileName(int i, const iString &tag, const iString &root)
 	{
@@ -179,27 +260,21 @@ namespace iWriter_Private
 				//
 				//  Other views
 				//
-				return "v" + iString::FromNumber(i+1,(i<99)?"%02d":"%d") + "-" + root;
+				return root + "-v" + iString::FromNumber(i+1,(i<99)?"%02d":"%d");
 			}
 		}
 		else
 		{
-			return tag + "-" + root;
+			return root + "-" + tag;
 		}
 	}
-
-
-	iString RightEyeFrameFileName(const iString &name)
-	{
-		return "re-" + name;
-	}
 };
 
 
 using namespace iWriter_Private;
 
 
-void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images, const iString &path, const iString &root)
+void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images, const iString &root)
 {
 	if(mStarted)
 	{
@@ -218,7 +293,15 @@ void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images,
 		for(i=0; i<mImageWriters.Size(); i+=2)
 		{
 			name = FrameFileName(i/2,images[i/2].GetTag(),root);
-			mImageWriters[i]->SetFileName((path+name+"."+this->GetFileSuffix()).ToCharPointer());
+			
+			if(images[i/2].IsStereo())
+			{
+				mImageWriters[i]->SetFileName((name+"-left"+this->GetFileSuffix()).ToCharPointer());
+			}
+			else
+			{
+				mImageWriters[i]->SetFileName((name+this->GetFileSuffix()).ToCharPointer());
+			}
 			mImageWriters[i]->SetInput(images[i/2].LeftEye().DataObject());
 			mImageWriters[i]->Start();
 			//
@@ -227,7 +310,7 @@ void iGenericMultiImageMovieWriter::WriteFrame(const iStereoImageArray& images,
 			if(images[i/2].IsStereo())
 			{
 				mImageWriters[i+1]->SetInput(images[i/2].RightEye().DataObject());
-				mImageWriters[i+1]->SetFileName((path+RightEyeFrameFileName(name)+"."+this->GetFileSuffix()).ToCharPointer());
+				mImageWriters[i+1]->SetFileName((name+"-right"+this->GetFileSuffix()).ToCharPointer());
 				mImageWriters[i+1]->Start();
 			}
 			else
@@ -300,8 +383,6 @@ iWriter::~iWriter()
 }
 
 
-
-
 void iWriter::SetImageFormat(int i)
 {
 	if(ImageFormat::IsValid(i) && i!=mImageFormat)
@@ -349,6 +430,15 @@ void iWriter::SetImageFormat(int i)
 		mImageWriter->AddObserver(vtkCommand::ProgressEvent,this->GetViewModule()->GetProgressEventObserver());
 		mImageWriter->AddObserver(vtkCommand::EndEvent,this->GetViewModule()->GetProgressEventObserver());
 		this->GetViewModule()->ClearCache();
+
+		//
+		//  Reset the animation writer if needed
+		//
+		if(mAnimationOutput == AnimationOutput::Image)
+		{
+			mAnimationOutput = -1;
+			this->SetAnimationOutput(AnimationOutput::Image);
+		}
 	}
 }
 
@@ -382,9 +472,9 @@ void iWriter::SetAnimationOutput(int i)
 		default:
 			{
 				//
-				//  Did not find a movie writer
+				//  File-set movie writer
 				//
-				mAnimationOutput = 0;
+				mMovieWriter = MultiImageMovieWriter<FileSetMovieWriter>::New(this->GetViewModule(),"",mImageWriter); IERROR_ASSERT(mMovieWriter);
 			}
 		}
 		this->GetViewModule()->ClearCache();
@@ -414,71 +504,27 @@ void iWriter::SetPostScriptOrientation(int i)
 }
 
 
-void iWriter::Start()
+void iWriter::StartMovie()
 {
-	if(mMovieWriter != 0)
-	{
-		mMovieWriter->Start();
-	}
+	IERROR_ASSERT(mMovieWriter);
+	mMovieWriter->Start();
 }
 
 
-void iWriter::Finish()
+void iWriter::FinishMovie()
 {
-	if(mMovieWriter != 0)
-	{
-		mMovieWriter->Finish();
-		mCurrentAnimationImageIndex++;
-	}
+	IERROR_ASSERT(mMovieWriter);
+	mMovieWriter->Finish();
 }
 
 
-void iWriter::WriteFrame(const iStereoImageArray& images, int mode)
-{
-	iString path, root;
-	int *cur;
-	
-	switch(mode) 
-	{
-	case ImageType::Snapshot:
-		{
-			root = mCurrentSnapshotImageFilePrefix;
-			cur = &mCurrentSnapshotImageIndex;
-			break;
-		}
-	case ImageType::AnimationFrame:
-		{
-			root = mCurrentAnimationImageFilePrefix;
-			cur = &mCurrentAnimationImageIndex;
-			break;
-		}
-	default:
-		{
-			IERROR_LOW("Invalid argument to iWriter::WriteFrame.");
-			return;
-		}
-	}
-
-	path = this->GetViewModule()->GetControlModule()->GetShell()->GetEnvironment(Environment::Image);
-	root += iString::FromNumber(*cur,"-%05d");
-
-	if(mode==ImageType::Snapshot || mMovieWriter==0)
-	{
-		this->WriteImageFrame(images,path,root);
-		(*cur)++;
-	}
-	else
-	{
-		this->WriteMovieFrame(images,path,root);
-	}
-}
-
-
-void iWriter::WriteImageFrame(const iStereoImageArray& images, const iString &path, const iString &root)
+void iWriter::WriteImageFrame(const iStereoImageArray& images, const iString &root)
 {
 	int i;
 	iString suf, name;
 
+	IERROR_ASSERT(mImageWriter);
+
 	switch(mImageFormat) 
 	{
 	case ImageFormat::JPG: { suf = ".jpg"; break; }
@@ -497,7 +543,14 @@ void iWriter::WriteImageFrame(const iStereoImageArray& images, const iString &pa
 		name = FrameFileName(i,images[i].GetTag(),root);
 
 		mImageWriter->SetInput(images[i].LeftEye().DataObject());
-		mImageWriter->SetFileName((path+name+suf).ToCharPointer());
+		if(images[i].IsStereo())
+		{
+			mImageWriter->SetFileName((name+"-left"+suf).ToCharPointer());
+		}
+		else
+		{
+			mImageWriter->SetFileName((name+suf).ToCharPointer());
+		}
 		mImageWriter->Write();
 		//
 		//  Right eye
@@ -505,22 +558,16 @@ void iWriter::WriteImageFrame(const iStereoImageArray& images, const iString &pa
 		if(images[i].IsStereo())
 		{
 			mImageWriter->SetInput(images[i].RightEye().DataObject());
-			mImageWriter->SetFileName((path+RightEyeFrameFileName(name)+suf).ToCharPointer());
+			mImageWriter->SetFileName((name+"-right"+suf).ToCharPointer());
 			mImageWriter->Write();
 		}
 	}
 }
 
 
-void iWriter::WriteMovieFrame(const iStereoImageArray& images, const iString &path, const iString &root)
+void iWriter::WriteMovieFrame(const iStereoImageArray& images, const iString &root)
 {
-	if(mMovieWriter != 0)
-	{
-		mMovieWriter->WriteFrame(images,path,root);
-	}
-	else
-	{
-		IERROR_LOW("Cannot write a movie file: a MovieWriter has not been created.");
-	}
+	IERROR_ASSERT(mMovieWriter);
+	mMovieWriter->WriteFrame(images,root);
 }
 
