@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -85,9 +85,10 @@ public:
 	//
 	//  Writing functionality
 	//
-	void Start();
-	void WriteFrame(const iStereoImageArray& images, int mode);
-	void Finish();
+	void WriteImageFrame(const iStereoImageArray& images, const iString &root);
+	void StartMovie();
+	void WriteMovieFrame(const iStereoImageArray& images, const iString &root);
+	void FinishMovie();
 
 	void SetImageFormat(int);
 	inline int GetImageFormat() const { return mImageFormat; }
@@ -101,9 +102,6 @@ public:
 	void SetPostScriptOrientation(int);
 	inline int GetPostScriptOrientation() const { return mPostScriptOrientation; }
 
-	inline void ResetAnimationImageIndex(int v = 1){ if(v > 0) mCurrentAnimationImageIndex = v; }
-	inline int GetCurrentAnimationImageIndex() const { return mCurrentAnimationImageIndex; }
-
 protected:
 	
 	virtual ~iWriter();
@@ -112,15 +110,9 @@ private:
 
 	iWriter(iViewModule *vm);
 
-	void WriteImageFrame(const iStereoImageArray& images, const iString &path, const iString &root);
-	void WriteMovieFrame(const iStereoImageArray& images, const iString &path, const iString &root);
-
 	//
 	//  Members
 	//
-	static int mCurrentSnapshotImageIndex, mCurrentAnimationImageIndex;
-	static iString mCurrentSnapshotImageFilePrefix, mCurrentAnimationImageFilePrefix;
-	
 	int mImageFormat, mAnimationOutput;
 	int mPostScriptPaperFormat, mPostScriptOrientation;
 
