@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -30,6 +30,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 #include "iconfigure.h"
+#include "iconsole.h"
 #include "ierror.h"
 #include "ifile.h"
 #include "iobject.h"
@@ -215,7 +216,7 @@ namespace iHelpFactory_Private
 
 		f.WriteLine("//LICENSE A");
 		f.WriteLine("#if 0");
-		f.WriteLine("#include \"../Work/"+outroot+".txt\"");
+		f.WriteLine("#include \"../../Work/"+outroot+".txt\"");
 		f.WriteLine("#else");
 		f.WriteLine("static iHelpData data[] = {");
 
@@ -265,6 +266,9 @@ namespace iHelpFactory_Private
 		f.WriteLine("};");
 		f.WriteLine("#endif");
 		f.Close();
+
+		iConsole::Display(iConsole::_Warning,"IFrIT is creating compressed help data...\nPlease compile again and re-run.");
+
 		exit(0);
 	}
 
@@ -547,57 +551,16 @@ iHelpDataBuffer* iHelpFactory::FindData(const char *tag, InfoSource source, bool
 
 
 #ifdef I_DEBUG
-void iHelpFactory::CreateUserGuide(UGForm form)
+void iHelpFactory::CreateUserGuide()
 {
 	static const iString afterPartTitle("<p>&nbsp;");
 	iString text, stmp;
 	iHelpDataBuffer *dtmp1;
 
-	if(form == _Publish)
-	{
-		iHelpFactory::CreateUserGuide(iHelpFactory::_Public);
-		iHelpFactory::CreateUserGuide(iHelpFactory::_Private);
-		system("Work\\scripts\\createug.csh");
-		return;
-	}
-
-	iString kind;
-	switch(form)
-	{
-	case _Base:
-		{
-			kind = "Base";
-			break;
-		}
-	case _Public:
-		{
-			kind = "Public";
-			break;
-		}
-	case _Private:
-		{
-			kind = "Private";
-			break;
-		}
-	}
-
 	//
 	//  Create the title page
 	//
 	stmp = "<html><head><title>Title page</title></head><body><center><img src=\"../images/genie2.png\"><p><img src=\"images/_logoug.png\" alt=\"<h1>IFrIT<br>User Guide</h1>\"><p><h2>by</h2><h1>Nick Gnedin and IFrIT</h1><p>&nbsp;<p>&nbsp;<p>&nbsp;<p><h3>IFrIT Version " + iVersion::GetVersion() + "</center>";
-	switch(form)
-	{
-	case _Public:
-		{
-			stmp += "<p><center><h3>(Including Public Extensions)</h3></center>";
-			break;
-		}
-	case _Private:
-		{
-			stmp += "<p><center><h3>(Including All Extensions)</h3></center>";
-			break;
-		}
-	}
 
 	//
 	//  Create preface
@@ -611,7 +574,7 @@ void iHelpFactory::CreateUserGuide(UGForm form)
 		delete dtmp1;
 	}
 	stmp += "</body></html>";
-	WriteFile("Work/docs/ugTitle"+kind+".html",stmp);
+	WriteFile("Work/docs/ugTitle.html",stmp);
 
 	//
 	//  Create part on user guide
@@ -819,45 +782,19 @@ void iHelpFactory::CreateUserGuide(UGForm form)
 #endif
 
 	//
-	//  Define what to create
+	//  If extra info is included, remove special <extra type=...> </extra> and <private></private> tags 
 	//
-	switch(form)
-	{
-	case _Base:
-		{
-			//
-			//  Remove everything between <extra type=...> and </extra> tags 
-			//
-			text.RemoveFormatting("<extra type=","</extra>");
-			//
-			//  No break, keep going
-			//
-		}
-	case _Public:
-		{
-			//
-			//  Remove everything between <private> and </private> tags 
-			//
-			text.RemoveFormatting("<private>","</private>");
-			break;
-		}
-	case _Private:
-		{
-			//
-			//  If extra info is included, remove special <extra type=...> </extra> and <private></private> tags 
-			//
-			text.RemoveFormatting("<extra type=",">");
-			text.Replace("</extra>","");
-			text.Replace("<private>","");
-			text.Replace("</private>","");
-			break;
-		}
-	}
+	text.RemoveFormatting("<extra type=",">");
+	text.Replace("</extra>","");
+	text.Replace("<private>","");
+	text.Replace("</private>","");
 
 	//
 	//  Create the html file
 	//
-	WriteFile("Work/docs/ug"+kind+".html","<html><title>&copy; 2005-2008 by Nick Gnedin</title><body>"+text+"</body></html>");
+	WriteFile("Work/docs/ug.html","<html><title>&copy; 2005-2012 by Nick Gnedin</title><body>"+text+"</body></html>");
+
+	system("Work\\scripts\\createpdf.csh");
 }
 #endif
 
