@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -26,6 +26,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 =========================================================================*/
 
 
+#include "iconsole.h"
 #include "iimagefactory.h"
 #include "istring.h"
 
@@ -45,6 +46,7 @@ namespace iImageFactory_Private
 		if(num == 0)
 		{
 			CreateData("Work/docs/images","Code/help/iimagefactorydata2.h","az");
+			iConsole::Display(iConsole::_Warning,"IFrIT is creating compressed help data...\nPlease compile again and re-run.");
 			exit(0);
 		}
 
