@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -50,6 +50,16 @@ ibgFrameSubject::ibgFrameSubject(iggFrame *owner, int /*cols*/) : ibgWidgetSubje
 }
 
 
+bool ibgFrameSubject::BeforeShow()
+{
+	if(mFrameOwner != 0)
+	{
+		if(mFrameOwner->NeedsRedoLayout()) return true;
+	}
+	return false;
+}
+
+
 //
 //  FrameBook class
 //
