@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -62,13 +62,15 @@ protected:
 	virtual void SetFullScreen(bool) = 0;
 	virtual void MakeCurrent() = 0;
 
-	virtual void* GetDisplayId() const = 0;
+	virtual void* GetDisplay() const = 0;
+	virtual void* GetContext() const = 0;
 	virtual void* GetWindowId() const = 0;
 	virtual void SetWindowName(const iString &s) = 0;
 
 	virtual void RenderIntoMemory(iImage &) = 0;
 	virtual bool IsReadyForDumpingImage() = 0;
 
+	virtual bool IsDirect() const = 0;
 	virtual bool IsCurrent() const = 0;
 
 	virtual void RequestStereo(bool s) = 0;
