@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -53,7 +53,7 @@ public:
 
 protected:
 
-	ibgWidgetColorSelectionSubject(iggWidget *owner, bool horizontal);
+	ibgWidgetColorSelectionSubject(iggWidget *owner);
 };
 
 #endif  // IBGWIDGETKEYCOLORSELECTIONSUBJECT_H
