@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -40,7 +40,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iString;
 
 class iggWidget;
-class iggWidgetRenderModeButton;
+class ibgWidgetButtonSubject;
 
 
 class ibgWidgetEntrySubject : public ibgWidgetSubject
@@ -48,12 +48,13 @@ class ibgWidgetEntrySubject : public ibgWidgetSubject
 
 public:
 
-	ibgWidgetEntrySubject(iggWidget *owner, bool slider, int numdig, const iString &label, iggWidgetRenderModeButton* rmb);
+	ibgWidgetEntrySubject(iggWidget *owner, bool slider, int numdig, const iString &label);
 	virtual ~ibgWidgetEntrySubject();
 
 	virtual void FreezeNumberOfDigits(bool s);
 	void IncrementNumDigits(int n){ if(mNumDigits>0 && mNumDigits+n>0) mNumDigits += n; }
 
+	virtual void AddButton(ibgWidgetButtonSubject* button) = 0;
 	virtual void SetEditable(bool s) = 0;
 	virtual void SetDelayedEdit(bool s) = 0;
 
@@ -72,6 +73,8 @@ public:
 	virtual void SetText(const iString &text) = 0;
 	virtual void SelectText(int start, int len = -1) = 0;
 
+	virtual void ShowTail() = 0;
+
 	virtual void SetStretch(int label, int slider, int number = 0) = 0;
 
 protected:
