@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -38,7 +38,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 class iColor;
 class iTransform;
 
-class iggWidgetRenderModeButton;
+class ibgWidgetButtonSubject;
 
 
 class ibgWidgetTrackBallSubject : public ibgWidgetSubject
@@ -55,8 +55,9 @@ public:
 
 protected:
 
-    ibgWidgetTrackBallSubject(iggWidget *owner, bool followCamera, iggWidgetRenderModeButton* rmb);
+    ibgWidgetTrackBallSubject(iggWidget *owner, bool followCamera);
 
+	virtual void AddButton(ibgWidgetButtonSubject* button) = 0;
 	virtual void GetSizes(int &w0, int &h0, int &rad, int &cor) = 0;
 	virtual void Repaint() = 0;
 
