@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -404,14 +404,14 @@ ibgWidgetButtonSubject* iggSubjectFactory::CreateWidgetButtonSubject(iggWidget *
 }
 	
 
-ibgWidgetColorSelectionSubject* iggSubjectFactory::CreateWidgetColorSelectionSubject(iggWidget *owner, bool horizontal)
+ibgWidgetColorSelectionSubject* iggSubjectFactory::CreateWidgetColorSelectionSubject(iggWidget *owner)
 {
 	if(owner->GetShell() == 0) return 0;
 
 	if(owner->GetShell()->Type() == qt)
 	{
 #if ISHELL_INCLUDED(ISHELL_QT)
-		RETURN_SUBJECT1(qt,WidgetColorSelection,horizontal);
+		RETURN_SUBJECT0(qt,WidgetColorSelection);
 #else
 		return 0;
 #endif
@@ -420,7 +420,7 @@ ibgWidgetColorSelectionSubject* iggSubjectFactory::CreateWidgetColorSelectionSub
 	if(owner->GetShell()->Type() == fx)
 	{
 #if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT1(fx,WidgetColorSelection,horizontal);
+		RETURN_SUBJECT0(fx,WidgetColorSelection);
 #else
 		return 0;
 #endif
@@ -507,14 +507,14 @@ ibgWidgetDrawAreaSubject* iggSubjectFactory::CreateWidgetDrawAreaSubject(iggWidg
 }
 	
 
-ibgWidgetEntrySubject* iggSubjectFactory::CreateWidgetEntrySubject(iggWidget *owner, bool slider, int numdig, const iString &label, iggWidgetRenderModeButton* rmb)
+ibgWidgetEntrySubject* iggSubjectFactory::CreateWidgetEntrySubject(iggWidget *owner, bool slider, int numdig, const iString &label)
 {
 	if(owner->GetShell() == 0) return 0;
 
 	if(owner->GetShell()->Type() == qt)
 	{
 #if ISHELL_INCLUDED(ISHELL_QT)
-		RETURN_SUBJECT4(qt,WidgetEntry,slider,numdig,label,rmb);
+		RETURN_SUBJECT3(qt,WidgetEntry,slider,numdig,label);
 #else
 		return 0;
 #endif
@@ -523,7 +523,7 @@ ibgWidgetEntrySubject* iggSubjectFactory::CreateWidgetEntrySubject(iggWidget *ow
 	if(owner->GetShell()->Type() == fx)
 	{
 #if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT4(fx,WidgetEntry,slider,numdig,label,rmb);
+		RETURN_SUBJECT3(fx,WidgetEntry,slider,numdig,label);
 #else
 		return 0;
 #endif
@@ -689,14 +689,14 @@ ibgWidgetTextEditorSubject* iggSubjectFactory::CreateWidgetTextEditorSubject(igg
 }
 
 
-ibgWidgetTrackBallSubject* iggSubjectFactory::CreateWidgetTrackBallSubject(iggWidget *owner, bool followCamera, iggWidgetRenderModeButton* rmb)
+ibgWidgetTrackBallSubject* iggSubjectFactory::CreateWidgetTrackBallSubject(iggWidget *owner, bool followCamera)
 {
 	if(owner->GetShell() == 0) return 0;
 
 	if(owner->GetShell()->Type() == qt)
 	{
 #if ISHELL_INCLUDED(ISHELL_QT)
-		RETURN_SUBJECT2(qt,WidgetTrackBall,followCamera,rmb);
+		RETURN_SUBJECT1(qt,WidgetTrackBall,followCamera);
 #else
 		return 0;
 #endif
@@ -705,7 +705,7 @@ ibgWidgetTrackBallSubject* iggSubjectFactory::CreateWidgetTrackBallSubject(iggWi
 	if(owner->GetShell()->Type() == fx)
 	{
 #if ISHELL_INCLUDED(ISHELL_FX)
-		RETURN_SUBJECT2(fx,WidgetTrackBall,followCamera,rmb);
+		RETURN_SUBJECT1(fx,WidgetTrackBall,followCamera);
 #else
 		return 0;
 #endif
