@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -50,7 +50,6 @@ class iggShell;
 class iggWidget;
 class iggWidgetDrawArea;
 class iggWidgetHelpBrowser;
-class iggWidgetRenderModeButton;
 class iggWidgetTextEditor;
 
 class ibgDialogSubject;
@@ -101,18 +100,18 @@ public:
 	static ibgShellSubject*							CreateShellSubject(iggShell *owner, int argc, char **argv);
 
 	static ibgWidgetButtonSubject*					CreateWidgetButtonSubject(iggWidget *owner, int type, const iString &text, int slot);
-	static ibgWidgetColorSelectionSubject*			CreateWidgetColorSelectionSubject(iggWidget *owner, bool horizontal);
+	static ibgWidgetColorSelectionSubject*			CreateWidgetColorSelectionSubject(iggWidget *owner);
 	static ibgWidgetComboBoxSubject*				CreateWidgetComboBoxSubject(iggWidget *owner, const iString &title, bool bold = false);
 	static ibgWidgetDisplayAreaSubject*				CreateWidgetDisplayAreaSubject(iggWidget *owner, const iString &text);
 	static ibgWidgetDrawAreaSubject*				CreateWidgetDrawAreaSubject(iggWidgetDrawArea *owner, bool interactive);
-	static ibgWidgetEntrySubject*					CreateWidgetEntrySubject(iggWidget *owner, bool slider, int numdig, const iString &label, iggWidgetRenderModeButton* rmb);
+	static ibgWidgetEntrySubject*					CreateWidgetEntrySubject(iggWidget *owner, bool slider, int numdig, const iString &label);
 	static ibgWidgetHelpBrowserSubject*				CreateWidgetHelpBrowserSubject(iggWidgetHelpBrowser *owner);
 	static ibgWidgetMultiImageDisplayAreaSubject*	CreateWidgetMultiImageDisplayAreaSubject(iggWidget *owner);
 	static ibgWidgetProgressBarSubject*				CreateWidgetProgressBarSubject(iggWidget *owner);
 	static ibgWidgetRadioBoxSubject*				CreateWidgetRadioBoxSubject(iggWidget *owner, int cols, const iString &title);
 	static ibgWidgetSpinBoxSubject*					CreateWidgetSpinBoxSubject(iggWidget *owner, int min, int max, const iString &title, int step);
 	static ibgWidgetTextEditorSubject*				CreateWidgetTextEditorSubject(iggWidgetTextEditor *owner, unsigned int mode);
-	static ibgWidgetTrackBallSubject*				CreateWidgetTrackBallSubject(iggWidget *owner, bool followCamera, iggWidgetRenderModeButton* rmb);
+	static ibgWidgetTrackBallSubject*				CreateWidgetTrackBallSubject(iggWidget *owner, bool followCamera);
 
 private:
 
