@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -36,6 +36,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggelement.h"
 
 
+#include "iarray.h"
+
+
 class iImage;
 class iString;
 
@@ -78,7 +81,7 @@ public:
 	inline ibgDialogSubject* GetSubject() const { return mSubject; }
 	inline iggFrame* GetFrame() const { return mFrame; }
 
-	virtual void Show(bool s);
+	void Show(bool s);
 	bool IsVisible() const;
 	void ResizeContents(int w, int h);
 
@@ -93,15 +96,25 @@ public:
 	virtual const iString& GetToolTip() const;
 	iString GetBaloonHelp() const;
 
+#ifdef I_DEBUG
+	static void FlashAllDialogs();
+#endif
+
 protected:
 
 	iggDialog(iShell *shell, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext = "");
 	iggDialog(const iggMenuWindow *mw, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext = "");
 	iggDialog(const iggDialog *pd, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext = "");
 
+	virtual void ShowBody(bool s);
 	virtual bool CanBeClosed();
 	void AttachSubject(ibgDialogSubject *subject); //  this is a dummy for factory use
 
+	bool ImmediateConstruction() const; 
+	void CompleteConstruction();
+	virtual void CompleteConstructionBody() = 0;
+
+	bool mCompleteConstructionCalled;
 	ibgDialogSubject *mSubject;
 	iggMainWindow *mMainWindow;
 	iggFrame *mFrame;
@@ -112,6 +125,11 @@ private:
 
 	void Define(const ibgWindowSubject *base, unsigned int mode, const iImage *icon, const iString &title, const char *helpkey, int cols, const char *closetext);
 
+	//
+	//  Registry
+	//
+	static iPointerArray<iggDialog>& List();
+
 	iggDialog(const iggDialog&); // Not implemented.
 	void operator=(const iggDialog&);  // Not implemented.
 };
