@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -116,6 +116,12 @@ using namespace iggDialogAnimatingProgress_Private;
 
 
 iggDialogAnimatingProgress::iggDialogAnimatingProgress(iggMainWindow *parent) : iggDialog(parent,DialogFlag::Blocking|DialogFlag::NoTitleBar,0,"Animating...",0,4,0), iScriptObserver(0)
+{
+	if(this->ImmediateConstruction()) this->CompleteConstruction();
+}
+
+
+void iggDialogAnimatingProgress::CompleteConstructionBody()
 {
 	mFrame->AddLine(new iggWidgetTextArea("%bAnimating the scene...",mFrame),4);
 	
@@ -124,9 +130,6 @@ iggDialogAnimatingProgress::iggDialogAnimatingProgress(iggMainWindow *parent) :
 	mFrame->AddSpace(10);
 
 	mInfoFrame = new iggFrame(mFrame,2);
-	mCurrentImageNumber = new iggWidgetTextArea("   1",mInfoFrame);
-	mCurrentImageNumber->AlignLeft(true);
-	mInfoFrame->AddLine(new iggWidgetTextArea("Current image #: ",mInfoFrame),mCurrentImageNumber);
 	mCurrentRecord = new iggWidgetTextArea("   0",mInfoFrame);
 	mCurrentRecord->AlignLeft(true);
 	mInfoFrame->AddLine(new iggWidgetTextArea("Current record: ",mInfoFrame),mCurrentRecord);
@@ -164,7 +167,9 @@ void iggDialogAnimatingProgress::OnScriptStartBody()
     mCancelled = false;
 	this->Pause(false);
 
-	mLastImageIndex = mLastRecord = mLastFrame = -1;
+	mLastRecord = mLastFrame = -1;
+
+	mCurrentViewModule = this->GetShell()->GetControlModule()->GetViewModule();
 
 	this->DisplayInfo();
 
@@ -194,15 +199,13 @@ void iggDialogAnimatingProgress::OnScriptEndLineBody(int, const iString &)
 void iggDialogAnimatingProgress::DisplayInfo()
 {
 	bool nr;
-	int cr, cf, cii = mCurrentViewModule->GetWriter()->GetCurrentAnimationImageIndex();
+	int cr, cf;
+	iString s;
+	
+	this->CompleteConstruction();
 	
 	mCurrentViewModule->GetAnimator()->GetInfo(nr,cr,cf);
 
-	if(cii != mLastImageIndex)
-	{
-		mLastImageIndex = cii;
-		mCurrentImageNumber->SetText(iString::FromNumber(cii,"%5d"));
-	}
 	if(cr != mLastRecord)
 	{
 		mLastRecord = cr;
@@ -241,6 +244,8 @@ void iggDialogAnimatingProgress::Pause(bool s)
 {
 	mPaused = s;
 
+	this->CompleteConstruction();
+	
 	mInfoFrame->Show(!s);
 	mWarningFrame->Show(s);
 
