@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -49,13 +49,14 @@ public:
 	virtual ~iggDialogAuto();
 
 	const iString& GetTitle() const { return mTitle; }
-	virtual void Show(bool s);
 	void ForceShow(bool s);
 
 protected:
 
 	iggDialogAuto(iggMainWindow *mw, const iString &title, int cols);
 
+	virtual void ShowBody(bool s);
+
 private:
 
 	const iString mTitle;
