@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -292,7 +292,7 @@ namespace iggDialogCommandLine_Private
 			mDialog = dialog;
 			mCurHistoryLine = -1;
 
-			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,0,"",0);
+			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,0,"");
 			this->SetBaloonHelp("Type a script command","Type a Control Script command to be executed. Add a semicolon (;) at the end of the command to execute this and all previous unexecuted commands.<p>"+Help1);
 		}
 
@@ -487,8 +487,12 @@ namespace iggDialogCommandLine_Private
 			mFrame->SetColStretch(1,10);
 
 			this->ResizeContents(300,400);
+
+			this->CompleteConstruction();
 		}
 
+		void CompleteConstructionBody(){}
+
 		virtual const iString& GetToolTip() const 
 		{
 			static const iString tmp = "Shows the script text typed in so far";
@@ -497,7 +501,7 @@ namespace iggDialogCommandLine_Private
 
 	protected:
 
-		virtual void Show(bool s)
+		virtual void ShowBody(bool s)
 		{
 			if(s)
 			{
@@ -505,7 +509,7 @@ namespace iggDialogCommandLine_Private
 				text.Replace("\n","<br>");
 				mBrowser->SetText(text);
 			}
-			iggDialog::Show(s);
+			iggDialog::ShowBody(s);
 		}
 
 		CommandInterpreter *mInterpreter;
@@ -519,6 +523,15 @@ using namespace iggDialogCommandLine_Private;
 
 
 iggDialogCommandLine::iggDialogCommandLine(iggMainWindow *parent) : iggDialog(parent,0U,iImageFactory::FindIcon("comline.png"),"Command Line","sr.gg.dc",1,0)
+{
+	mViewScriptDialog = 0;
+	mInterpreter = 0;
+
+	if(this->ImmediateConstruction()) this->CompleteConstruction();
+}
+
+
+void iggDialogCommandLine::CompleteConstructionBody()
 {
 	iggWidgetTextBrowser *b = new iggWidgetTextBrowser(true,false,mFrame);
 	CommandInterpreter *ci = new CommandInterpreter(b);
@@ -577,8 +590,8 @@ iggDialogCommandLine::iggDialogCommandLine(iggMainWindow *parent) : iggDialog(pa
 
 iggDialogCommandLine::~iggDialogCommandLine()
 {
-	delete mViewScriptDialog;
-	mInterpreter->Delete();
+	if(mViewScriptDialog != 0) delete mViewScriptDialog;
+	if(mInterpreter != 0) mInterpreter->Delete();
 }
 
 
