@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -104,7 +104,7 @@ namespace iggDialogDataExplorer_Private
 		VariablePropertyDialogOpacitySlider(VariablePropertyDialog *dialog, iggFrame *parent) : iggWidget(parent)
 		{
 			mDialog = dialog;
-			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,true,0,"Opacity",0);
+			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,true,0,"Opacity");
 			mNeedsBaloonHelp = false;
 		}
 
@@ -125,7 +125,7 @@ namespace iggDialogDataExplorer_Private
 		VariablePropertyDialogColorSelection(VariablePropertyDialog *dialog, iggFrame *parent) : iggWidget(parent)
 		{
 			mDialog = dialog;
-			mSubject = iggSubjectFactory::CreateWidgetColorSelectionSubject(this,true);
+			mSubject = iggSubjectFactory::CreateWidgetColorSelectionSubject(this);
 			mNeedsBaloonHelp = false;
 		}
 
@@ -148,7 +148,10 @@ namespace iggDialogDataExplorer_Private
 			mList = list;
 			mArea = area;
 			mVariable = 0;
+		}
 
+		void CompleteConstructionBody()
+		{
 			mFrame->AddLine(new VariablePropertyDialogOpacitySlider(this,mFrame));
 			mFrame->AddLine(new VariablePropertyDialogColorSelection(this,mFrame));
 		}
@@ -1227,6 +1230,14 @@ using namespace iggDialogDataExplorer_Private;
 
 
 iggDialogDataExplorer::iggDialogDataExplorer(iggMainWindow *parent) : iggDialog(parent,0U,iImageFactory::FindIcon("dataexp.png"),"Data Explorer","sr.gg.dd",2)
+{
+	mProvider = 0;
+
+	if(this->ImmediateConstruction()) this->CompleteConstruction();
+}
+
+
+void iggDialogDataExplorer::CompleteConstructionBody()
 {
 	iggFrame *box1, *box2, *tmp1, *tmp2;
 
@@ -1329,7 +1340,7 @@ iggDialogDataExplorer::iggDialogDataExplorer(iggMainWindow *parent) : iggDialog(
 
 iggDialogDataExplorer::~iggDialogDataExplorer()
 {
-	delete mProvider;
+	if(mProvider != 0) delete mProvider;
 }
 
 
