@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -234,6 +234,12 @@ iggDialogFileSetExplorer::iggDialogFileSetExplorer(iggMainWindow *parent) : iggD
 	mMustBeClosed = false;
 	mLoadAll = true;
 
+	if(this->ImmediateConstruction()) this->CompleteConstruction();
+}
+
+
+void iggDialogFileSetExplorer::CompleteConstructionBody()
+{
 	mView = new View(this,mFrame);
 	mFrame->AddLine(mView,3);
 	mFrame->AddLine(new LoadAllCheckBox(this,mFrame),(iggWidget *)0,new RefreshButton(this,mFrame));
@@ -255,11 +261,11 @@ void iggDialogFileSetExplorer::UpdateDialog()
 }
 
 
-void iggDialogFileSetExplorer::Show(bool s)
+void iggDialogFileSetExplorer::ShowBody(bool s)
 {
 	mMustBeClosed = false;
-	iggDialog::Show(s);
-	if(mMustBeClosed) iggDialog::Show(false);
+	iggDialog::ShowBody(s);
+	if(mMustBeClosed) iggDialog::ShowBody(false);
 }
 
 
