@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -43,7 +43,6 @@ public:
 
 	iggDialogFileSetExplorer(iggMainWindow *parent);
 
-	virtual void Show(bool s);
 	virtual void UpdateDialog();
 
 	void SetLoadAll(bool s){ mLoadAll = s; }
@@ -55,6 +54,9 @@ public:
 
 protected:
 
+	virtual void CompleteConstructionBody();
+	virtual void ShowBody(bool s);
+
 	bool mMustBeClosed, mLoadAll;
 	iggWidgetListView *mView;
 };
