@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -197,6 +197,12 @@ using namespace iggDialogHelp_Private;
 //  Main class
 //
 iggDialogHelp::iggDialogHelp(iggMainWindow *parent) : iggDialog(parent,0U,0,"Help","sr.gg.dh",2)
+{
+	if(this->ImmediateConstruction()) this->CompleteConstruction();
+}
+
+
+void iggDialogHelp::CompleteConstructionBody()
 {
 	HelpBrowser *hb = new HelpBrowser(this,mFrame);
 	TopicList *tc = new TopicList(hb,mFrame);
