@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -882,7 +882,14 @@ iggDialogImageComposer::iggDialogImageComposer(iggMainWindow *parent) : iggDialo
 {
 	mCurrentBackgroundWindow = -1;
 	mCurrentForegroundWindow = -1;
+	mArea = 0;
 
+	if(this->ImmediateConstruction()) this->CompleteConstruction();
+}
+
+
+void iggDialogImageComposer::CompleteConstructionBody()
+{
 	iggFrame *tmp, *tmp2;
 
 	tmp = new iggFrame(mFrame);
@@ -937,12 +944,12 @@ iggDialogImageComposer::iggDialogImageComposer(iggMainWindow *parent) : iggDialo
 	tmp->AddLine(b,2);
 	tmp->AddSpace(10);
 
-	tmp2 = new iggFrame(tmp,2);
+	tmp2 = new iggFrame(tmp,3);
 	wid = new iggWidgetKeySpinBox(0,100,"",0,iImageComposer::KeyBorderWidth(),tmp2);
 	wid->AddDependent(mArea);
 	wid->AddDependent(mLabel);
 	tmp2->AddLine(new iggWidgetTextArea("Border width  ",tmp2),wid);
-	iggWidgetKeyColorSelection *bc = new iggWidgetKeyColorSelection(iImageComposer::KeyBorderColor(),tmp2,true);
+	iggWidgetKeyColorSelection *bc = new iggWidgetKeyColorSelection(iImageComposer::KeyBorderColor(),tmp2);
 	bc->SetText("Set");
 	bc->AddDependent(mArea);
 	tmp2->AddLine(new iggWidgetTextArea("Border color  ",tmp2),bc);
@@ -954,10 +961,12 @@ iggDialogImageComposer::iggDialogImageComposer(iggMainWindow *parent) : iggDialo
 	wid->AddDependent(mArea);
 	wid->AddDependent(mLabel);
 	tmp2->AddLine(wid,2);
-	tmp2->SetColStretch(1,10);
+	tmp2->SetColStretch(1,3);
+	tmp2->SetColStretch(2,10);
 
 	tmp->AddLine(tmp2);
 	tmp->AddSpace(10);
+	tmp->SetColStretch(1,10);
 
 	//
 	//  Foreground page
@@ -982,7 +991,9 @@ iggDialogImageComposer::iggDialogImageComposer(iggMainWindow *parent) : iggDialo
 	mIndexHolders[1] = new iggWidgetKeySpinBox(0,100,"",0,iImageComposer::KeyForegroundWindowBorderWidth(),b,0);
 	mIndexHolders[1]->AddDependent(mArea);
 	b->AddLine(new iggWidgetTextArea("Border width",b),mIndexHolders[1]);
-	mIndexHolders[2] = new iggWidgetKeyColorSelection(iImageComposer::KeyForegroundWindowBorderColor(),b,true,0);
+	iggWidgetKeyColorSelection *cs = new iggWidgetKeyColorSelection(iImageComposer::KeyForegroundWindowBorderColor(),b,0);
+	cs->SetText("Set");
+	mIndexHolders[2] = cs;
 	mIndexHolders[2]->AddDependent(mArea);
 	b->AddLine(new iggWidgetTextArea("Border color",b),mIndexHolders[2]);
 	psb = new PseudoColorBox(false,this,b);
@@ -1080,6 +1091,14 @@ void iggDialogImageComposer::UpdateZooms()
 }
 
 
+iggWidget* iggDialogImageComposer::GetArea()
+{
+	this->CompleteConstruction();
+
+	return mArea; 
+}
+
+
 iImageComposer* iggDialogImageComposer::GetImageComposer() const
 {
 	return this->GetShell()->GetControlModule()->GetImageComposer();
