@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -57,10 +57,12 @@ public:
 
 	void UpdateView();
 	void UpdateZooms();
-	iggWidget* GetArea() const { return mArea; }
+	iggWidget* GetArea();
 
 protected:
 
+	virtual void CompleteConstructionBody();
+
 	int mCurrentBackgroundWindow, mCurrentForegroundWindow;
 	iggWidget *mArea, *mLabel, *mBackgroundWindowsList;
 
