@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -53,10 +53,9 @@ public:
 	void LoadData(const iDataInfo &info, const iString &filename, int mod);
 	void ReloadData(const iDataInfo &info);
 
-	virtual void Show(bool s);
-
 protected:
 
+	virtual void CompleteConstructionBody();
 	virtual bool CanBeClosed();
 
 	iggWidgetTextArea *mLabel;
