@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -146,6 +146,12 @@ using namespace iggDialogPerformanceMeter_Private;
 
 
 iggDialogPerformanceMeter::iggDialogPerformanceMeter(iggMainWindow *parent) : iggDialog(parent,0U,iImageFactory::FindIcon("perf.png"),"Performance Meter",0,7)
+{
+	if(this->ImmediateConstruction()) this->CompleteConstruction();
+}
+
+
+void iggDialogPerformanceMeter::CompleteConstructionBody()
 {
 	iggWidgetNumberDisplay *tm = new iggWidgetNumberDisplay("",mFrame);
 	tm->Display(iSystem::GetMemoryLimit(),1);
