@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -116,6 +116,12 @@ using namespace iggDialogPickerWindow_Private;
 
 
 iggDialogPickerWindow::iggDialogPickerWindow(iggMainWindow *parent) : iggDialog(parent,0U,iImageFactory::FindIcon("picks.png"),"Picker Window","sr.gg.dk",1)
+{
+	if(this->ImmediateConstruction()) this->CompleteConstruction();
+}
+
+
+void iggDialogPickerWindow::CompleteConstructionBody()
 {
 	mWaitFrame = new iggFrame(mFrame);
 	mWaitFrame->AddLine(new iggWidgetTextArea("Please wait, the data are being gathered...",mWaitFrame));
@@ -146,19 +152,21 @@ iggDialogPickerWindow::iggDialogPickerWindow(iggMainWindow *parent) : iggDialog(
 }
 
 
-void iggDialogPickerWindow::Show(bool s)
+void iggDialogPickerWindow::ShowBody(bool s)
 {
 	int i;
 	for(i=0; i<this->GetShell()->GetControlModule()->GetNumberOfViewModules(); i++)
 	{
 		this->GetShell()->GetControlModule()->GetViewModule(i)->GetPicker()->ShowPickedPoint(s);
 	}
-	iggDialog::Show(s);
+	iggDialog::ShowBody(s);
 }
 
 
 void iggDialogPickerWindow::CollectData(bool s)
 {
+	if(!mCompleteConstructionCalled) this->CompleteConstruction();
+
 	mWaitFrame->Show(s);
 	mInfoFrame->Show(!s);
 }
@@ -166,6 +174,8 @@ void iggDialogPickerWindow::CollectData(bool s)
 
 void iggDialogPickerWindow::DisplayData(const iPicker *picker)
 {
+	if(!mCompleteConstructionCalled) this->CompleteConstruction();
+
 	mInfo->Clear();
 
 	if(picker!=0 && !picker->GetObjectName().IsEmpty())
