@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -46,13 +46,14 @@ public:
 
 	iggDialogPickerWindow(iggMainWindow *parent);
 
-	virtual void Show(bool s);
-
 	void CollectData(bool s);
 	void DisplayData(const iPicker *picker);
 
 protected:
 
+	virtual void CompleteConstructionBody();
+	virtual void ShowBody(bool s);
+
 	iggFrame *mInfoFrame, *mWaitFrame;
 	iggWidgetTextBrowser *mInfo;
 };
