@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -86,6 +86,16 @@ iggDialogRenderingProgress::iggDialogRenderingProgress(iggMainWindow *parent) :
 	mBlockParent = true;  // no explicit blocking required, since it is a semi-modal dialog
 	mIsParentBlocked = false;
 
+	mCancelled = true;
+	mPreviousTime = 0.0;
+	mTimer = vtkTimerLog::New(); IERROR_ASSERT(mTimer);
+
+	if(this->ImmediateConstruction()) this->CompleteConstruction();
+}
+
+
+void iggDialogRenderingProgress::CompleteConstructionBody()
+{
 	iggFrame*tmp;
 
 	mFrame->AddLine(new iggWidgetTextArea("%bRendering the scene...",mFrame));
@@ -107,10 +117,6 @@ iggDialogRenderingProgress::iggDialogRenderingProgress(iggMainWindow *parent) :
 	mRemarkFrame = new iggFrame(mFrame);
 	mRemarkFrame->AddLine(new iggWidgetTextArea("Interrupting all processes...",mRemarkFrame));
 	mFrame->AddLine(mRemarkFrame);
-
-	mCancelled = true;
-	mPreviousTime = 0.0;
-	mTimer = vtkTimerLog::New(); IERROR_ASSERT(mTimer);
 }
 	
 
@@ -122,6 +128,8 @@ iggDialogRenderingProgress::~iggDialogRenderingProgress()
 
 void iggDialogRenderingProgress::Start(bool interactive)
 {
+	if(!mCompleteConstructionCalled) this->CompleteConstruction();
+
 	mTimer->StartTimer();
 	mCancelled = false;
 	mPreviousTime = 0.0;
