@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -49,6 +49,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggdialoghelp.h"
 #include "iggframetopparent.h"
 #include "iggmainwindow.h"
+#include "iggshell.h"
 #include "iggwidgetmisc.h"
 #include "iggwidgetotherbutton.h"
 #include "iggwidgettext.h"
@@ -277,7 +278,7 @@ namespace iggDialogScriptDebugger_Private
 
 		FindText(iggFrame *parent) : iggWidget(parent)
 		{
-			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,0,"Find:",0);
+			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,0,"Find:");
 			this->SetBaloonHelp("Type a string to find");
 		}
 
@@ -357,6 +358,14 @@ namespace iggDialogScriptDebugger_Private
 			mFrame->AddLine(cs);
 			mFrame->AddLine(wo);
 			mFrame->AddLine(bs);
+
+			this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
 		}
 	};
 
@@ -428,7 +437,7 @@ namespace iggDialogScriptDebugger_Private
 		{
 			mDebugger = d; 
 
-			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,true,0,"Delay",0);
+			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,true,0,"Delay");
 			mSubject->SetRange(0,10);
 			mSubject->SetValue(3);
 
@@ -538,8 +547,6 @@ using namespace iggDialogScriptDebugger_Private;
 //
 iggDialogScriptDebugger::iggDialogScriptDebugger(iggMainWindow *parent) : iggMenuWindow(parent), iScriptObserver(0)
 {
-	int i;
-
 	//
 	//  Create MenuSubject
 	//
@@ -551,8 +558,21 @@ iggDialogScriptDebugger::iggDialogScriptDebugger(iggMainWindow *parent) : iggMen
 	mCurIter = -1;
 	mNumIter = 0;
 	mDebugFlag = 1;
+	
+	mTimer = 0;
+	mFindDialog = 0;
+	mEditor = 0;
 
 	mFirstShow = true;
+	mCompleteConstructionCalled = false;
+
+	if(this->ImmediateConstruction()) this->CompleteConstruction();
+}
+
+
+void iggDialogScriptDebugger::CompleteConstructionBody()
+{
+	int i;
 
 	//
 	//  Top frame
@@ -628,9 +648,9 @@ iggDialogScriptDebugger::iggDialogScriptDebugger(iggMainWindow *parent) : iggMen
 
 iggDialogScriptDebugger::~iggDialogScriptDebugger()
 {
-	mTimer->Delete();
+	if(mTimer != 0) mTimer->Delete();
 	this->CheckModified();
-	delete mFindDialog;
+	if(mFindDialog != 0) delete mFindDialog;
 }
 
 
@@ -639,6 +659,12 @@ void iggDialogScriptDebugger::Show(bool s)
 	if(s && mFirstShow)
 	{
 		mFirstShow = false;
+
+		if(!mCompleteConstructionCalled)
+		{
+			this->CompleteConstruction();
+		}
+
 		int wg1[4], wg2[4];
 		this->GetMainWindow()->GetSubject()->GetWindowGeometry(wg1);
 		this->GetSubject()->GetWindowGeometry(wg2);
@@ -687,7 +713,6 @@ void iggDialogScriptDebugger::Debug(bool s)
 		this->GetAnimator()->SetDebugFlag(mDebugFlag); // make sure we are current
 		this->SetScript(this->GetAnimator()->GetScript());
 		mRunState = _RunStatePaused;
-		this->GetAnimator()->SetUseScript(true);
 		this->GetAnimator()->Start();
 		this->UpdateVariables();
 		mEditor->MarkLine(this->GetAnimator()->GetScript());
@@ -815,7 +840,7 @@ bool iggDialogScriptDebugger::CheckSyntax(bool silent)
 	iAnimatorScript *s = this->GetAnimator()->GetScript();
 	if(!s->Compile())
 	{
-		this->GetMainWindow()->PopupWindow(mGlobalFrame,iString("Syntax error: line ")+iString::FromNumber(s->GetThisLine()+1)+"\n"+s->GetErrorStatus()->Message(),PopupWindow::Error);
+		this->GetMainWindow()->PopupWindow(mGlobalFrame,iString("Syntax error: line ")+iString::FromNumber(s->GetErrorLine()+1)+"\n"+s->GetErrorStatus()->Message(),PopupWindow::Error);
 		mEditor->ShowError(s);
 		return false;
 	}
@@ -884,6 +909,8 @@ void iggDialogScriptDebugger::UpdateButtons()
 
 void iggDialogScriptDebugger::UpdateContents()
 {
+	if(!mCompleteConstructionCalled) return;
+
 	mGlobalFrame->UpdateWidget();
 	this->UpdateButtons();
 }
@@ -891,7 +918,7 @@ void iggDialogScriptDebugger::UpdateContents()
 
 void iggDialogScriptDebugger::CheckModified()
 {
-	if(mEditor->TextModified())
+	if(mEditor!=0 && mEditor->TextModified())
 	{
 		switch(mMainWindow->PopupWindow(mGlobalFrame,"The current script is not saved.",PopupWindow::Warning,"Save","Ignore")) 
 		{
@@ -960,7 +987,7 @@ void iggDialogScriptDebugger::LoadFromFile(const iString &filename)
 	this->SetContents(text);
 	mCurrentFileName = fn;
 
-	this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->SetScriptFileName(fn);
+	this->GetShell()->GetControlModule()->GetViewModule()->GetAnimator()->SetScriptFile(fn);
 }
 
 
@@ -1222,4 +1249,22 @@ void iggDialogScriptDebugger::OnMenuBody(int id, bool on)
 	IERROR_LOW("Invalid menu item id.");
 }
 
+
+bool iggDialogScriptDebugger::ImmediateConstruction() const
+{
+	return iRequiredCast<iggShell>(INFO,this->GetShell())->CheckCondition(iParameter::Condition::DisableDelayedInitialization);
+}
+
+
+void iggDialogScriptDebugger::CompleteConstruction()
+{
+	if(mCompleteConstructionCalled) return;
+
+	this->CompleteConstructionBody();
+	mCompleteConstructionCalled = true;
+#ifdef I_DEBUG
+	iConsole::PrintDebugMessage(iString("Completing delayed construction for element #")+iString::FromNumber(this->GetId()));
+#endif
+}
+
 #endif
