@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -71,6 +71,10 @@ public:
 
 protected:
 
+	bool ImmediateConstruction() const; 
+	void CompleteConstruction();
+	virtual void CompleteConstructionBody();
+
 	virtual void UpdateContents();
 
 	virtual void OnScriptStartBody();
@@ -93,6 +97,7 @@ protected:
 	iggWidgetListView *mVarView;
 	iggDialog *mFindDialog;
 
+	bool mCompleteConstructionCalled;
 	int mRunState, mCurIter, mNumIter, mDebugFlag;
 	float mDelayTime;
 	bool mDebugging, mAllowFrameStep, mInsideALine, mFirstShow;
