@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -38,6 +38,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "iggmainwindow.h"
 #include "iggrenderwindowobserver.h"
+#include "iggshell.h"
 #include "iggwidget.h"
 
 #include "ibgframesubject.h"
@@ -295,6 +296,12 @@ void iggFrame::Define(int cols, bool withsubject)
 }
 
 
+bool iggFrame::NeedsRedoLayout()
+{
+	return false;
+}
+
+
 void iggFrame::GetFrameGeometry(int wg[4]) const
 {
 	mSubject->GetFrameGeometry(wg);
@@ -424,6 +431,47 @@ void iggFrame::FlipThroughAllChildren()
 }
 
 
+//
+//  A frame with delayed construction.
+//
+iggFrameDC::iggFrameDC(iggFrameBase *parent, int cols) : iggFrame(parent,cols)
+{
+	mCompleteConstructionCalled = false;
+}
+
+
+bool iggFrameDC::ImmediateConstruction() const
+{
+	return iRequiredCast<iggShell>(INFO,this->GetShell())->CheckCondition(iParameter::Condition::DisableDelayedInitialization);
+}
+
+
+bool iggFrameDC::NeedsRedoLayout()
+{
+	if(mCompleteConstructionCalled)
+	{
+		return false;
+	}
+	else
+	{
+		this->CompleteConstruction();
+		return true;
+	}
+}
+
+
+void iggFrameDC::CompleteConstruction()
+{
+	if(mCompleteConstructionCalled) return;
+
+	this->CompleteConstructionBody();
+	mCompleteConstructionCalled = true;
+#ifdef I_DEBUG
+	iConsole::PrintDebugMessage(iString("Completing delayed construction for element #")+iString::FromNumber(this->GetId()));
+#endif
+}
+
+
 //
 //  FrameBook class
 //
