@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -211,7 +211,7 @@ namespace iggFrameRangeMapping_Private
 
 		HistogramSlider(iggFrame *parent) : iggWidget(parent)
 		{
-			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,true,0,"",0);
+			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,true,0,"");
 			mSubject->SetRange(-10,10);
 			mSubject->SetValue(0);
 
