@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -276,8 +276,9 @@ namespace iggMainWindow_Private
 	namespace ToolBar
 	{
 		const int OpenWindowsPage = 801;
-		const int MinimizeWindowsPage = 802;
-		const int MaximizeWindowsPage = 803;
+		const int MinimizeWindows = 802;
+		const int MaximizeWindows = 803;
+		const int MoveAllTogether = 804;
 
 		const int ShowSurface = 901;
 		const int ShowCrossSection = 902;
@@ -609,6 +610,11 @@ namespace iggMainWindow_Private
 	public:
 
 		DialogAbout(iggMainWindow *parent) : iggDialog(parent,DialogFlag::Modal,0,"About",0,3,"Ok")
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+		void CompleteConstructionBody()
 		{
 			int i, n;
 			iString s;
@@ -646,13 +652,12 @@ namespace iggMainWindow_Private
 			n = s.Contains(';');
 			for(i=0; i<n; i++) mFrame->AddLine(new iggWidgetTextArea(s.Section(";",i,i),mFrame),3);
 			mFrame->AddLine(new iggWidgetTextArea("",mFrame),3);
-			mFrame->AddLine(new iggWidgetTextArea("IFrIT is created and maintained by Nick Gnedin",mFrame),3);
 		}
 
-		virtual void Show(bool s)
+		virtual void ShowBody(bool s)
 		{
 			if(s) mFlipper->Start(); else mFlipper->Abort();
-			iggDialog::Show(s);
+			iggDialog::ShowBody(s);
 		}
 
 	protected:
@@ -667,16 +672,21 @@ namespace iggMainWindow_Private
 	public:
 
 		DialogDocking(iggMainWindow *parent) : iggDialog(parent,DialogFlag::Blocking|DialogFlag::NoTitleBar,0,"Docking...",0,3,0)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+		void CompleteConstructionBody()
 		{
 			mFlipper = new iggWidgetLogoFlipper(mFrame);
 			mFrame->AddLine(0,mFlipper);
 			mFrame->AddLine(new iggWidgetTextArea("%b%+Rearranging windows...",mFrame),3);
 		}
 
-		virtual void Show(bool s)
+		virtual void ShowBody(bool s)
 		{
 			if(s) mFlipper->Start(); else mFlipper->Abort();
-			iggDialog::Show(s);
+			iggDialog::ShowBody(s);
 		}
 
 	protected:
@@ -694,6 +704,11 @@ namespace iggMainWindow_Private
 	public:
 
 		AxesLabelsDialog(iggMainWindow *parent) : iggDialogAuto(parent,"Axes Labels",3)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+		void CompleteConstructionBody()
 		{
 			mFrame->AddLine(new iggWidgetKeyTextLineEdit(false,"X: Label",iViewModule::KeyAxesBoxLabels(),RenderMode::UseGlobal,mFrame,0),new iggWidgetKeyFloatLineEdit("Min",iViewModule::KeyAxesBoxRanges(),RenderMode::UseGlobal,mFrame,0),new iggWidgetKeyFloatLineEdit("Max",iViewModule::KeyAxesBoxRanges(),RenderMode::UseGlobal,mFrame,1));
 			mFrame->AddLine(new iggWidgetKeyTextLineEdit(false,"Y: Label",iViewModule::KeyAxesBoxLabels(),RenderMode::UseGlobal,mFrame,1),new iggWidgetKeyFloatLineEdit("Min",iViewModule::KeyAxesBoxRanges(),RenderMode::UseGlobal,mFrame,2),new iggWidgetKeyFloatLineEdit("Max",iViewModule::KeyAxesBoxRanges(),RenderMode::UseGlobal,mFrame,3));
@@ -777,6 +792,26 @@ namespace iggMainWindow_Private
 		iggFrame *mStartFrame;
 	};
 
+	class DebugHelperFlashAllDialogsButton : public iggWidgetSimpleButton
+	{
+
+	public:
+
+		DebugHelperFlashAllDialogsButton(iggFrame *parent) : iggWidgetSimpleButton("Flash all dialogs",parent)
+		{
+			mNeedsBaloonHelp = false;
+        }
+
+	protected:
+
+		virtual void Execute()
+		{
+			this->GetMainWindow()->Block(true);
+			iggDialog::FlashAllDialogs();
+			this->GetMainWindow()->Block(false);
+		}
+	};
+
 	class DebugHelperCreateUGButton : public iggWidgetSimpleButton
 	{
 
@@ -792,7 +827,7 @@ namespace iggMainWindow_Private
 		virtual void Execute()
 		{
 			this->GetMainWindow()->Block(true);
-			iHelpFactory::CreateUserGuide(iHelpFactory::_Publish);
+			iHelpFactory::CreateUserGuide();
 			this->GetMainWindow()->Block(false);
 		}
 	};
@@ -838,13 +873,25 @@ namespace iggMainWindow_Private
 	public:
 
 		DebugHelperDialog(iggFrame *sf, iggMainWindow *parent) : iggDialog(parent,0U,0,"Debug Helper",0,1)
+		{
+			mStartFrame = sf;
+
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		void CompleteConstructionBody()
 		{
 			mFrame->AddLine(new DebugHelperParallelRadioBox(mFrame));
 			mFrame->AddLine(new DebugHelperEmphasizeAllWidgetsCheckBox(mFrame));
 			mFrame->AddLine(new DebugHelperEmphasizeUnderCursorCheckBox(mFrame));
-			mFrame->AddLine(new DebugHelperFlipAllPagesButton(sf,mFrame));
+			mFrame->AddLine(new DebugHelperFlipAllPagesButton(mStartFrame,mFrame));
+			mFrame->AddLine(new DebugHelperFlashAllDialogsButton(mFrame));
 			mFrame->AddLine(new DebugHelperCreateUGButton(mFrame));
 		}
+
+		iggFrame *mStartFrame;
 	};
 #endif
 };
@@ -862,7 +909,7 @@ using namespace iggMainWindow_Private;
 //
 iggMainWindow::iggMainWindow(iShell *shell) : iObject("MainWindow"), iggMenuWindow(shell), mReloadDataInfo(new iDataInfo), mEraseDataInfo(new iDataInfo)
 {
-	mInitialized = mDocked = mDoNotOfferToReload = mDetailLoadedDataInfo = mAllowPrePopulateToolBar = false;
+	mInitialized = mDocked = mDoNotOfferToReload = mDetailLoadedDataInfo = mAllowPrePopulateToolBar = mMoveTogether = false;
 	mInteractorHelp = mToolTips = mOptionsAreGlobal = mWindowUnderFocusCurrent = mAutoRender = true;
 	mIdiosyncratic = true;
 
@@ -958,7 +1005,6 @@ void iggMainWindow::StartInitialization()
 	//
 	iggShell *s = iRequiredCast<iggShell>(INFO,this->GetShell());
 	
-	if(s->IsDesktopSmall(true)) mLog->Show(false);
 	if(s->CheckCondition(iParameter::Condition::SlowRemoteConnection))
 	{
 		ibgRenderWindowSubject::RenderOnFocus = true;
@@ -991,7 +1037,6 @@ void iggMainWindow::StartInitialization()
 	Book *book = new Book(tmpf);
 	mBook = book;
 
-//	iggPage::SetDelayedConstruction(false);
 	mViewPage = new iggPageView(mBook);
 	mDataPage = new iggPageData(mBook);
 	
@@ -1001,7 +1046,6 @@ void iggMainWindow::StartInitialization()
 	mPages[3] = mParticlesPage = new iggPageParticles(mBook);
 	mPages[4] = new iggPageVectorField(mBook);
 	mPages[5] = new iggPageTensorField(mBook);
-//	iggPage::SetDelayedConstruction(true);
 
 	iParticlesViewSubject::UseFullState(false); // optimization, since we use iParticleGroup keys
 
@@ -1033,23 +1077,33 @@ void iggMainWindow::StartInitialization()
 	mBaseFrame->ShowLayer(0);
 
 	mGlobalFrame->AddLine(mBaseFrame,3);
-	iggFrame *tmp1 = new iggFrame(mGlobalFrame,2);
-	iggFrame *tmp2 = new iggFrame(mGlobalFrame);
-	tmp1->AddSpace(10);
+
+	iggFrameFlip *flip1 = new iggFrameFlip(mGlobalFrame,false);
+	iggFrame *tmp1 = new iggFrame(flip1,3);
 	mRenderButton = new RenderButton(tmp1);
 	mRenderButton->Show(!mAutoRender);
 	tmp1->SetPadding(true);
 	tmp1->AddLine(new ImageButton(tmp1),mRenderButton);
-	tmp1->AddSpace(10);
-	mDataTypeFrame = new iggFrameFlip(tmp2,false);
-	tmp2->AddSpace(10);
-	tmp2->AddLine(mDataTypeFrame);
-	tmp2->AddSpace(10);
-	mGlobalFrame->AddLine(tmp1,new iggWidgetTextArea("",mGlobalFrame),tmp2);
+	tmp1->SetColStretch(2,10);
+	flip1->AddLayer(tmp1);
+	flip1->ShowLayer(0);
+
+	mDataTypeFrame = new iggFrameFlip(mGlobalFrame,false);
+
+	//mGlobalFrame->AddLine(tmp1,new iggWidgetTextArea("",mGlobalFrame),tmp2);
+	mGlobalFrame->AddLine(flip1,(iggWidget *)0,mDataTypeFrame);
 	mGlobalFrame->AddLine(mLog,3);
-	mGlobalFrame->SetRowStretch(0,0);
+	mGlobalFrame->SetRowStretch(0,1);
 	mGlobalFrame->SetRowStretch(1,0);
-	mGlobalFrame->SetRowStretch(2,1);
+	if(s->IsDesktopSmall(true))
+	{
+		mLog->Show(false);
+		mGlobalFrame->SetRowStretch(2,0);
+	}
+	else
+	{
+		mGlobalFrame->SetRowStretch(2,10);
+	}
 
 	book->PolishPages();
 
@@ -1523,7 +1577,8 @@ void iggMainWindow::WriteToLog(const iString &prefix, const iString &message, co
 		mLog->AppendTextLine(prefix,message,color);
 		if(mLog->GetNumberOfLines() > 1000)
 		{
-			while(mLog->GetNumberOfLines() > 700) mLog->RemoveLine(0);
+			iString text = mLog->GetText();
+			mLog->SetText(text.Part(text.Length()/5));
 		}
 	}
 }
@@ -1531,11 +1586,14 @@ void iggMainWindow::WriteToLog(const iString &prefix, const iString &message, co
 
 void iggMainWindow::WriteToLog(const iString &message)
 {
-	mLog->AppendTextLine("\t",message);
-
-	if(mLog->GetNumberOfLines() > 1000)
+	if(mLog != 0)
 	{
-		while(mLog->GetNumberOfLines() > 700) mLog->RemoveLine(0);
+		mLog->AppendTextLine("\t",message);
+		if(mLog->GetNumberOfLines() > 1000)
+		{
+			iString text = mLog->GetText();
+			mLog->SetText(text.Part(text.Length()/5));
+		}
 	}
 }
 
@@ -1549,8 +1607,14 @@ void iggMainWindow::ClearLog()
 void iggMainWindow::ShowLog(bool s)
 {
 	mLog->Show(s);
-	if(!s)
+	if(s)
 	{
+		mGlobalFrame->SetRowStretch(2,10);
+		this->ProcessEvents();
+	}
+	else
+	{
+		mGlobalFrame->SetRowStretch(2,0);
 		this->ProcessEvents();
 
 		int wg[4];
@@ -2008,7 +2072,7 @@ void iggMainWindow::DisplayWindowsAsWindows()
 }
 
 
-void iggMainWindow::MoveWindows(int pos[2], bool all)
+void iggMainWindow::MoveWindows(int pos[2])
 {
 	//
 	//  We must make this function safe against multiple concurrent calls.
@@ -2020,9 +2084,9 @@ void iggMainWindow::MoveWindows(int pos[2], bool all)
 	if(mInMove) return; // ignore rapidly arriving events
 	mInMove = true;
 
-	int wg[4];
-	if(all && mInitialized && !mDocked) // do not move the first render window
+	if(mMoveTogether && mInitialized && !mDocked) // do not move the first render window
 	{
+		int wg[4];
 		int i, dp[2];
 		dp[0] = pos[0] - mPrevPos[0];
 		dp[1] = pos[1] - mPrevPos[1];
@@ -2051,7 +2115,7 @@ void iggMainWindow::MoveWindows(int pos[2], bool all)
 	//
 	if(mNextPos[0]!=pos[0] || mNextPos[1]!=pos[1])
 	{
-		this->MoveWindows(mNextPos,all);
+		this->MoveWindows(mNextPos);
 	}
 }
 
@@ -2115,7 +2179,7 @@ void iggMainWindow::BuildMenus()
 	
 		this->GetSubject()->BeginMenu("Automatic Dialogs",false);
 		{
-			this->GetSubject()->AddMenuItem(Menu::Dialog::AutoBlock,"Do &not launch automatically",0,"",true,iggDialogAuto::mBlockShowing);
+			this->GetSubject()->AddMenuItem(Menu::Dialog::AutoBlock,"Do not launch automatically",0,"",true,iggDialogAuto::mBlockShowing);
 			int i;
 			iString ws;
 			for(i=0; i<mAutoDialogList.Size() && i<Menu::Dialog::AutoEnd-Menu::Dialog::AutoBegin; i++)
@@ -2130,7 +2194,7 @@ void iggMainWindow::BuildMenus()
 		if(mDialogParallelController!=0 && this->GetSubject()->GetShell()->GetControlModule()->GetParallelManager()->GetMaxNumberOfProcessors()>1) this->GetSubject()->AddMenuItem(Menu::Dialog::ParallelController,"Parallel &Controller",iImageFactory::FindIcon("parallel.png"),"Ctrl+C",false,false);
 		if(mDialogDataExplorer != 0) this->GetSubject()->AddMenuItem(Menu::Dialog::DataExplorer,"&Data Explorer",iImageFactory::FindIcon("dataexp.png"),"Ctrl+D",false,false);
 		if(mDialogImageComposer != 0) this->GetSubject()->AddMenuItem(Menu::Dialog::ImageComposer,"&Image Composer",iImageFactory::FindIcon("imcomp.png"),"Ctrl+I",false,false);
-		if(mDialogCommandLine != 0) this->GetSubject()->AddMenuItem(Menu::Dialog::CommandLine,"&Command Interpreter",iImageFactory::FindIcon("comline.png"),"Ctrl+N",false,false);
+		if(mDialogCommandLine != 0) this->GetSubject()->AddMenuItem(Menu::Dialog::CommandLine,"Command I&nterpreter",iImageFactory::FindIcon("comline.png"),"Ctrl+N",false,false);
 		mExtensionWindow->PopulateGlobalDialogMenu();
 	}
 	this->GetSubject()->EndMenu();
@@ -2330,14 +2394,9 @@ void iggMainWindow::BuildMenus()
 	mExtensionWindow->PopulateShowToolBar();
 	this->GetSubject()->AddToolBarSeparator();
 	this->GetSubject()->AddToolBarButton(ToolBar::OpenWindowsPage,"Switch to page with multiple windows controls",iImageFactory::FindIcon("wins.png"),false);
-	this->GetSubject()->AddToolBarButton(ToolBar::MinimizeWindowsPage,"Minimize all windows",iImageFactory::FindIcon("minimize.png"),false);
-	this->GetSubject()->AddToolBarButton(ToolBar::MaximizeWindowsPage,"Restore all windows to normal size",iImageFactory::FindIcon("maximize.png"),false);
-
-	this->GetSubject()->AddToolBarSeparator();
-	if(mDialogPickerWindow != 0) this->GetSubject()->AddToolBarButton(Menu::Dialog::PickerWindow,"Open picker window");
-	if(mDialogFileSetExplorer != 0) this->GetSubject()->AddToolBarButton(Menu::Dialog::FileSetExplorer,"Open file set explorer window");
-	if(mDialogDataExplorer != 0) this->GetSubject()->AddToolBarButton(Menu::Dialog::DataExplorer,"Open data explorer window");
-	if(mDialogImageComposer != 0) this->GetSubject()->AddToolBarButton(Menu::Dialog::ImageComposer,"Open image composer window");
+	this->GetSubject()->AddToolBarButton(ToolBar::MinimizeWindows,"Minimize all windows",iImageFactory::FindIcon("minimize.png"),false);
+	this->GetSubject()->AddToolBarButton(ToolBar::MaximizeWindows,"Restore all windows to normal size",iImageFactory::FindIcon("maximize.png"),false);
+	this->GetSubject()->AddToolBarButton(ToolBar::MoveAllTogether,"Move all windows together",iImageFactory::FindIcon("together.png"),true);
 }
 
 
@@ -2501,7 +2560,7 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 			{
 				if(id>=Menu::Dialog::AutoBegin && id<Menu::Dialog::AutoBegin+mAutoDialogList.Size())
 				{
-					mAutoDialogList[id-Menu::Dialog::AutoBegin]->ForceShow(true);
+					mAutoDialogList[id-Menu::Dialog::AutoBegin]->ForceShow(on);
 				}
 				else IERROR_LOW("Invalid menu item id.");
 			}
@@ -2979,17 +3038,22 @@ void iggMainWindow::OnMenuBody(int id, bool on)
 				mViewPage->GetWindowListDialog()->Show(true);
 				break;
 			}
-		case ToolBar::MinimizeWindowsPage:
+		case ToolBar::MinimizeWindows:
 			{
 				this->DisplayWindowsAsIcons();
 				this->GetSubject()->GetHelper()->ShowAsIcon();
 				break;
 			}
-		case ToolBar::MaximizeWindowsPage:
+		case ToolBar::MaximizeWindows:
 			{
 				this->DisplayWindowsAsWindows();
 				break;
 			}
+		case ToolBar::MoveAllTogether:
+			{
+				mMoveTogether = on;
+				break;
+			}
 		case ToolBar::ShowSurface:
 			{
 				this->GetShell()->GetControlModule()->Show(iSurfaceViewSubject::Type(),on,true);
