@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -215,7 +215,7 @@ public:
 	//
 	void DisplayWindowsAsIcons();
 	void DisplayWindowsAsWindows();
-	void MoveWindows(int pos[2], bool all);
+	void MoveWindows(int pos[2]);
 
 	inline bool IsDocked() const { return mDocked; }
 	inline bool IsAutoRender() const { return mAutoRender; }
@@ -309,7 +309,7 @@ private:
 	int mCurrentTheme, mBlockLevel;
 	iPointerArray<ibgWindowSubject> mWindowList;
 	iggWidgetProgressBar *mProgressBar;
-	bool mDocked, mInteractorHelp, mToolTips, mOptionsAreGlobal, mWindowUnderFocusCurrent, mDetailLoadedDataInfo, mAutoRender;
+	bool mDocked, mInteractorHelp, mToolTips, mOptionsAreGlobal, mWindowUnderFocusCurrent, mDetailLoadedDataInfo, mAutoRender, mMoveTogether;
 	bool mIdiosyncratic, mDoNotOfferToReload, mInitialized, mInMove, mTwoSubjectsAreTheSame, mAllowPrePopulateToolBar;
 	iDataInfo *mReloadDataInfo, *mEraseDataInfo;
 	iString mStateFileName;
