@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -253,7 +253,7 @@ namespace iggPageCrossSection_Private
 		{
 			mButton = button;
 
-			mSubject = iggSubjectFactory::CreateWidgetSpinBoxSubject(this,2,1000,"the box in",1);
+			mSubject = iggSubjectFactory::CreateWidgetSpinBoxSubject(this,2,1000," the box in ",1);
 			mSubject->SetValue(10);
 
 			this->SetBaloonHelp("Number of steps to scan the box in","Set the number of steps to scan the box with a cross section in.");
@@ -294,6 +294,212 @@ namespace iggPageCrossSection_Private
 			this->GetShell()->GetControlModule()->GetViewModule()->Render();
 		}
 	};
+
+
+	//
+	//  Main page
+	// ************************************************
+	//
+	class MainPage : public iggFrameDC
+	{
+
+	public:
+	
+		MainPage(iggFrameBase *parent, iggDataTypeProvider *provider) : iggFrameDC(parent,3), mProvider(provider), mSlider(0)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+		PositionSlider* Slider() const { return mSlider; }
+
+	protected:
+
+		iggDataTypeProvider *mProvider;
+		PositionSlider *mSlider;
+
+		virtual void CompleteConstructionBody()
+		{
+			//
+			//  Show
+			//
+			iggWidget *show = new iggWidgetShowButton(iCrossSectionViewSubject::Type(),this);
+			iggFrameCurrentInstance *ci1 = new iggFrameCurrentInstance(false,"Instance","Instance",iViewModule::KeyCrossSectionCurrent(),iViewModule::KeyCrossSectionMax(),this);
+			ci1->AddDependent(this);
+			this->AddLine(show,static_cast<iggWidget*>(0),ci1);
+			this->AddSpace(2);
+			//
+			//  Paint with and Direction
+			//
+			iggFrame *pf = new iggFrame(this,2);
+			iggFrameDataVariableList *pl = new iggFrameDataVariableList(mProvider,"Paint with...",iCrossSectionViewSubject::KeyVar(),0,pf,0);
+			pl->Complete();
+			pl->AddDependent(show);
+			iggWidgetKeyRadioBox *cd = new iggWidgetKeyRadioBox(1,"Direction",0,iCrossSectionViewSubject::KeyDir(),pf);
+			cd->InsertItem("X");
+			cd->InsertItem("Y");
+			cd->InsertItem("Z");
+			pf->AddLine(pl,cd);
+			this->AddLine(pf);
+			this->AddSpace(2);
+			//
+			//  Method
+			//
+			iggFrame *mf = new iggFrame(this,2);
+			iggWidgetKeyRadioBox *cm = new iggWidgetKeyRadioBox(1,"Method",0,iCrossSectionViewSubject::KeyMethod(),mf);
+			cm->InsertItem("Polygons");
+			cm->InsertItem("Textures");
+			mf->AddLine(cm,new iggWidgetKeyCheckBox("Interpolate data",iCrossSectionViewSubject::KeyInterpolateData(),mf));
+			this->AddLine(mf);
+			this->AddSpace(10);
+			//
+			//  Position
+			//
+			mSlider = new PositionSlider(this);
+			DownsampleCheckBox *dc = new DownsampleCheckBox(this);
+			mSlider->SetDownsampleBuddy(dc);
+			this->AddLine(mSlider,3);
+			this->AddLine(dc);
+
+			this->AddSpace(2);
+			this->AddLine(new iggFrameAttachPosition(mSlider,iCrossSectionViewSubject::KeyAttachToMarker(),"",this,true),1);
+			this->AddLine(new OrthogonalizeViewButton(this));
+
+			this->AddSpace(10);
+
+			this->SetColStretch(1,10);
+			this->SetColStretch(2,5);
+		}
+	};
+
+
+	//
+	//  Paint page
+	// ************************************************
+	//
+	class PaintPage : public iggFrameDC
+	{
+
+	public:
+	
+		PaintPage(iggFrameBase *parent) : iggFrameDC(parent,1)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
+			const iImage *icon = iImageFactory::FindIcon("xsec.png");
+
+			//
+			//  Book
+			//
+			iggFrameBook *pb = new iggFrameBook(this);
+			this->AddLine(pb);
+			//
+			//  Palette page
+			//
+			iggFrame *pbpage0 = new iggFrame(pb,2);
+			pb->AddPage("Palette",icon,pbpage0);
+			{
+				iggFramePaletteSelection *ps = new iggFramePaletteSelection(false,iCrossSectionViewSubject::KeyPalette(),pbpage0,0);
+				pbpage0->AddLine(ps);
+				pbpage0->AddSpace(20);
+
+				pbpage0->SetColStretch(0,10);
+				pbpage0->SetColStretch(1,3);
+			}
+			//
+			//  Material page
+			//
+			iggFrame *pbpage1 = new iggFrame(pb,2);
+			pb->AddPage("Material",icon,pbpage1);
+			{
+				iggFrameMaterialProperties *mp = new iggFrameMaterialProperties(true,true,iCrossSectionViewSubject::Type(),pbpage1);
+				pbpage1->AddLine(mp);
+
+				pbpage1->AddSpace(10);
+				pbpage1->SetColStretch(0,10);
+				pbpage1->SetColStretch(1,3);
+			}
+		}
+	};
+
+	//
+	//  Instances page
+	// ************************************************
+	//
+	class InstancesPage : public iggFrameDC
+	{
+
+	public:
+	
+		InstancesPage(iggFrameBase *parent) : iggFrameDC(parent,3)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
+			//
+			//  Instance #
+			//
+			iggFrameCurrentInstance *ci2 = new iggFrameCurrentInstance(false,"Instance","Instance",iViewModule::KeyCrossSectionCurrent(),iViewModule::KeyCrossSectionMax(),this);
+			ci2->AddDependent(this);
+			this->AddLine(ci2);
+			this->AddSpace(2);
+			//
+			//  Color
+			//
+			this->AddLine(new iggFrameCreateDeleteButton(this,iCrossSectionViewSubject::Type(),true,"instance",this));
+			this->AddSpace(10);
+
+			this->SetColStretch(2,10);
+		}
+	};
+
+	//
+	//  Special page
+	// ************************************************
+	//
+	class SpecialPage : public iggFrameDC
+	{
+
+	public:
+	
+		SpecialPage(iggFrameBase *parent, MainPage *p) : iggFrameDC(parent,2), mMainPage(p)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		MainPage *mMainPage;
+
+		virtual void CompleteConstructionBody()
+		{
+			iggFrame *pf = new iggFrame(this,3);
+			ScanBoxButton *sb = new ScanBoxButton(pf);
+			sb->SetBuddy(mMainPage->Slider());
+			pf->AddLine(sb,new ScanDurationSpinBox(sb,pf),new iggWidgetTextArea("steps",pf));
+			this->AddLine(pf);
+			this->AddSpace(2);
+
+			pf = new iggFrame("Place cross-section at...",this,2);
+			pf->AddLine(new iggWidgetTextArea("Minimum of the data",pf),new iggWidgetKeyExecIntButton(0,"Go",iCrossSectionViewSubject::KeySpecialLocation(),pf));
+			pf->AddLine(new iggWidgetTextArea("Maximum of the data",pf),new iggWidgetKeyExecIntButton(1,"Go",iCrossSectionViewSubject::KeySpecialLocation(),pf));
+			pf->AddLine(new iggWidgetTextArea("Center of the box",pf),new iggWidgetKeyExecIntButton(3,"Go",iCrossSectionViewSubject::KeySpecialLocation(),pf));
+			pf->AddLine(new iggWidgetTextArea("Lower 1/4 of the box",pf),new iggWidgetKeyExecIntButton(2,"Go",iCrossSectionViewSubject::KeySpecialLocation(),pf));
+			pf->AddLine(new iggWidgetTextArea("Upper 1/4 of the box",pf),new iggWidgetKeyExecIntButton(4,"Go",iCrossSectionViewSubject::KeySpecialLocation(),pf));
+			this->AddLine(pf);
+
+			this->AddSpace(10);
+			this->SetColStretch(1,10);
+		}
+	};
 };
 
 
@@ -308,140 +514,29 @@ iggPageCrossSection::iggPageCrossSection(iggFrameBase *parent) : iggPageObject(p
 	//  Main page
 	// ************************************************
 	//
-	iggFrame *page0 = new iggFrame(mBook,3);
+	MainPage *page0 = new MainPage(mBook,mProvider);
 	mBook->AddPage("Main",icon,page0);
-	//
-	//  Show
-	//
-	iggWidget *show = new iggWidgetShowButton(iCrossSectionViewSubject::Type(),page0);
-	iggFrameCurrentInstance *ci1 = new iggFrameCurrentInstance(false,"Instance","Instance",iViewModule::KeyCrossSectionCurrent(),iViewModule::KeyCrossSectionMax(),page0);
-	ci1->AddDependent(this);
-	page0->AddLine(show,static_cast<iggWidget*>(0),ci1);
-	page0->AddSpace(2);
-	//
-	//  Paint with and Direction
-	//
-	iggFrame *pf = new iggFrame(page0,2);
-	iggFrameDataVariableList *pl = new iggFrameDataVariableList(mProvider,"Paint with...",iCrossSectionViewSubject::KeyVar(),0,pf,0);
-	pl->Complete();
-	pl->AddDependent(show);
-	iggWidgetKeyRadioBox *cd = new iggWidgetKeyRadioBox(1,"Direction",0,iCrossSectionViewSubject::KeyDir(),pf);
-	cd->InsertItem("X");
-	cd->InsertItem("Y");
-	cd->InsertItem("Z");
-	pf->AddLine(pl,cd);
-	page0->AddLine(pf);
-	page0->AddSpace(2);
-	//
-	//  Method
-	//
-	iggFrame *mf = new iggFrame(page0,2);
-	iggWidgetKeyRadioBox *cm = new iggWidgetKeyRadioBox(1,"Method",0,iCrossSectionViewSubject::KeyMethod(),mf);
-	cm->InsertItem("Polygons");
-	cm->InsertItem("Textures");
-	mf->AddLine(cm,new iggWidgetKeyCheckBox("Interpolate data",iCrossSectionViewSubject::KeyInterpolateData(),mf));
-	page0->AddLine(mf);
-	page0->AddSpace(10);
-	//
-	//  Position
-	//
-	PositionSlider *cp = new PositionSlider(page0);
-	DownsampleCheckBox *dc = new DownsampleCheckBox(page0);
-	cp->SetDownsampleBuddy(dc);
-	page0->AddLine(cp,2);
-	page0->AddLine(dc);
-
-	page0->AddSpace(2);
-	page0->AddLine(new iggFrameAttachPosition(cp,iCrossSectionViewSubject::KeyAttachToMarker(),"",page0,true),1);
-	page0->AddLine(new OrthogonalizeViewButton(page0));
-
-	page0->AddSpace(10);
-
-	page0->SetColStretch(1,10);
-	page0->SetColStretch(2,5);
 
 	//
 	//  Paint page
 	// ************************************************
 	//
-	iggFrame *page1 = new iggFrame(mBook,1);
+	PaintPage *page1 = new PaintPage(mBook);
 	mBook->AddPage("Paint",icon,page1);
-	//
-	//  Book
-	//
-	iggFrameBook *pb = new iggFrameBook(page1);
-	page1->AddLine(pb);
-	//
-	//  Palette page
-	//
-	iggFrame *pbpage0 = new iggFrame(pb,2);
-	pb->AddPage("Palette",icon,pbpage0);
-
-	iggFramePaletteSelection *ps = new iggFramePaletteSelection(false,iCrossSectionViewSubject::KeyPalette(),pbpage0,0);
-	pbpage0->AddLine(ps);
-	pbpage0->AddSpace(20);
-
-	pbpage0->SetColStretch(0,10);
-	pbpage0->SetColStretch(1,3);
-
-	//
-	//  Material page
-	//
-	iggFrame *pbpage1 = new iggFrame(pb,2);
-	pb->AddPage("Material",icon,pbpage1);
-
-	iggFrameMaterialProperties *mp = new iggFrameMaterialProperties(true,true,iCrossSectionViewSubject::Type(),pbpage1);
-	pbpage1->AddLine(mp);
-
-	pbpage1->AddSpace(10);
-	pbpage1->SetColStretch(0,10);
-	pbpage1->SetColStretch(1,3);
 
 	//
 	//  Instances page
 	// ************************************************
 	//
-	iggFrame *page2 = new iggFrame(mBook,3);
+	InstancesPage *page2 = new InstancesPage(mBook);
 	mBook->AddPage("Instances",icon,page2);
-	//
-	//  Instance #
-	//
-	iggFrameCurrentInstance *ci2 = new iggFrameCurrentInstance(false,"Instance","Instance",iViewModule::KeyCrossSectionCurrent(),iViewModule::KeyCrossSectionMax(),page2);
-	ci2->AddDependent(this);
-	page2->AddLine(ci2);
-	page2->AddSpace(2);
-	//
-	//  Color
-	//
-	page2->AddLine(new iggFrameCreateDeleteButton(this,iCrossSectionViewSubject::Type(),true,"instance",page2));
-	page2->AddSpace(10);
-
-	page2->SetColStretch(2,10);
 
 	//
 	//  Special page
 	// ************************************************
 	//
-	iggFrame *page3 = new iggFrame(mBook,2);
+	SpecialPage *page3 = new SpecialPage(mBook,page0);
 	mBook->AddPage("Special",icon,page3);
-	
-	pf = new iggFrame(page3,3);
-	ScanBoxButton *sb = new ScanBoxButton(pf);
-	sb->SetBuddy(cp);
-	pf->AddLine(sb,new ScanDurationSpinBox(sb,pf),new iggWidgetTextArea("steps",pf));
-	page3->AddLine(pf);
-	page3->AddSpace(2);
-
-	pf = new iggFrame("Place cross-section at...",page3,2);
-	pf->AddLine(new iggWidgetTextArea("Minimum of the data",pf),new iggWidgetKeyExecIntButton(0,"Go",iCrossSectionViewSubject::KeySpecialLocation(),pf));
-	pf->AddLine(new iggWidgetTextArea("Maximum of the data",pf),new iggWidgetKeyExecIntButton(1,"Go",iCrossSectionViewSubject::KeySpecialLocation(),pf));
-	pf->AddLine(new iggWidgetTextArea("Center of the box",pf),new iggWidgetKeyExecIntButton(3,"Go",iCrossSectionViewSubject::KeySpecialLocation(),pf));
-	pf->AddLine(new iggWidgetTextArea("Lower 1/4 of the box",pf),new iggWidgetKeyExecIntButton(2,"Go",iCrossSectionViewSubject::KeySpecialLocation(),pf));
-	pf->AddLine(new iggWidgetTextArea("Upper 1/4 of the box",pf),new iggWidgetKeyExecIntButton(4,"Go",iCrossSectionViewSubject::KeySpecialLocation(),pf));
-	page3->AddLine(pf);
-
-	page3->AddSpace(10);
-	page3->SetColStretch(1,10);
 }
 
 #endif
