@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -291,7 +291,7 @@ namespace iggPageData_Private
 				mMin = lim->GetMin(mIndex);
 				mMax = lim->GetMax(mIndex);
 				mStretch = lim->GetStretch(mIndex);
-				if(lim->GetClass(mIndex) > 999) this->SetStep(1.0f);
+				if(lim->GetRank(mIndex) == -1) this->SetStep(1.0f);
 				mResolution = this->ComputeResolution();
 				this->SetRange(0,mResolution);
 				this->iggWidgetKeyFloatSlider::UpdateWidgetBody();
@@ -317,9 +317,13 @@ namespace iggPageData_Private
 			vls1->AddBuddy(vls2);
 			this->AddLine(vls1,2,new LimitsExpandButton(true,true,mPage,this,index),1,new LimitsExpandButton(true,false,mPage,this,index),1);
 			this->AddLine(vls2,2,new LimitsExpandButton(false,false,mPage,this,index),1,new LimitsExpandButton(false,true,mPage,this,index),1);
-			mStretchBox = new LimitsStretchComboBox(mPage,this,index);
-			this->AddLine(mStretchBox,1,new LimitsNameEdit(mPage,this,index),3);
-			this->SetColStretch(1,10);
+			iggFrame *f = new iggFrame(this,3);
+			mStretchBox = new LimitsStretchComboBox(mPage,f,index);
+			f->AddLine(new LimitsNameEdit(mPage,f,index),(iggWidget *)0,mStretchBox);
+			f->SetColStretch(0,5);
+			f->SetColStretch(1,1);
+			this->AddLine(f,4);
+			this->SetColStretch(0,5);
 		}
 
 	protected:
@@ -369,7 +373,7 @@ namespace iggPageData_Private
 		
 	public:
 		
-		LimitsFrameSet(const iggPageData *page, iggFrame *parent) : iggFrameScroll(parent,false), mPage(page)
+		LimitsFrameSet(const iggPageData *page, iggFrame *parent) : iggFrameScroll(parent,true), mPage(page)
 		{
 			mNeedsBaloonHelp = false;
 		}
@@ -558,7 +562,7 @@ namespace iggPageData_Private
 
 		CalculatorLineEdit(iggFrame *parent) : iggWidget(parent)
 		{
-			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,0,"%bFunction:",0);
+			mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,0,"%bFunction:");
 			mSubject->SetEditable(false);
 
 			mNeedsBaloonHelp = false;
@@ -663,6 +667,11 @@ namespace iggPageData_Private
 		{
 			mLineEdit = le;
 
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+		void CompleteConstructionBody()
+		{
 			mCalculatorLineEdit = new CalculatorLineEdit(mFrame);
 			mFrame->AddLine(mCalculatorLineEdit,2);
 
@@ -734,7 +743,7 @@ namespace iggPageData_Private
 			mFrame->AddLine(f3,f4);
 		}
 
-		virtual void Show(bool s)
+		virtual void ShowBody(bool s)
 		{
 			if(s)
 			{
@@ -743,7 +752,7 @@ namespace iggPageData_Private
 				mCalculatorLineEdit->SetText(line);
 			}
 			
-			iggDialog::Show(s);
+			iggDialog::ShowBody(s);
 		}
 
 		virtual const iString& GetToolTip() const
@@ -851,40 +860,117 @@ namespace iggPageData_Private
 
 		iggDataTypeProvider *mProvider;
 	};
-};
 
 
-using namespace iggPageData_Private;
+	//
+	//  Shift page
+	//
+	class CommonShiftPage : public iggFrameDC
+	{
+
+	public:
+	
+		CommonShiftPage(iggFrameBase *parent) : iggFrameDC(parent,2)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
+			iggFrame *sh = new iggFrame(this);
+			sh->AddLine(new ShiftingSlider("%bX",iDataReader::KeyShiftData(),sh,0));
+			sh->AddLine(new ShiftingSlider("%bY",iDataReader::KeyShiftData(),sh,1));
+			sh->AddLine(new ShiftingSlider("%bZ",iDataReader::KeyShiftData(),sh,2));
+			this->AddLine(sh);
+			this->AddSpace(10);
+			this->SetColStretch(0,10);
+			this->SetColStretch(1,3);
+		}
+	};
 
 
-iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent,true,true)
-{
-	const iImage *icon = iImageFactory::FindIcon("data.png");
+	//
+	//  Erase page
+	//
+	class CommonErasePage : public iggFrameDC
+	{
 
-	mInfoBuffer = new iDataInfo[DataWith::COUNT]; IERROR_ASSERT(mInfoBuffer);
-	mProvider = new iggCompositeDataTypeProvider(this); IERROR_ASSERT(mProvider);
-	mProvider->AddProvider(new iggKeywordDataTypeProvider("scalars",this));
-	mProvider->AddProvider(new iggKeywordDataTypeProvider("particles",this));
+	public:
 
-	iDataType::FindTypesByKeywords(mInfoBuffer[DataWith::ParticleDownsampling],"particles");
-	mInfoBuffer[DataWith::BoundaryCondition] = mInfoBuffer[DataWith::ParticleDownsampling] + iUniformScalarsDataSubject::DataType() + iUniformVectorsDataSubject::DataType() + iUniformTensorsDataSubject::DataType();
-	mInfoBuffer[DataWith::VariableCalculation] = iUniformScalarsDataSubject::DataType();
+		CommonErasePage(iggFrameBase *parent) : iggFrameDC(parent,2)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
+			ErasePushButton *eb = new ErasePushButton("Erase selected data",this);
+			this->AddLine(new EraseFrame(eb,this));
+			this->AddLine(eb);
+			this->AddSpace(2);
+			this->SetRowStretch(0,10);
+			this->SetColStretch(0,10);
+			this->SetColStretch(1,0);
+		}
+	};
+
+
+	//
+	//  Fixed/adjustable page
+	//
+	class CommonRangePage : public iggFrameDC
+	{
+
+	public:
+
+		CommonRangePage(iggFrameBase *parent) : iggFrameDC(parent,2)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
+			this->AddLine(new FixedLimitsFrame(this));
+			this->AddSpace(10);
+			this->SetRowStretch(0,8);
+			this->SetColStretch(1,10);
+		}
+	};
 
-	this->GetMainWindow()->GetExtensionWindow()->AddReloadingDataTypes(this);
 
 	//
 	//  Common page
 	// ************************************************
 	//
-	iggFrame *page0 = new iggFrame(mBook,1);
-	mBook->AddPage("Common",icon,page0);
+	class CommonPage : public iggFrameDC
 	{
-		//
-		//  Book
-		//
-		iggFrameBook *sb = new iggFrameBook(page0);
-		page0->AddLine(sb);
+
+	public:
+	
+		CommonPage(iggFrameBase *parent, iDataInfo *info) : iggFrameDC(parent,1), mInfoBuffer(info)
 		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		iDataInfo *mInfoBuffer;
+
+		virtual void CompleteConstructionBody()
+		{
+			const iImage *icon = iImageFactory::FindIcon("data.png");
+
+			//
+			//  Book
+			//
+			iggFrameBook *sb = new iggFrameBook(this);
+			this->AddLine(sb);
 			//
 			//  Global page
 			//
@@ -917,59 +1003,53 @@ iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent,true,true)
 			//
 			//  Shift page
 			//
-			iggFrame *sbpage1 = new iggFrame(sb,2);
+			CommonShiftPage *sbpage1 = new CommonShiftPage(sb);
 			sb->AddPage("Shift data",icon,sbpage1);
-			{
-				iggFrame *sh = new iggFrame(sbpage1);
-				sh->AddLine(new ShiftingSlider("%bX",iDataReader::KeyShiftData(),sh,0));
-				sh->AddLine(new ShiftingSlider("%bY",iDataReader::KeyShiftData(),sh,1));
-				sh->AddLine(new ShiftingSlider("%bZ",iDataReader::KeyShiftData(),sh,2));
-				sbpage1->AddLine(sh);
-				sbpage1->AddSpace(10);
-				sbpage1->SetColStretch(0,10);
-				sbpage1->SetColStretch(1,3);
-			}		
+
 			//
 			//  Erase page
 			//
-			iggFrame *sbpage2 = new iggFrame(sb,2);
+			CommonErasePage *sbpage2 = new CommonErasePage(sb);
 			sb->AddPage("Erase",icon,sbpage2);
-			{
-				ErasePushButton *eb = new ErasePushButton("Erase selected data",sbpage2);
-				sbpage2->AddLine(new EraseFrame(eb,sbpage2));
-				sbpage2->AddLine(eb);
-				sbpage2->AddSpace(2);
-				sbpage2->SetRowStretch(0,10);
-				sbpage2->SetColStretch(0,10);
-				sbpage2->SetColStretch(1,10);
-			}
+
 			//
 			//  Fixed/adjustable page
 			//
-			iggFrame *sbpage3 = new iggFrame(sb,2);
+			CommonRangePage *sbpage3 = new CommonRangePage(sb);
 			sb->AddPage("Ranges",icon,sbpage3);
-			{
-				sbpage3->AddLine(new FixedLimitsFrame(sbpage3));
-				sbpage3->AddSpace(10);
-				sbpage3->SetRowStretch(0,8);
-				sbpage3->SetColStretch(1,10);
-			}
 		}
-	}
+	};
+
 
 	//
 	//  Field data page
 	// ************************************************
 	//
-	iggFrame *page1 = new iggFrame(mBook,1);
-	mBook->AddPage("Field data",icon,page1);
+	class FieldDataPage : public iggFrameDC
 	{
-		//
-		//  Book
-		//
-		iggFrameBook *fb = new iggFrameBook(page1);
-		page1->AddLine(fb);
+
+	public:
+	
+		FieldDataPage(iggFrameBase *parent, iggPageData *owner, iDataInfo *info, iggCompositeDataTypeProvider *provider) : iggFrameDC(parent,1), mOwner(owner), mInfoBuffer(info), mProvider(provider)
 		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		iggPageData *mOwner;
+		iDataInfo *mInfoBuffer;
+		iggCompositeDataTypeProvider *mProvider;
+
+		virtual void CompleteConstructionBody()
+		{
+			const iImage *icon = iImageFactory::FindIcon("data.png");
+
+			//
+			//  Book
+			//
+			iggFrameBook *fb = new iggFrameBook(this);
+			this->AddLine(fb);
 			//
 			//  Placement page
 			//
@@ -984,24 +1064,24 @@ iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent,true,true)
 				iggWidgetTextArea *tmp = new iggWidgetTextArea("  Dimension to fit",fbpage2);
 				tmp->AlignLeft(true);
 				fbpage2->AddLine(tmp);
-				iggWidgetKeyRadioBox *fb = new iggWidgetKeyRadioBox(1,"into bounding box",2,iDataReader::KeyScaledDimension(),fbpage2);
-				fb->InsertItem("Longest");
-				fb->InsertItem("Shortest");
-				fb->InsertItem("X");
-				fb->InsertItem("Y");
-				fb->InsertItem("Z");
-				fbpage2->AddLine(fb);
+				iggWidgetKeyRadioBox *bb = new iggWidgetKeyRadioBox(1,"into bounding box",2,iDataReader::KeyScaledDimension(),fbpage2);
+				bb->InsertItem("Longest");
+				bb->InsertItem("Shortest");
+				bb->InsertItem("X");
+				bb->InsertItem("Y");
+				bb->InsertItem("Z");
+				fbpage2->AddLine(bb);
 				fbpage2->AddSpace(10);
 
 				fbpage2->SetColStretch(1,10);
-			}		
+			}
 			//
 			//  Limits page
 			//
 			iggFrame *fbpage1 = new iggFrame(fb,1);
 			fb->AddPage("Limits",icon,fbpage1);
 			{
-				fbpage1->AddLine(new LimitsFrameSet(this,fbpage1));
+				fbpage1->AddLine(new LimitsFrameSet(mOwner,fbpage1));
 			}
 			//
 			//  Operate page
@@ -1029,21 +1109,37 @@ iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent,true,true)
 				fbpage3->SetColStretch(2,3);
 			}
 		}
-	}
+	};
+
 
 	//
 	//  Particle data page
 	// ************************************************
 	//
-	iggFrame *page2 = new iggFrame(mBook,1);
-	mBook->AddPage("Particle data",icon,page2);
+	class ParticleDataPage : public iggFrameDC
 	{
-		//
-		//  Book
-		//
-		iggFrameBook *pb = new iggFrameBook(page2);
-		page2->AddLine(pb);
+
+	public:
+	
+		ParticleDataPage(iggFrameBase *parent, iDataInfo *info, iggCompositeDataTypeProvider *provider) : iggFrameDC(parent,1), mInfoBuffer(info), mProvider(provider)
 		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		iDataInfo *mInfoBuffer;
+		iggCompositeDataTypeProvider *mProvider;
+
+		virtual void CompleteConstructionBody()
+		{
+			const iImage *icon = iImageFactory::FindIcon("data.png");
+
+			//
+			//  Book
+			//
+			iggFrameBook *pb = new iggFrameBook(this);
+			this->AddLine(pb);
 			//
 			//  Downsample page
 			//
@@ -1096,7 +1192,48 @@ iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent,true,true)
 				pbpage1->SetColStretch(1,10);
 			}
 		}
-	}
+	};
+};
+
+
+using namespace iggPageData_Private;
+
+
+iggPageData::iggPageData(iggFrameBase *parent) : iggPageMain(parent,true,true)
+{
+	const iImage *icon = iImageFactory::FindIcon("data.png");
+
+	mInfoBuffer = new iDataInfo[DataWith::COUNT]; IERROR_ASSERT(mInfoBuffer);
+	mProvider = new iggCompositeDataTypeProvider(this); IERROR_ASSERT(mProvider);
+	mProvider->AddProvider(new iggKeywordDataTypeProvider("scalars",this));
+	mProvider->AddProvider(new iggKeywordDataTypeProvider("particles",this));
+
+	iDataType::FindTypesByKeywords(mInfoBuffer[DataWith::ParticleDownsampling],"particles");
+	mInfoBuffer[DataWith::BoundaryCondition] = mInfoBuffer[DataWith::ParticleDownsampling] + iUniformScalarsDataSubject::DataType() + iUniformVectorsDataSubject::DataType() + iUniformTensorsDataSubject::DataType();
+	mInfoBuffer[DataWith::VariableCalculation] = iUniformScalarsDataSubject::DataType();
+
+	this->GetMainWindow()->GetExtensionWindow()->AddReloadingDataTypes(this);
+
+	//
+	//  Common page
+	// ************************************************
+	//
+	CommonPage *page0 = new CommonPage(mBook,mInfoBuffer);
+	mBook->AddPage("Common",icon,page0);
+
+	//
+	//  Field data page
+	// ************************************************
+	//
+	FieldDataPage *page1 = new FieldDataPage(mBook,this,mInfoBuffer,mProvider);
+	mBook->AddPage("Field data",icon,page1);
+
+	//
+	//  Particle data page
+	// ************************************************
+	//
+	ParticleDataPage *page2 = new ParticleDataPage(mBook,mInfoBuffer,mProvider);
+	mBook->AddPage("Particle data",icon,page2);
 }
 
 
