@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -232,6 +232,354 @@ namespace iggPageParticles_Private
 
 		iggPageParticles *mPage;
 	};
+
+
+	//
+	//  Main page
+	// ************************************************
+	//
+	class MainPage : public iggFrameDC
+	{
+
+	public:
+
+		MainPage(iggFrameBase *parent) : iggFrameDC(parent,3)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
+			//
+			//  Show
+			//
+			iggFrameCurrentInstance *ci = new iggFrameCurrentInstance(false,"Group","Group",iParticlesViewSubject::KeyCurrentGroup(),iParticlesViewSubject::KeyMaxGroup(),this);
+			ci->AddDependent(this);
+			this->AddLine(new iggWidgetShowButton(iParticlesViewSubject::Type(),this),static_cast<iggWidget*>(0),ci);
+			this->AddSpace(2);
+			//
+			//  Method & color normals
+			//
+			iggFrame *tf = new iggFrame(this,2);
+			iggWidgetKeyComboBox *tb = new iggWidgetKeyComboBox("Type",0,iParticleGroup::KeyType(),tf);
+			int i;
+			for(i=0; i<PointGlyphType::SIZE; i++)
+			{
+				tb->InsertItem(iPointGlyph::GetName(i));
+			}
+			tf->AddLine(tb,new iggWidgetKeyColorSelection(iParticleGroup::KeyColor(),tf));
+
+			this->AddLine(tf);
+			this->AddSpace(10);
+			//
+			//  Opacity
+			//
+			iggWidgetKeyFloatSlider *os = new iggWidgetKeyFloatSlider(1.0e-4,1.0,40,1,5,"Opacity",iParticleGroup::KeyOpacity(),RenderMode::UseGlobal,this);
+			os->SetStretch(2,10);
+			this->AddLine(os,2);
+			iggWidgetKeyFloatSlider *ss = new iggWidgetKeyFloatSlider(1.0e-2,1.0e2,40,1,5,"Size",iParticleGroup::KeyFixedSize(),RenderMode::UseGlobal,this);
+			ss->SetStretch(2,10);
+			this->AddLine(ss,2);
+			iggFrame *tmp = new iggFrame(this,4);
+			tmp->AddLine(new AdjustSizeSliderButton(ss,false,tmp),new AdjustSizeSliderButton(ss,true,tmp),new iggWidgetTextArea("Expand/shrink the lower limit",tmp));
+			tmp->SetColStretch(3,10);
+			this->AddLine(tmp);
+			this->AddLine(new iggWidgetKeyCheckBox("Scale particles automatically",iParticleGroup::KeyAutoScaled(),this));
+			this->AddSpace(10);
+
+			this->SetColStretch(1,10); 
+		}
+	};
+
+
+	//
+	//  Paint page
+	// ************************************************
+	//
+	class PaintPage : public iggFrameDC
+	{
+
+	public:
+	
+		PaintPage(iggFrameBase *parent, iggDataTypeProvider *provider) : iggFrameDC(parent,1), mProvider(provider)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+		iggWidgetKeyVariableLimitsSlider* AttLower() const { return mAttLower; }
+		iggWidgetKeyVariableLimitsSlider* AttUpper() const { return mAttUpper; }
+
+	protected:
+
+		iggDataTypeProvider *mProvider;
+		iggWidgetKeyVariableLimitsSlider *mAttLower, *mAttUpper;
+
+		virtual void CompleteConstructionBody()
+		{
+			const iImage *icon = iImageFactory::FindIcon("part.png");
+
+			//
+			//  Book
+			//
+			iggFrameBook *pb = new iggFrameBook(this);
+			this->AddLine(pb);
+			//
+			//  Palette page
+			//
+			iggFrame *pbpage0 = new iggFrame(pb,3);
+			pb->AddPage("Palette",icon,pbpage0);
+			{
+				iggFrame *pf = new iggFrame(pbpage0,2);
+				iggFrameDataVariableList *pl = new iggFrameDataVariableList(mProvider,"Paint with...",iParticleGroup::KeyAttributeToColor(),0,pf);
+				pl->InsertItem("None");
+				pl->Complete();
+				iggFrame *tmp = new iggFrame(pf);
+				tmp->AddSpace(10);
+				iggWidgetKeyStretchComboBox *ls = new iggWidgetKeyStretchComboBox(iParticleGroup::KeyStretchToColor(),tmp);
+				tmp->AddLine(ls);
+				tmp->AddSpace(10);
+				pf->AddLine(pl,tmp);
+				pbpage0->AddLine(pf);
+
+				pbpage0->AddSpace(5);
+
+				mAttLower = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Min",iParticleGroup::KeyLowerLimitToColor(),&iParticleGroup::KeyAttributeToColor(),&iParticleGroup::KeyStretchToColor(),RenderMode::UseGlobal,pbpage0,0,&iParticleGroup::KeyAttributeToColor());
+				mAttUpper = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Max",iParticleGroup::KeyUpperLimitToColor(),&iParticleGroup::KeyAttributeToColor(),&iParticleGroup::KeyStretchToColor(),RenderMode::UseGlobal,pbpage0,0,&iParticleGroup::KeyAttributeToColor());
+				pl->AddDependent(mAttLower);
+				pl->AddDependent(mAttUpper);
+				ls->AddDependent(mAttLower);
+				ls->AddDependent(mAttUpper);
+				mAttLower->AddBuddy(mAttUpper);
+				pbpage0->AddLine(mAttLower,2);
+				pbpage0->AddLine(mAttUpper,2);
+
+				pbpage0->AddSpace(10);
+
+				pbpage0->AddLine(new iggFramePaletteSelection(true,iParticleGroup::KeyPalette(),pbpage0),2);
+				pbpage0->AddSpace(20);
+
+				pbpage0->SetColStretch(1,10);
+				pbpage0->SetColStretch(2,3);
+			}
+			//
+			//  Material page
+			//
+			iggFrame *pbpage1 = new iggFrame(pb,2);
+			pb->AddPage("Material",icon,pbpage1);
+			{
+				pbpage1->AddLine(new iggFrameMaterialProperties(true,false,iParticleGroup::Type(),pbpage1));
+				pbpage1->AddSpace(10);
+
+				pbpage1->SetColStretch(0,10);
+				pbpage1->SetColStretch(1,3);
+			}
+		}
+	};
+
+
+	//
+	//  Size page
+	// ************************************************
+	//
+	class SizePage : public iggFrameDC
+	{
+
+	public:
+
+		SizePage(iggFrameBase *parent, iggDataTypeProvider *provider, PaintPage *pp) : iggFrameDC(parent,1), mProvider(provider), mPaintPage(pp)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		iggDataTypeProvider *mProvider;
+		PaintPage *mPaintPage;
+
+		virtual void CompleteConstructionBody()
+		{
+			const iImage *icon = iImageFactory::FindIcon("part.png");
+
+			//
+			//  Book
+			//
+			iggFrameBook *sb = new iggFrameBook(this);
+			this->AddLine(sb);
+			//
+			//  Settings page
+			//
+			iggFrame *sbpage0 = new iggFrame(sb,3);
+			sb->AddPage("Settings",icon,sbpage0);
+			{
+				iggFrame *sf = new iggFrame(sbpage0,2);
+				iggFrameDataVariableList *sl = new iggFrameDataVariableList(mProvider,"Size with...",iParticleGroup::KeyAttributeToSize(),0,sf);
+				sl->InsertItem("None");
+				sl->Complete();
+				iggFrame *tmp = new iggFrame(sf);
+				tmp->AddSpace(10);
+				iggWidgetKeyStretchComboBox *lz = new iggWidgetKeyStretchComboBox(iParticleGroup::KeyStretchToSize(),tmp);
+				tmp->AddLine(lz);
+				tmp->AddSpace(10);
+				sf->AddLine(sl,tmp);
+				sf->AddLine(new iggWidgetKeyCheckBox("Use as size; scale by",iParticleGroup::KeyAttributeSizeDirect(),sf),new iggWidgetKeyFloatLineEdit("",iParticleGroup::KeyAttributeSizeExtraFactor(),RenderMode::UseGlobal,sf));
+
+				sbpage0->AddLine(sf);
+
+				sbpage0->AddSpace(5);
+
+				iggWidgetKeyVariableLimitsSlider *bl = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Min",iParticleGroup::KeyLowerLimitToSize(),&iParticleGroup::KeyAttributeToSize(),&iParticleGroup::KeyStretchToSize(),RenderMode::UseGlobal,sbpage0,0,&iParticleGroup::KeyAttributeToSize());
+				iggWidgetKeyVariableLimitsSlider *bu = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Max",iParticleGroup::KeyUpperLimitToSize(),&iParticleGroup::KeyAttributeToSize(),&iParticleGroup::KeyStretchToSize(),RenderMode::UseGlobal,sbpage0,0,&iParticleGroup::KeyAttributeToSize());
+				sl->AddDependent(bl);
+				sl->AddDependent(bu);
+				lz->AddDependent(bl);
+				lz->AddDependent(bu);
+				bl->AddBuddy(bu);
+				//
+				//  Add paint limits as well
+				//
+				bu->AddBuddy(mPaintPage->AttUpper());
+				bl->AddBuddy(mPaintPage->AttLower());
+
+				sbpage0->AddLine(bl,2);
+				sbpage0->AddLine(bu,2);
+
+				sbpage0->AddSpace(10);
+
+				sbpage0->SetColStretch(1,10);
+				sbpage0->SetColStretch(2,3);
+			}
+			//
+			//  Function page
+			//
+			iggFrame *sbpage1 = new iggFrame(sb,1);
+			sb->AddPage("Function",icon,sbpage1);
+			{
+				//
+				//  FunctionMapping widget
+				//
+				sbpage1->AddLine(new iggFrameFunctionMapping(iParticleGroup::KeySizeFunction(),sbpage1));
+			}
+		}
+	};
+
+
+	//
+	//  Replicate page
+	// ************************************************
+	//
+	class ReplicatePage : public iggFrameDC
+	{
+
+	public:
+
+		ReplicatePage(iggFrameBase *parent) : iggFrameDC(parent,2)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
+			//
+			//  Replicate
+			//
+			this->AddLine(new iggFrameReplicate(iParticlesViewSubject::Type(),this));
+			this->AddSpace(10);
+			this->SetColStretch(1,3);
+		}
+	};
+
+	//
+	//  Advanced page
+	// ************************************************
+	//
+	class AdvancedPage : public iggFrameDC
+	{
+
+	public:
+
+		AdvancedPage(iggFrameBase *parent, iggDataTypeProvider *provider) : iggFrameDC(parent,1), mProvider(provider)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		iggDataTypeProvider *mProvider;
+
+		virtual void CompleteConstructionBody()
+		{
+			const iImage *icon = iImageFactory::FindIcon("part.png");
+
+			//
+			//  Book
+			//
+			iggFrameBook *ab = new iggFrameBook(this);
+			this->AddLine(ab);
+			//
+			//  Split page
+			//
+			iggFrame *abpage0 = new iggFrame(ab,1);
+			ab->AddPage("Split into groups",icon,abpage0);
+			{
+				//
+				//  Book
+				//
+				iggFrameBook *db = new iggFrameBook(abpage0);
+				abpage0->AddLine(db);
+				iggFrameDataVariableList *av;
+				iggWidgetKeyStretchComboBox *as;
+				//
+				//  Main page
+				//
+				iggFrame *dbpage0 = new iggFrame(db,2);
+				db->AddPage("Main",icon,dbpage0);
+				{
+					av = new iggFrameDataVariableList(mProvider,"Split by...",iParticlesViewSubject::KeyAttributeToSplit(),0,dbpage0);
+					av->InsertItem("Do not split");
+					av->Complete(); // splitter's attributes start with -1
+					dbpage0->AddLine(av);
+
+					as = new iggWidgetKeyStretchComboBox(iParticlesViewSubject::KeySplitRangesStretch(),dbpage0);
+					dbpage0->AddLine(as);
+					dbpage0->AddSpace(10);
+					dbpage0->SetColStretch(1,3);
+				}
+				//
+				//  FunctionMapping widget
+				//
+				iggFrame *dbpage1 = new iggFrame(db,1);
+				db->AddPage("Ranges",icon,dbpage1);
+				{
+					RangeMapping *rm = new RangeMapping(this,dbpage1);
+					av->AddDependent(rm);
+					as->AddDependent(rm);
+
+					dbpage1->AddLine(rm);
+				}
+				//
+				//  Connect page
+				//
+				iggFrame *abpage1 = new iggFrame(ab,3);
+				ab->AddPage("Connect with lines",icon,abpage1);
+				{
+					iggFrameDataVariableList *cv = new iggFrameDataVariableList(mProvider,"Connect by...",iParticleGroup::KeyAttributeToConnect(),0,abpage1);
+					cv->InsertItem("Do not connect");
+					cv->Complete(); // connector's attributes start with -1
+					iggFrameDataVariableList *sv = new iggFrameDataVariableList(mProvider,"Separate by...",iParticleGroup::KeyAttributeToSeparate(),0,abpage1);
+					sv->InsertItem("None");
+					sv->Complete(); // connector's attributes start with -1
+					abpage1->AddLine(cv,sv);
+
+					abpage1->AddSpace(10);
+					abpage1->SetColStretch(2,10);
+				}
+			}
+		}
+	};
 };
 
 
@@ -240,8 +588,6 @@ using namespace iggPageParticles_Private;
 
 iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,ViewSubject::Id::Particles)
 {
-	int i;
-
 	const iImage *icon = iImageFactory::FindIcon("part.png");
 
 	mCurrentParticles = this->GetParticlesObject()->GetActiveDataTypeIndex();
@@ -255,6 +601,7 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,
 	mIcons.Add(iImageFactory::FindIcon("part.png"));
 	const iDataInfo &di(mProvider->GetDataInfo());
 	const iImage *image;
+	int i;
 	for(i=1; i<di.Count(); i++)
 	{
 		image = this->GetMainWindow()->GetExtensionWindow()->GetSpecialParticleIcon(di.Type(i));
@@ -265,253 +612,36 @@ iggPageParticles::iggPageParticles(iggFrameBase *parent) : iggPageObject(parent,
 	//  Main page
 	// ************************************************
 	//
-	iggFrame *page0 = new iggFrame(mBook,3);
+	MainPage *page0 = new MainPage(mBook);
 	mBook->AddPage("Main",icon,page0);
-	//
-	//  Show
-	//
-	iggFrameCurrentInstance *ci = new iggFrameCurrentInstance(false,"Group","Group",iParticlesViewSubject::KeyCurrentGroup(),iParticlesViewSubject::KeyMaxGroup(),page0);
-	ci->AddDependent(this);
-	page0->AddLine(new iggWidgetShowButton(iParticlesViewSubject::Type(),page0),static_cast<iggWidget*>(0),ci);
-	page0->AddSpace(2);
-	//
-	//  Method & color normals
-	//
-	iggFrame *tf = new iggFrame(page0,2);
-	iggFrame *tf1 = new iggFrame(tf,1);
-	iggWidgetKeyComboBox *tb = new iggWidgetKeyComboBox("Type",0,iParticleGroup::KeyType(),tf1);
-	tf1->AddLine(tb);
-	tf1->AddSpace(10);
-	for(i=0; i<PointGlyphType::SIZE; i++)
-	{
-		tb->InsertItem(iPointGlyph::GetName(i));
-	}
-	tf->AddLine(tf1,new iggWidgetKeyColorSelection(iParticleGroup::KeyColor(),tf,false));
-
-	page0->AddLine(tf);
-	page0->AddSpace(10);
-	//
-	//  Opacity
-	//
-	iggWidgetKeyFloatSlider *os = new iggWidgetKeyFloatSlider(1.0e-4,1.0,40,1,5,"Opacity",iParticleGroup::KeyOpacity(),RenderMode::UseGlobal,page0);
-	os->SetStretch(2,10);
-	page0->AddLine(os,2);
-	iggWidgetKeyFloatSlider *ss = new iggWidgetKeyFloatSlider(1.0e-2,1.0e2,40,1,5,"Size",iParticleGroup::KeyFixedSize(),RenderMode::UseGlobal,page0);
-	ss->SetStretch(2,10);
-	page0->AddLine(ss,2);
-	iggFrame *tmp = new iggFrame(page0,4);
-	tmp->AddLine(new AdjustSizeSliderButton(ss,false,tmp),new AdjustSizeSliderButton(ss,true,tmp),new iggWidgetTextArea("Expand/shrink the lower limit",tmp));
-	tmp->SetColStretch(3,10);
-	page0->AddLine(tmp);
-	page0->AddLine(new iggWidgetKeyCheckBox("Scale particles automatically",iParticleGroup::KeyAutoScaled(),page0));
-	page0->AddSpace(10);
-
-	page0->SetColStretch(1,10); 
 
 	//
 	//  Paint page
 	// ************************************************
 	//
-	iggFrame *page1 = new iggFrame(mBook,1);
+	PaintPage *page1 = new PaintPage(mBook,mProvider);
 	mBook->AddPage("Paint",icon,page1);
-	//
-	//  Book
-	//
-	iggFrameBook *pb = new iggFrameBook(page1);
-	page1->AddLine(pb);
-	//
-	//  Palette page
-	//
-	iggFrame *pbpage0 = new iggFrame(pb,3);
-	pb->AddPage("Palette",icon,pbpage0);
-
-	iggFrame *pf = new iggFrame(pbpage0,2);
-	iggFrameDataVariableList *pl = new iggFrameDataVariableList(mProvider,"Paint with...",iParticleGroup::KeyAttributeToColor(),0,pf);
-	pl->InsertItem("None");
-	pl->Complete();
-	tmp = new iggFrame(pf);
-	tmp->AddSpace(10);
-	iggWidgetKeyStretchComboBox *ls = new iggWidgetKeyStretchComboBox(iParticleGroup::KeyStretchToColor(),tmp);
-	tmp->AddLine(ls);
-	tmp->AddSpace(10);
-	pf->AddLine(pl,tmp);
-	pbpage0->AddLine(pf);
-
-	pbpage0->AddSpace(5);
-
-	iggWidgetKeyVariableLimitsSlider *al = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Min",iParticleGroup::KeyLowerLimitToColor(),&iParticleGroup::KeyAttributeToColor(),&iParticleGroup::KeyStretchToColor(),RenderMode::UseGlobal,pbpage0,0,&iParticleGroup::KeyAttributeToColor());
-	iggWidgetKeyVariableLimitsSlider *au = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Max",iParticleGroup::KeyUpperLimitToColor(),&iParticleGroup::KeyAttributeToColor(),&iParticleGroup::KeyStretchToColor(),RenderMode::UseGlobal,pbpage0,0,&iParticleGroup::KeyAttributeToColor());
-	pl->AddDependent(al);
-	pl->AddDependent(au);
-	ls->AddDependent(al);
-	ls->AddDependent(au);
-	al->AddBuddy(au);
-	pbpage0->AddLine(al,2);
-	pbpage0->AddLine(au,2);
-
-	pbpage0->AddSpace(10);
-
-	pbpage0->AddLine(new iggFramePaletteSelection(true,iParticleGroup::KeyPalette(),pbpage0),2);
-	pbpage0->AddSpace(20);
-
-	pbpage0->SetColStretch(1,10);
-	pbpage0->SetColStretch(2,3);
-
-	//
-	//  Material page
-	//
-	iggFrame *pbpage1 = new iggFrame(pb,2);
-	pb->AddPage("Material",icon,pbpage1);
-
-	pbpage1->AddLine(new iggFrameMaterialProperties(true,false,iParticleGroup::Type(),pbpage1));
-	pbpage1->AddSpace(10);
-
-	pbpage1->SetColStretch(0,10);
-	pbpage1->SetColStretch(1,3);
 
 	//
 	//  Size page
 	// ************************************************
 	//
-	iggFrame *page2 = new iggFrame(mBook,1);
+	SizePage *page2 = new SizePage(mBook,mProvider,page1);
 	mBook->AddPage("Size",icon,page2);
-	//
-	//  Book
-	//
-	iggFrameBook *sb = new iggFrameBook(page2);
-	page2->AddLine(sb);
-	//
-	//  Settings page
-	//
-	iggFrame *sbpage0 = new iggFrame(sb,3);
-	sb->AddPage("Settings",icon,sbpage0);
-
-	iggFrame *sf = new iggFrame(sbpage0,2);
-	iggFrameDataVariableList *sl = new iggFrameDataVariableList(mProvider,"Size with...",iParticleGroup::KeyAttributeToSize(),0,sf);
-	sl->InsertItem("None");
-	sl->Complete();
-	tmp = new iggFrame(sf);
-	tmp->AddSpace(10);
-	iggWidgetKeyStretchComboBox *lz = new iggWidgetKeyStretchComboBox(iParticleGroup::KeyStretchToSize(),tmp);
-	tmp->AddLine(lz);
-	tmp->AddSpace(10);
-	sf->AddLine(sl,tmp);
-	sf->AddLine(new iggWidgetKeyCheckBox("Use as size; scale by",iParticleGroup::KeyAttributeSizeDirect(),sf),new iggWidgetKeyFloatLineEdit("",iParticleGroup::KeyAttributeSizeExtraFactor(),RenderMode::UseGlobal,sf));
-	
-	sbpage0->AddLine(sf);
-
-	sbpage0->AddSpace(5);
-
-	iggWidgetKeyVariableLimitsSlider *bl = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Min",iParticleGroup::KeyLowerLimitToSize(),&iParticleGroup::KeyAttributeToSize(),&iParticleGroup::KeyStretchToSize(),RenderMode::UseGlobal,sbpage0,0,&iParticleGroup::KeyAttributeToSize());
-	iggWidgetKeyVariableLimitsSlider *bu = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Max",iParticleGroup::KeyUpperLimitToSize(),&iParticleGroup::KeyAttributeToSize(),&iParticleGroup::KeyStretchToSize(),RenderMode::UseGlobal,sbpage0,0,&iParticleGroup::KeyAttributeToSize());
-	sl->AddDependent(bl);
-	sl->AddDependent(bu);
-	lz->AddDependent(bl);
-	lz->AddDependent(bu);
-	bl->AddBuddy(bu);
-	//
-	//  Add paint limits as well
-	//
-	bl->AddBuddy(au);
-	bu->AddBuddy(al);
-
-	sbpage0->AddLine(bl,2);
-	sbpage0->AddLine(bu,2);
-
-	sbpage0->AddSpace(10);
-
-	sbpage0->SetColStretch(1,10);
-	sbpage0->SetColStretch(2,3);
-
-	//
-	//  Function page
-	//
-	iggFrame *sbpage1 = new iggFrame(sb,1);
-	sb->AddPage("Function",icon,sbpage1);
-	//
-	//  FunctionMapping widget
-	//
-	sbpage1->AddLine(new iggFrameFunctionMapping(iParticleGroup::KeySizeFunction(),sbpage1));
 
 	//
 	//  Replicate page
 	// ************************************************
 	//
-	iggFrame *page3 = new iggFrame(mBook,2);
+	ReplicatePage *page3 = new ReplicatePage(mBook);
 	mBook->AddPage("Replicate",icon,page3);
-	//
-	//  Replicate
-	//
-	page3->AddLine(new iggFrameReplicate(iParticlesViewSubject::Type(),page3));
-	page3->AddSpace(10);
-	page3->SetColStretch(1,3);
 
 	//
 	//  Advanced page
 	// ************************************************
 	//
-	iggFrame *page4 = new iggFrame(mBook,1);
+	AdvancedPage *page4 = new AdvancedPage(mBook,mProvider);
 	mBook->AddPage("Advanced",icon,page4);
-	//
-	//  Book
-	//
-	iggFrameBook *ab = new iggFrameBook(page4);
-	page4->AddLine(ab);
-
-	//
-	//  Split page
-	//
-	iggFrame *abpage0 = new iggFrame(ab,1);
-	ab->AddPage("Split into groups",icon,abpage0);
-
-	//
-	//  Book
-	//
-	iggFrameBook *db = new iggFrameBook(abpage0);
-	abpage0->AddLine(db);
-	//
-	//  Main page
-	//
-	iggFrame *dbpage0 = new iggFrame(db,2);
-	db->AddPage("Main",icon,dbpage0);
-
-	iggFrameDataVariableList *av = new iggFrameDataVariableList(mProvider,"Split by...",iParticlesViewSubject::KeyAttributeToSplit(),0,dbpage0);
-	av->InsertItem("Do not split");
-	av->Complete(); // splitter's attributes start with -1
-	dbpage0->AddLine(av);
-
-	iggWidgetKeyStretchComboBox *as = new iggWidgetKeyStretchComboBox(iParticlesViewSubject::KeySplitRangesStretch(),dbpage0);
-	dbpage0->AddLine(as);
-	dbpage0->AddSpace(10);
-	dbpage0->SetColStretch(1,3);
-	//
-	//  FunctionMapping widget
-	//
-	iggFrame *dbpage1 = new iggFrame(db,1);
-	db->AddPage("Ranges",icon,dbpage1);
-
-	RangeMapping *rm = new RangeMapping(this,dbpage1);
-	av->AddDependent(rm);
-	as->AddDependent(rm);
-	
-	dbpage1->AddLine(rm);
-
-	//
-	//  Connect page
-	//
-	iggFrame *abpage1 = new iggFrame(ab,3);
-	ab->AddPage("Connect with lines",icon,abpage1);
-
-	iggFrameDataVariableList *cv = new iggFrameDataVariableList(mProvider,"Connect by...",iParticleGroup::KeyAttributeToConnect(),0,abpage1);
-	cv->InsertItem("Do not connect");
-	cv->Complete(); // connector's attributes start with -1
-	iggFrameDataVariableList *sv = new iggFrameDataVariableList(mProvider,"Separate by...",iParticleGroup::KeyAttributeToSeparate(),0,abpage1);
-	sv->InsertItem("None");
-	sv->Complete(); // connector's attributes start with -1
-	abpage1->AddLine(cv,sv);
-
-	abpage1->AddSpace(10);
-	abpage1->SetColStretch(2,10);
 }
 
 
