@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -449,6 +449,268 @@ namespace iggPageSurface_Private
 			this->GetMainWindow()->Block(false);
 		}
 	};
+
+
+	//
+	//  Main page
+	// ************************************************
+	//
+	class MainPage : public iggFrameDC
+	{
+
+	public:
+
+		MainPage(iggFrameBase *parent, iggDataTypeProvider *provider) : iggFrameDC(parent,1), mProvider(provider)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		iggDataTypeProvider *mProvider;
+
+		virtual void CompleteConstructionBody()
+		{
+			//
+			//  Top half-page sub-frame
+			//
+			iggFrame *page0top = new iggFrame(this,4);
+			this->AddLine(page0top);
+			//
+			//  Show
+			//
+			iggWidget *show = new iggWidgetShowButton(iSurfaceViewSubject::Type(),page0top);
+			iggFrameCurrentInstance *ci1 = new iggFrameCurrentInstance(false,"Instance","Instance",iViewModule::KeySurfaceCurrent(),iViewModule::KeySurfaceMax(),page0top);
+			ci1->AddDependent(this);
+			page0top->AddLine(show,static_cast<iggWidget*>(0),static_cast<iggWidget*>(0),ci1);
+			page0top->AddSpace(2);
+			//
+			//  Method & flip normals
+			//
+			iggFrame *mf = new iggFrame(page0top,2);
+			MethodRadioBox *mb = new MethodRadioBox(iSurfaceViewSubject::KeyMethod(),mf);
+			iggFrame *mf2 = new iggFrame(mf,1);
+			mf2->AddSpace(1);
+			mf2->AddLine(new iggWidgetKeyColorSelection(iSurfaceViewSubject::KeyColor(),mf2,0));
+			mf2->AddLine(new PrintInfoButton(mf2));
+			mf2->AddSpace(3);
+			mf2->AddLine(new iggWidgetKeyCheckBox("Flip normals",iSurfaceViewSubject::KeyNormalsFlipped(),mf2));
+			mf->AddLine(mb,mf2);
+			page0top->AddLine(mf,2);
+			page0top->AddSpace(2);
+			//
+			//  Opacity
+			//
+			iggWidgetKeyFloatSlider *os = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,5,"Opacity",iSurfaceViewSubject::KeyOpacity(),RenderMode::UseGlobal,page0top);
+			page0top->AddLine(os,3);
+			iggWidgetAllInstancesCheckBox *li = new iggWidgetAllInstancesCheckBox(page0top);
+			li->AddDependent(os);
+			page0top->AddLine(li,2);
+			page0top->AddSpace(10);
+
+			page0top->SetColStretch(2,3);
+
+			//
+			//  Lower half-page: various method-dependent settings in a headless mBook
+			//
+			iggFrame *page0bot = new iggFrame(this,1);
+			this->AddLine(page0bot);
+
+			iggFrameFlip *msflip = new iggFrameFlip(page0bot);
+			page0bot->AddLine(msflip);
+			page0bot->SetColStretch(0,10);
+			//	page0bot->SetColStretch(1,1);
+			mb->SetFlipBuddy(msflip);
+
+			//
+			//  Isosurface settings
+			//
+			iggFrame *mspage0 = new iggFrame(msflip,4);
+			msflip->AddLayer(mspage0);
+
+			iggFrame *iv = new iggFrame(mspage0,1);
+			iggFrameDataVariableList *io = new iggFrameDataVariableList(mProvider,"Isosurface of...",iSurfaceViewSubject::KeyIsoSurfaceVar(),0,iv);
+			io->Complete();
+			io->AddDependent(show);
+			iv->AddLine(io);
+			iv->AddLine(new iggWidgetKeyCheckBox("Optimize",iSurfaceViewSubject::KeyIsoSurfaceOptimization(),iv));
+
+			iggWidgetKeyRadioBox *id = new iggWidgetKeyRadioBox(1,"Reduction",0,iSurfaceViewSubject::KeyIsoSurfaceReduction(),mspage0);
+			id->InsertItem("None");
+			id->InsertItem("Light");
+			id->InsertItem("Medium");
+			id->InsertItem("Heavy");
+
+			iggWidgetKeyRadioBox *is = new iggWidgetKeyRadioBox(1,"Smoothing",0,iSurfaceViewSubject::KeyIsoSurfaceSmoothing(),mspage0);
+			is->InsertItem("None");
+			is->InsertItem("Light");
+			is->InsertItem("Medium");
+			is->InsertItem("Heavy");
+
+			mspage0->AddLine(iv,id,is);
+			mspage0->AddLine(new iggWidgetKeyCheckBox("Use alternative reduction method",iSurfaceViewSubject::KeyAlternativeIsoSurfaceReductionMethod(),mspage0),3);
+
+			mspage0->AddSpace(10);
+
+			iggWidget *il = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Level",iSurfaceViewSubject::KeyIsoSurfaceLevel(),&iSurfaceViewSubject::KeyIsoSurfaceVar(),0,RenderMode::UseGlobal,mspage0);
+			io->AddDependent(il);
+			mspage0->AddLine(il,3);
+
+			mspage0->AddSpace(10);
+			mspage0->SetColStretch(3,10);
+
+			//
+			//  Sphere & plane settings
+			//
+			iggFrame *mspage1 = new iggFrame(msflip);
+			msflip->AddLayer(mspage1);
+
+			iggFrameObjectControls *sc= new iggFrameObjectControls("",iSurfaceViewSubject::KeyPosition(true),iSurfaceViewSubject::KeyPlaneDirection(),iSurfaceViewSubject::KeySize(true),mspage1);
+			mb->SetObjectBuddy(sc);
+			mspage1->AddLine(sc);
+
+			mspage1->AddSpace(10);
+			mspage0->SetColStretch(0,10);
+		}
+	};
+
+
+	//
+	//  Paint page
+	// ************************************************
+	//
+	class PaintPage : public iggFrameDC
+	{
+
+	public:
+
+		PaintPage(iggFrameBase *parent, iggDataTypeProvider *provider) : iggFrameDC(parent,1), mProvider(provider)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		iggDataTypeProvider *mProvider;
+
+		virtual void CompleteConstructionBody()
+		{
+			const iImage *icon = iImageFactory::FindIcon("surf.png");
+
+			//
+			//  Book
+			//
+			iggFrameBook *pb = new iggFrameBook(this);
+			this->AddLine(pb);
+			//
+			//  Palette page
+			//
+			iggFrame *pbpage0 = new iggFrame(pb,3);
+			pb->AddPage("Palette",icon,pbpage0);
+			{
+				iggFrame *pf = new iggFrame(pbpage0,2);
+				iggFrameDataVariableList *pl = new iggFrameDataVariableList(mProvider,"Paint with...",iSurfaceViewSubject::KeyPaintVar(),0,pf,0);
+				pl->InsertItem("None");
+				pl->Complete();
+
+				SideRadioBox *ss = new SideRadioBox(pf);
+				ss->SetVarBuddy(pl);
+
+				pf->AddLine(pl,ss);
+				pbpage0->AddLine(pf);
+
+				pbpage0->AddSpace(10);
+
+				iggFramePaletteSelection *ps = new iggFramePaletteSelection(true,iSurfaceViewSubject::KeyPalette(),pbpage0,0);
+				ss->SetPalBuddy(ps);
+
+				pbpage0->AddLine(ps,2);
+
+				pbpage0->AddSpace(20);
+
+				pbpage0->SetColStretch(1,10);
+				pbpage0->SetColStretch(2,3);
+			}
+			//
+			//  Material page
+			//
+			iggFrame *pbpage1 = new iggFrame(pb,2);
+			pb->AddPage("Material",icon,pbpage1);
+			{
+				iggFrameMaterialProperties *mp = new iggFrameMaterialProperties(false,true,iSurfaceViewSubject::Type(),pbpage1,0);
+				pbpage1->AddLine(mp);
+
+				pbpage1->AddSpace(10);
+				pbpage1->SetColStretch(0,10);
+				pbpage1->SetColStretch(1,3);
+			}
+		}
+	};
+
+	//
+	//  Instances page
+	// ************************************************
+	//
+	class InstancesPage : public iggFrameDC
+	{
+
+	public:
+
+		InstancesPage(iggFrameBase *parent) : iggFrameDC(parent,3)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
+			//
+			//  Instance #
+			//
+			iggFrameCurrentInstance *ci2 = new iggFrameCurrentInstance(false,"Instance","Instance",iViewModule::KeySurfaceCurrent(),iViewModule::KeySurfaceMax(),this);
+			ci2->AddDependent(this);
+			this->AddLine(ci2,new iggWidgetKeyColorSelection(iSurfaceViewSubject::KeyColor(),this,0));
+			this->AddSpace(2);
+			//
+			//  Color
+			//
+			this->AddLine(new iggFrameCreateDeleteButton(this,iSurfaceViewSubject::Type(),true,"instance",this));
+			this->AddSpace(10);
+
+			this->AddLine(new BatchCreateFrame(this));
+			this->AddSpace(10);
+
+			this->SetColStretch(2,10);
+		}
+	};
+
+	//
+	//  Replicate page
+	// ************************************************
+	//
+	class ReplicatePage : public iggFrameDC
+	{
+
+	public:
+
+		ReplicatePage(iggFrameBase *parent) : iggFrameDC(parent,2)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
+			//
+			//  Replicate
+			//
+			this->AddLine(new iggFrameReplicate(iSurfaceViewSubject::Type(),this));
+			this->AddSpace(10);
+			this->SetColStretch(1,3);
+		}
+	};
 };
 
 
@@ -463,199 +725,29 @@ iggPageSurface::iggPageSurface(iggFrameBase *parent) : iggPageObject(parent,View
 	//  Main page
 	// ************************************************
 	//
-	iggFrame *page0 = new iggFrame(mBook,1);
+	MainPage *page0 = new MainPage(mBook,mProvider);
 	mBook->AddPage("Main",icon,page0);
-	//
-	//  Top half-page sub-frame
-	//
-	iggFrame *page0top = new iggFrame(page0,4);
-	page0->AddLine(page0top);
-	//
-	//  Show
-	//
-	iggWidget *show = new iggWidgetShowButton(iSurfaceViewSubject::Type(),page0top);
-	iggFrameCurrentInstance *ci1 = new iggFrameCurrentInstance(false,"Instance","Instance",iViewModule::KeySurfaceCurrent(),iViewModule::KeySurfaceMax(),page0top);
-	ci1->AddDependent(this);
-	page0top->AddLine(show,static_cast<iggWidget*>(0),static_cast<iggWidget*>(0),ci1);
-	page0top->AddSpace(2);
-	//
-	//  Method & flip normals
-	//
-	iggFrame *mf = new iggFrame(page0top,2);
-	MethodRadioBox *mb = new MethodRadioBox(iSurfaceViewSubject::KeyMethod(),mf);
-	iggFrame *mf2 = new iggFrame(mf,1);
-	mf2->AddLine(new iggWidgetKeyColorSelection(iSurfaceViewSubject::KeyColor(),mf2,false,0));
-	mf2->AddLine(new iggWidgetKeyCheckBox("Flip normals",iSurfaceViewSubject::KeyNormalsFlipped(),mf2));
-	mf->AddLine(mb,mf2);
-	mf2 = new iggFrame(page0top);
-	mf2->AddSpace(1);
-	mf2->AddLine(new PrintInfoButton(mf2));
-	mf2->AddSpace(1);
-	page0top->AddLine(mf,2,mf2,1);
-	page0top->AddSpace(2);
-	//
-	//  Opacity
-	//
-	iggWidgetKeyFloatSlider *os = new iggWidgetKeyFloatSlider(0.0,1.0,100,0,5,"Opacity",iSurfaceViewSubject::KeyOpacity(),RenderMode::UseGlobal,page0top);
-	page0top->AddLine(os,3);
-	iggWidgetAllInstancesCheckBox *li = new iggWidgetAllInstancesCheckBox(page0top);
-	li->AddDependent(os);
-	page0top->AddLine(li,2);
-	page0top->AddSpace(10);
-
-	page0top->SetColStretch(2,3);
-
-	//
-	//  Lower half-page: various method-dependent settings in a headless mBook
-	//
-	iggFrame *page0bot = new iggFrame(page0,1);
-	page0->AddLine(page0bot);
-
-	iggFrameFlip *msflip = new iggFrameFlip(page0bot);
-	page0bot->AddLine(msflip);
-	page0bot->SetColStretch(0,10);
-//	page0bot->SetColStretch(1,1);
-	mb->SetFlipBuddy(msflip);
-
-	//
-	//  Isosurface settings
-	//
-	iggFrame *mspage0 = new iggFrame(msflip,4);
-	msflip->AddLayer(mspage0);
-
-	iggFrame *iv = new iggFrame(mspage0,1);
-	iggFrameDataVariableList *io = new iggFrameDataVariableList(mProvider,"Isosurface of...",iSurfaceViewSubject::KeyIsoSurfaceVar(),0,iv);
-	io->Complete();
-	io->AddDependent(show);
-	iv->AddLine(io);
-	iv->AddLine(new iggWidgetKeyCheckBox("Optimize",iSurfaceViewSubject::KeyIsoSurfaceOptimization(),iv));
-	
-	iggWidgetKeyRadioBox *id = new iggWidgetKeyRadioBox(1,"Reduction",0,iSurfaceViewSubject::KeyIsoSurfaceReduction(),mspage0);
-	id->InsertItem("None");
-	id->InsertItem("Light");
-	id->InsertItem("Medium");
-	id->InsertItem("Heavy");
-
-	iggWidgetKeyRadioBox *is = new iggWidgetKeyRadioBox(1,"Smoothing",0,iSurfaceViewSubject::KeyIsoSurfaceSmoothing(),mspage0);
-	is->InsertItem("None");
-	is->InsertItem("Light");
-	is->InsertItem("Medium");
-	is->InsertItem("Heavy");
-
-	mspage0->AddLine(iv,id,is);
-	mspage0->AddLine(new iggWidgetKeyCheckBox("Use alternative reduction method",iSurfaceViewSubject::KeyAlternativeIsoSurfaceReductionMethod(),mspage0),3);
-	
-	mspage0->AddSpace(10);
-
-	iggWidget *il = new iggWidgetKeyVariableLimitsSlider(mProvider,5,"Level",iSurfaceViewSubject::KeyIsoSurfaceLevel(),&iSurfaceViewSubject::KeyIsoSurfaceVar(),0,RenderMode::UseGlobal,mspage0);
-	io->AddDependent(il);
-	mspage0->AddLine(il,3);
-	
-	mspage0->AddSpace(10);
-	mspage0->SetColStretch(3,10);
-
-	//
-	//  Sphere & plane settings
-	//
-	iggFrame *mspage1 = new iggFrame(msflip);
-	msflip->AddLayer(mspage1);
-
-	iggFrameObjectControls *sc= new iggFrameObjectControls("",iSurfaceViewSubject::KeyPosition(true),iSurfaceViewSubject::KeyPlaneDirection(),iSurfaceViewSubject::KeySize(true),mspage1);
-	mb->SetObjectBuddy(sc);
-	mspage1->AddLine(sc);
-
-	mspage1->AddSpace(10);
-	mspage0->SetColStretch(0,10);
 
 	//
 	//  Paint page
 	// ************************************************
 	//
-	iggFrame *page1 = new iggFrame(mBook,1);
+	PaintPage *page1 = new PaintPage(mBook,mProvider);
 	mBook->AddPage("Paint",icon,page1);
-	//
-	//  Book
-	//
-	iggFrameBook *pb = new iggFrameBook(page1);
-	page1->AddLine(pb);
-	//
-	//  Palette page
-	//
-	iggFrame *pbpage0 = new iggFrame(pb,3);
-	pb->AddPage("Palette",icon,pbpage0);
-
-	iggFrame *pf = new iggFrame(pbpage0,2);
-	iggFrameDataVariableList *pl = new iggFrameDataVariableList(mProvider,"Paint with...",iSurfaceViewSubject::KeyPaintVar(),0,pf,0);
-	pl->InsertItem("None");
-	pl->Complete();
-
-	SideRadioBox *ss = new SideRadioBox(pf);
-	ss->SetVarBuddy(pl);
-
-	pf->AddLine(pl,ss);
-	pbpage0->AddLine(pf);
-
-	pbpage0->AddSpace(10);
-
-	iggFramePaletteSelection *ps = new iggFramePaletteSelection(true,iSurfaceViewSubject::KeyPalette(),pbpage0,0);
-	ss->SetPalBuddy(ps);
-
-	pbpage0->AddLine(ps,2);
-
-	pbpage0->AddSpace(20);
-
-	pbpage0->SetColStretch(1,10);
-	pbpage0->SetColStretch(2,3);
-
-	//
-	//  Material page
-	//
-	iggFrame *pbpage1 = new iggFrame(pb,2);
-	pb->AddPage("Material",icon,pbpage1);
-
-	iggFrameMaterialProperties *mp = new iggFrameMaterialProperties(false,true,iSurfaceViewSubject::Type(),pbpage1,0);
-	pbpage1->AddLine(mp);
-	
-	pbpage1->AddSpace(10);
-	pbpage1->SetColStretch(0,10);
-	pbpage1->SetColStretch(1,3);
 
 	//
 	//  Instances page
 	// ************************************************
 	//
-	iggFrame *page2 = new iggFrame(mBook,3);
+	InstancesPage *page2 = new InstancesPage(mBook);
 	mBook->AddPage("Instances",icon,page2);
-	//
-	//  Instance #
-	//
-	iggFrameCurrentInstance *ci2 = new iggFrameCurrentInstance(false,"Instance","Instance",iViewModule::KeySurfaceCurrent(),iViewModule::KeySurfaceMax(),page2);
-	ci2->AddDependent(this);
-	page2->AddLine(ci2);
-	page2->AddSpace(2);
-	//
-	//  Color
-	//
-	page2->AddLine(new iggWidgetKeyColorSelection(iSurfaceViewSubject::KeyColor(),page2,false,0),new iggFrameCreateDeleteButton(this,iSurfaceViewSubject::Type(),true,"instance",page2));
-	page2->AddSpace(10);
-
-	page2->AddLine(new BatchCreateFrame(page2),2);
-	page2->AddSpace(10);
-
-	page2->SetColStretch(2,10);
 
 	//
 	//  Replicate page
 	// ************************************************
 	//
-	iggFrame *page3 = new iggFrame(mBook,2);
+	ReplicatePage *page3 = new ReplicatePage(mBook);
 	mBook->AddPage("Replicate",icon,page3);
-	//
-	//  Replicate
-	//
-	page3->AddLine(new iggFrameReplicate(iSurfaceViewSubject::Type(),page3));
-	page3->AddSpace(10);
-	page3->SetColStretch(1,3);
 }
 
 #endif
