@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -46,9 +46,11 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "iggframepaletteselection.h"
 #include "iggframereplicate.h"
 #include "iggmainwindow.h"
+#include "iggrenderwindow.h"
 #include "iggwidgetkeybutton.h"
 #include "iggwidgetkeyselectionbox.h"
 #include "iggwidgetkeyslider.h"
+#include "iggwidgetmisc.h"
 #include "iggwidgetotherbutton.h"
 
 #include "ibgframesubject.h"
@@ -155,6 +157,211 @@ namespace iggPageVolume_Private
 			this->iggWidgetKeyComboBox::UpdateWidgetBody();
 		}
 	};
+
+
+	//
+	//  Main page
+	// ************************************************
+	//
+	class MainPage : public iggFrameDC
+	{
+
+	public:
+
+		MainPage(iggFrameBase *parent, iggDataTypeProvider *provider) : iggFrameDC(parent,3), mProvider(provider)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		iggDataTypeProvider *mProvider;
+
+		virtual void CompleteConstructionBody()
+		{
+			//
+			//  Show
+			//
+			iggWidget *show = new iggWidgetShowButton(iVolumeViewSubject::Type(),this);
+			this->AddLine(show);
+			this->AddSpace(2);
+			//
+			//  Field & method
+			//
+			iggFrame *tmp = new iggFrame("Method",this);
+			tmp->AddLine(new MethodBox(tmp));
+			this->AddLine(tmp);
+
+			iggFrameDataVariableList *pl = new iggFrameDataVariableList(mProvider,"Field",iVolumeViewSubject::KeyVar(),0,this,0);
+			pl->Complete();
+			pl->AddDependent(show);
+#ifdef VTK_USE_VOLUMEPRO
+			this->AddLine(pl,new iggPageVolume_Private::WindowSizeFrame(this));
+#else
+			this->AddLine(pl);
+#endif
+			this->AddSpace(10);
+
+			this->SetColStretch(2,10);
+		}
+	};
+
+
+	//
+	//  Paint page
+	// ************************************************
+	//
+	class PaintPage : public iggFrameDC
+	{
+
+	public:
+
+		PaintPage(iggFrameBase *parent) : iggFrameDC(parent,1)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
+			const iImage *icon = iImageFactory::FindIcon("volv.png");
+			//
+			//  Book
+			//
+			iggFrameBook *pb = new iggFrameBook(this);
+			this->AddLine(pb);
+			//
+			//  Palette page
+			//
+			iggFrame *pbpage0 = new iggFrame(pb,2);
+			pb->AddPage("Palette",icon,pbpage0);
+			{
+				iggFramePaletteSelection *ps = new iggFramePaletteSelection(false,iVolumeViewSubject::KeyPalette(),pbpage0,0);
+				pbpage0->AddLine(ps);
+				pbpage0->AddSpace(20);
+
+				pbpage0->SetColStretch(0,10);
+				pbpage0->SetColStretch(1,3);
+			}
+			//
+			//  Material page
+			//
+			iggFrame *pbpage1 = new iggFrame(pb,2);
+			pb->AddPage("Material",icon,pbpage1);
+			{
+				iggFrameMaterialProperties *mp = new iggFrameMaterialProperties(true,false,iVolumeViewSubject::Type(),pbpage1);
+				pbpage1->AddLine(mp);
+
+				pbpage1->AddSpace(10);
+				pbpage1->SetColStretch(0,10);
+				pbpage1->SetColStretch(1,3);
+			}
+		}
+	};
+
+
+	//
+	//  Opacity page
+	// ************************************************
+	//
+	class OpacityPage : public iggFrameDC
+	{
+
+	public:
+
+		OpacityPage(iggFrameBase *parent) : iggFrameDC(parent,1)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
+			//
+			//  FunctionMapping widget
+			//
+			this->AddLine(new iggFrameFunctionMapping(iVolumeViewSubject::KeyOpacityFunction(),this));
+		}
+	};
+
+
+	//
+	//  Replicate page
+	// ************************************************
+	//
+	class ReplicatePage : public iggFrameDC
+	{
+
+	public:
+
+		ReplicatePage(iggFrameBase *parent) : iggFrameDC(parent,2)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
+			//
+			//  Replicate
+			//
+			this->AddLine(new iggFrameReplicate(iVolumeViewSubject::Type(),this));
+			this->AddSpace(10);
+			this->SetColStretch(1,3);
+		}
+	};
+
+
+	//
+	//  Extras page
+	// ************************************************
+	//
+	class ExtrasPage : public iggFrameDC
+	{
+
+	public:
+
+		ExtrasPage(iggFrameBase *parent) : iggFrameDC(parent,3)
+		{
+			if(this->ImmediateConstruction()) this->CompleteConstruction();
+		}
+
+	protected:
+
+		virtual void CompleteConstructionBody()
+		{
+			//
+			//  Ray casting settings
+			//
+			iggFrame *rc = new iggFrame("Rendering settings",this,2);
+			iggWidgetKeyRadioBox *it = new iggWidgetKeyRadioBox(1,"Interpolation type",0,iVolumeViewSubject::KeyInterpolationType(),rc);
+			it->InsertItem("Nearest neighbor");
+			it->InsertItem("Linear");
+			iggWidgetKeyRadioBox *bm = new iggWidgetKeyRadioBox(1,"Blending mode",0,iVolumeViewSubject::KeyBlendMode(),rc);
+			bm->InsertItem("Composite");
+			bm->InsertItem("Maximum intensity");
+			rc->AddLine(it,bm);
+			this->AddLine(rc);
+			this->AddSpace(10);
+
+			iggFrame *rs = new iggFrame("Downsampling settings",this,1);
+			iggWidgetKeyFloatSlider *fs = new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Image downsampling",iVolumeViewSubject::KeyImageDownsampleFactor(),RenderMode::UseGlobal,rs);
+			fs->SetStretch(3,10);
+			rs->AddLine(fs);
+			fs = new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Depth downsampling",iVolumeViewSubject::KeyDepthDownsampleFactor(),RenderMode::UseGlobal,rs);
+			fs->SetStretch(3,10);
+			rs->AddLine(fs);
+
+			this->AddLine(rs,2);
+			this->AddSpace(10);
+
+			this->SetColStretch(1,10);
+			this->SetColStretch(2,3);
+		}
+	};
 };
 
 
@@ -169,127 +376,36 @@ iggPageVolume::iggPageVolume(iggFrameBase *parent) : iggPageObject(parent,ViewSu
 	//  Main page
 	// ************************************************
 	//
-	iggFrame *page0 = new iggFrame(mBook,3);
+	MainPage *page0 = new MainPage(mBook,mProvider);
 	mBook->AddPage("Main",icon,page0);
-	//
-	//  Show
-	//
-	iggWidget *show = new iggWidgetShowButton(iVolumeViewSubject::Type(),page0);
-	page0->AddLine(show);
-	page0->AddSpace(2);
-	//
-	//  Field & method
-	//
-	iggFrame *tmp = new iggFrame("Method",page0);
-	tmp->AddLine(new MethodBox(tmp));
-	page0->AddLine(tmp);
-
-	iggFrameDataVariableList *pl = new iggFrameDataVariableList(mProvider,"Field",iVolumeViewSubject::KeyVar(),0,page0,0);
-	pl->Complete();
-	pl->AddDependent(show);
-#ifdef VTK_USE_VOLUMEPRO
-	page0->AddLine(pl,new iggPageVolume_Private::WindowSizeFrame(page0));
-#else
-	page0->AddLine(pl);
-#endif
-	page0->AddSpace(10);
-
-	page0->SetColStretch(2,10);
 
 	//
 	//  Paint page
 	// ************************************************
 	//
-	iggFrame *page1 = new iggFrame(mBook,1);
+	PaintPage *page1 = new PaintPage(mBook);
 	mBook->AddPage("Paint",icon,page1);
-	//
-	//  Book
-	//
-	iggFrameBook *pb = new iggFrameBook(page1);
-	page1->AddLine(pb);
-	//
-	//  Palette page
-	//
-	iggFrame *pbpage0 = new iggFrame(pb,2);
-	pb->AddPage("Palette",icon,pbpage0);
-
-	iggFramePaletteSelection *ps = new iggFramePaletteSelection(false,iVolumeViewSubject::KeyPalette(),pbpage0,0);
-	pbpage0->AddLine(ps);
-	pbpage0->AddSpace(20);
-
-	pbpage0->SetColStretch(0,10);
-	pbpage0->SetColStretch(1,3);
-
-	//
-	//  Material page
-	//
-	iggFrame *pbpage1 = new iggFrame(pb,2);
-	pb->AddPage("Material",icon,pbpage1);
-
-	iggFrameMaterialProperties *mp = new iggFrameMaterialProperties(true,false,iVolumeViewSubject::Type(),pbpage1);
-	pbpage1->AddLine(mp);
-
-	pbpage1->AddSpace(10);
-	pbpage1->SetColStretch(0,10);
-	pbpage1->SetColStretch(1,3);
 
 	//
 	//  Opacity page
 	// ************************************************
 	//
-	iggFrame *page2 = new iggFrame(mBook,1);
+	OpacityPage *page2 = new OpacityPage(mBook);
 	mBook->AddPage("Opacity",icon,page2);
-	//
-	//  FunctionMapping widget
-	//
-	page2->AddLine(new iggFrameFunctionMapping(iVolumeViewSubject::KeyOpacityFunction(),page2));
 
 	//
 	//  Replicate page
 	// ************************************************
 	//
-	iggFrame *page3 = new iggFrame(mBook,2);
+	ReplicatePage *page3 = new ReplicatePage(mBook);
 	mBook->AddPage("Replicate",icon,page3);
-	//
-	//  Replicate
-	//
-	page3->AddLine(new iggFrameReplicate(iVolumeViewSubject::Type(),page3));
-	page3->AddSpace(10);
-	page3->SetColStretch(1,3);
 
 	//
 	//  Extras page
 	// ************************************************
 	//
-	iggFrame *page4 = new iggFrame(mBook,3);
+	ExtrasPage *page4 = new ExtrasPage(mBook);
 	mBook->AddPage("Extras",icon,page4);
-	//
-	//  Ray casting settings
-	//
-	iggFrame *rc = new iggFrame("Rendering settings",page4,2);
-	iggWidgetKeyRadioBox *it = new iggWidgetKeyRadioBox(1,"Interpolation type",0,iVolumeViewSubject::KeyInterpolationType(),rc);
-	it->InsertItem("Nearest neighbor");
-	it->InsertItem("Linear");
-	iggWidgetKeyRadioBox *bm = new iggWidgetKeyRadioBox(1,"Blending mode",0,iVolumeViewSubject::KeyBlendMode(),rc);
-	bm->InsertItem("Composite");
-	bm->InsertItem("Maximum intensity");
-	rc->AddLine(it,bm);
-	page4->AddLine(rc);
-	page4->AddSpace(10);
-
-	iggFrame *rs = new iggFrame("Downsampling settings",page4,1);
-	iggWidgetKeyFloatSlider *fs = new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Image downsampling",iVolumeViewSubject::KeyImageDownsampleFactor(),RenderMode::UseGlobal,rs);
-	fs->SetStretch(3,10);
-	rs->AddLine(fs);
-	fs = new iggWidgetKeyFloatSlider(0.1f,10.0f,20,1,4,"Depth downsampling",iVolumeViewSubject::KeyDepthDownsampleFactor(),RenderMode::UseGlobal,rs);
-	fs->SetStretch(3,10);
-	rs->AddLine(fs);
-
-	page4->AddLine(rs,2);
-	page4->AddSpace(10);
-
-	page4->SetColStretch(1,10);
-	page4->SetColStretch(2,3);
 }
 
 #endif
