@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -351,7 +351,7 @@ int* iggRenderWindow::GetScreenSize()
 
 void* iggRenderWindow::GetGenericDisplayId()
 {
-	return mSubject->GetDisplayId();
+	return mSubject->GetDisplay();
 }
 
 
@@ -443,6 +443,12 @@ bool iggRenderWindow::IsCurrent()
 }
 
 
+int iggRenderWindow::IsDirect()
+{
+	return mSubject->IsDirect() ? 1 : 0;
+}
+
+
 void iggRenderWindow::SetStereoCapableWindow(int capable)
 {
 	if(!mInitialized)
