@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -77,7 +77,12 @@ class iggDialogFlashWindow : public iggDialog
 
 public:
 
-	iggDialogFlashWindow(iShell *shell) : iggDialog(shell,DialogFlag::Unattached|DialogFlag::Blocking|DialogFlag::NoTitleBar,0,"",0,3,0)
+	iggDialogFlashWindow(iggShell *shell) : iggDialog(shell,DialogFlag::Unattached|DialogFlag::Blocking|DialogFlag::NoTitleBar,0,"",0,3,0)
+	{
+		this->CompleteConstruction();
+	}
+
+	void CompleteConstructionBody()
 	{
 		mFrame->AddLine(new iggWidgetTextArea("%b%+   IFrIT - Ionization FRont Interactive Tool   ",mFrame),3);
 		mFrame->AddLine(new iggWidgetTextArea("Version "+iVersion::GetVersion(),mFrame),3);
@@ -92,10 +97,10 @@ public:
 		this->ResizeContents(100,100);
 	}
 
-	virtual void Show(bool s)
+	virtual void ShowBody(bool s)
 	{
 		mFlipper->Reset();
-		iggDialog::Show(s);
+		iggDialog::ShowBody(s);
 	}
 
 	void OnInitAtom()
@@ -160,6 +165,7 @@ protected:
 			}
 		case iConsole::_LowError:
 			{
+				if(m.Part(0,7) == "ERROR: ") m = m.Part(7);
 				mMainWindow->WriteToLog("Error",m,iColor(255,0,0)); 
 				break; 
 			}
@@ -206,6 +212,12 @@ iggShell::iggShell(const iString &type, int argc, char **argv) : iShell(type,arg
 }
 
 
+iggShell::~iggShell()
+{
+	delete mSubject;
+}
+
+
 void iggShell::Exit()
 {
 	mSubject->Exit();
@@ -231,11 +243,7 @@ void iggShell::DefineSpecificCommandLineOptions()
 	this->AddCommandLineOption("owm",false,"use old-style window manager");
 	this->AddCommandLineOption("sds",false,"assume the desktop size is small");
 	this->AddCommandLineOption("src",false,"minimize updates for running on a slow remote connection");
-}
-
-
-iggShell::~iggShell()
-{
+	this->AddCommandLineOption("ddi",false,"disable delayed initialization");
 }
 
 
@@ -556,6 +564,12 @@ bool iggShell::AnalyseOneExtendedCommandLineOption(const struct Option &o)
 		return true;
 	}
 	
+	if(o.Name == "ddi")
+	{
+		mConditionFlags |= Condition::DisableDelayedInitialization;
+		return true;
+	}
+	
 	return false;
 }
 
