@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -48,9 +48,9 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 using namespace iParameter;
 
 
-iggWidgetKeyColorSelection::iggWidgetKeyColorSelection(const iObjectKey &key, iggFrame *parent, bool horizontal, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<iColor>(WidgetType::Other,key,RenderMode::Immediate,parent,index,indkey)
+iggWidgetKeyColorSelection::iggWidgetKeyColorSelection(const iObjectKey &key, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<iColor>(WidgetType::Other,key,RenderMode::Immediate,parent,index,indkey)
 {
-	mSubject = iggSubjectFactory::CreateWidgetColorSelectionSubject(this,horizontal);
+	mSubject = iggSubjectFactory::CreateWidgetColorSelectionSubject(this);
 }
 
 
