@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -46,7 +46,7 @@ class iggWidgetKeyColorSelection : public iggWidgetKeyHandler<iColor>
 
 public:
 
-	iggWidgetKeyColorSelection(const iObjectKey &key, iggFrame *parent, bool horizontal, int index = -1, const iObjectKey *indkey = 0);
+	iggWidgetKeyColorSelection(const iObjectKey &key, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);
 
 	void SetText(const iString &text);
 
