@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -36,12 +36,14 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 // iggWidgetKeyFloatLineEdit;
 // iggWidgetKeyPositionLineEdit;
 // iggWidgetKeySizeLineEdit;
+// iggWidgetKeyFileNameLineEdit;
 //
 #include "iggwidgetkeyhandler.h"
 
 
 #include "istring.h"
 
+class ibgWidgetButtonSubject;
 class ibgWidgetEntrySubject;
 
 
@@ -136,5 +138,25 @@ public:
 	iggWidgetKeySizeLineEdit(const iString &label, const iObjectKey &key, int rm, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);
 };
 
+
+class iggWidgetKeyFileNameLineEdit : public iggWidgetKeyTextLineEdit
+{
+
+public:
+
+	iggWidgetKeyFileNameLineEdit(bool render, const iString &header, const iString &location, const iString &selection, bool exists, const iString &label, bool unloadable, const iObjectKey &key, iggFrame *parent, int index = -1, const iObjectKey *indkey = 0);
+
+	void OpenLoadFileDialog();
+	void UnloadFile();
+
+protected:
+
+	virtual void OnVoid1Body();
+	virtual void UpdateWidgetBody();
+
+	bool mFileExists, mUnloadable, mRender;
+	iString mHeader, mLocation, mSelection;
+};
+
 #endif  // IGGWIDGETKEYLINEEDIT_H
 
