@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -49,8 +49,17 @@ using namespace iParameter;
 template<class T>
 iggWidgetKeyLineEdit<T>::iggWidgetKeyLineEdit(bool numeric, bool readonly, const iString &label, const iObjectKey &key, int rm, iggFrame *parent, int index, const iObjectKey *indkey) : iggWidgetKeyHandler<T>(WidgetType::Entry,key,rm,parent,index,indkey)
 {
-	this->mSubject = this->mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,(numeric)?10:0,label,(rm==RenderMode::NoRender)?0:new iggWidgetRenderModeButton(this)); IERROR_ASSERT(mSubject);
+
+	this->mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,(numeric)?10:0,label); IERROR_ASSERT(mSubject);
 	this->mSubject->SetEditable(!readonly);
+
+	if(rm != RenderMode::NoRender)
+	{
+		iggWidgetRenderModeButton *rm = new iggWidgetRenderModeButton(this); IERROR_ASSERT(rm);
+		rm->ClearLaidOutFlag(this->mSubject);
+		this->mSubject->AddButton(rm->GetSubject());
+	}
+
 	this->SetRenderMode(rm);
 }
 
