@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -68,7 +68,15 @@ iggWidgetKeyTrackBall::iggWidgetKeyTrackBall(const iObjectKey &dirkey, bool foll
 	}
 
 	mIsVectorKey = (this->GetKey().Dimension() == 3);
-	mSubject = iggSubjectFactory::CreateWidgetTrackBallSubject(this,followCamera,(rm==RenderMode::NoRender)?0:new iggWidgetRenderModeButton(this));
+	mSubject = iggSubjectFactory::CreateWidgetTrackBallSubject(this,followCamera);
+
+	if(rm != RenderMode::NoRender)
+	{
+		iggWidgetRenderModeButton *rm = new iggWidgetRenderModeButton(this); IERROR_ASSERT(rm);
+		rm->ClearLaidOutFlag(mSubject);
+		mSubject->AddButton(rm->GetSubject());
+	}
+
 	this->SetRenderMode(rm);
 }
 
