@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -123,7 +123,7 @@ iggWidgetLogoFlipper::iggWidgetLogoFlipper(iggFrame *parent) : iggWidgetImageFli
 //
 iggWidgetNumberDisplay::iggWidgetNumberDisplay(const iString &title, iggFrame *parent) : iggWidget(parent)
 {
-	mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,6,title,0);
+	mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,6,title);
 	mSubject->SetEditable(false);
 
 	mNeedsBaloonHelp = false;
@@ -156,7 +156,7 @@ void iggWidgetNumberDisplay::UpdateWidgetBody()
 //
 iggWidgetTextDisplay::iggWidgetTextDisplay(const iString &title, iggFrame *parent) : iggWidget(parent)
 {
-	mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,0,title,0);
+	mSubject = iggSubjectFactory::CreateWidgetEntrySubject(this,false,0,title);
 	mSubject->SetEditable(false);
 
 	mNeedsBaloonHelp = false;
