@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -104,10 +104,10 @@ void iggWidgetTextEditor::SetText(const iString &text)
 }
 
 
-/*iString iggWidgetTextEditor::GetText() const
+iString iggWidgetTextEditor::GetText() const
 {
 	return mSubject->GetText();
-}*/
+}
 
 
 iString iggWidgetTextEditor::GetLine(int n) const
