@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -90,7 +90,7 @@ public:
 	void Clear();
 	void SetModified(bool s);
 	virtual void SetText(const iString &text);
-//	iString GetText() const;
+	iString GetText() const;
 //	void AppendText(const iString &text);
 
 	//
