@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -83,8 +83,8 @@ protected:
 	virtual void moveEvent(QMoveEvent *e);
 	virtual void closeEvent(QCloseEvent *e);
 	virtual void resizeEvent(QResizeEvent *e); 
-	virtual void keyPressEvent(QKeyEvent *e); 
-	virtual void keyReleaseEvent(QKeyEvent *e); 
+//	virtual void keyPressEvent(QKeyEvent *e); 
+//	virtual void keyReleaseEvent(QKeyEvent *e); 
 //	virtual void focusInEvent(QFocusEvent *e);
 //	virtual void focusOutEvent(QFocusEvent *e);
 
@@ -94,7 +94,6 @@ private:
 
 	QWidget *mMainFrame;
 	QWorkspace *mDockingWorkspace;
-	bool mIsMoveAll;
 
 	iqtMainWindowSubject(const iqtMainWindowSubject&); // Not implemented.
 	void operator=(const iqtMainWindowSubject&);  // Not implemented.
