@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -194,7 +194,7 @@ void iqtRenderWindowSubject::MakeCurrent()
 }
 
 
-void* iqtRenderWindowSubject::GetDisplayId() const
+void* iqtRenderWindowSubject::GetDisplay() const
 {
 #if defined(Q_WS_X11)
 #ifdef IQT_3
@@ -208,6 +208,12 @@ void* iqtRenderWindowSubject::GetDisplayId() const
 }
 
 
+void* iqtRenderWindowSubject::GetContext() const
+{
+	return (void *)this->context();
+}
+
+
 void* iqtRenderWindowSubject::GetWindowId() const
 {
 	return (void *)this->winId();
@@ -385,6 +391,12 @@ void iqtRenderWindowSubject::OnTimer()
 }
 
 
+bool iqtRenderWindowSubject::IsDirect() const
+{
+	return this->format().directRendering();
+}
+
+
 bool iqtRenderWindowSubject::IsCurrent() const
 {
 	return this->context() == QGLContext::currentContext();
