@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -74,13 +74,15 @@ protected:
 	virtual void SetFullScreen(bool);
 	virtual void MakeCurrent();
 
-	virtual void* GetDisplayId() const;
+	virtual void* GetDisplay() const;
+	virtual void* GetContext() const;
 	virtual void* GetWindowId() const;
 	virtual void SetWindowName(const iString &s);
 
 	virtual void RenderIntoMemory(iImage &image);
 	virtual bool IsReadyForDumpingImage();
 
+	virtual bool IsDirect() const;
 	virtual bool IsCurrent() const;
 
 	virtual void RequestStereo(bool s);
