@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -58,7 +58,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #endif
 
 
-iqtWidgetColorSelectionSubject::iqtWidgetColorSelectionSubject(iggWidget *owner, bool horizontal) : QWidget(iqtHelper::Convert(owner->GetParent())), ibgWidgetColorSelectionSubject(owner,horizontal)
+iqtWidgetColorSelectionSubject::iqtWidgetColorSelectionSubject(iggWidget *owner) : QWidget(iqtHelper::Convert(owner->GetParent())), ibgWidgetColorSelectionSubject(owner), mSize(16)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
@@ -66,38 +66,11 @@ iqtWidgetColorSelectionSubject::iqtWidgetColorSelectionSubject(iggWidget *owner,
 	//  Create a layout
 	//
 	if(this->layout() != 0) delete this->layout();
-	QGridLayout *l;
-	if(horizontal) l = iqtHelper::NewLayout(this,2); else
-	{
-		l = iqtHelper::NewLayout(this,1);
-#ifdef IQT_3
-		l->expand(3,1);
-#endif
-	}
-
-	mLabel = new QLabel(this);
-	mLabel->setFrameStyle(QFrame::Panel | QFrame::Sunken);
-	mLabel->setLineWidth(2);
-#ifndef IQT_3
-#ifndef IQT_40
-	mLabel->setAutoFillBackground(true);
-#endif
-#endif
-	mLabel->setScaledContents(true);
-	mLabel->setMinimumSize(24,24);
-	if(horizontal)
-	{
-		l->addWidget(mLabel,0,0);
-	}
-	else
-	{
-		l->addWidget(mLabel,1,0);
-		l->setRowStretch(0,10);
-	}
+	QGridLayout *l = iqtHelper::NewLayout(this,1);
 
 	mButton = new QPushButton(this);
 	mButton->setText("Color");
-	if(horizontal) l->addWidget(mButton,0,1); else l->addWidget(mButton,2,0);
+	l->addWidget(mButton,0,0);
 
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum));
 
@@ -112,25 +85,44 @@ iqtWidgetColorSelectionSubject::~iqtWidgetColorSelectionSubject()
 
 const iColor iqtWidgetColorSelectionSubject::GetColor() const
 {
-#ifdef IQT_3
-	QColor c0 = mLabel->paletteBackgroundColor();
-#else
-	QColor c0 = mLabel->palette().color(mLabel->backgroundRole());
-#endif
-
-	QColor c = QColorDialog::getColor(c0); 
+	QColor c = QColorDialog::getColor(mColor); 
 	if(c.isValid())
 	{
-		iqtHelper::SetBackground(mLabel,c);
+		mColor = c;
+		this->DisplayColor();
 	}
-	else c = c0;
-	return iqtHelper::Convert(c);
+	return iqtHelper::Convert(mColor);
 }
 
 
 void iqtWidgetColorSelectionSubject::SetColor(const iColor &v)
 {
-	iqtHelper::SetBackground(mLabel,iqtHelper::Convert(v));
+	mColor = iqtHelper::Convert(v);
+	this->DisplayColor();
+}
+
+
+#ifdef IQT_3
+#include <qdrawutil.h>
+#include <qpainter.h>
+#else
+//#include <qdrawutil.h>
+#include <QtGui/QPainter>
+#endif
+
+
+void iqtWidgetColorSelectionSubject::DisplayColor() const
+{
+	QPixmap p(mSize,mSize);
+	p.fill(mColor);
+	QPainter w(&p);
+#ifdef IQT_3
+	qDrawShadePanel(&w,0,0,mSize,mSize,mButton->colorGroup(),true,2,0);
+	mButton->setIconSet(QIconSet(p));
+#else
+	qDrawShadePanel(&w,0,0,mSize,mSize,mButton->palette(),true,2,0);
+	mButton->setIcon(QIcon(p));
+#endif
 }
 
 	
