@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -64,12 +64,15 @@ public:
 
 protected:
 
-	iqtWidgetColorSelectionSubject(iggWidget *owner, bool horizontal);
+	iqtWidgetColorSelectionSubject(iggWidget *owner);
+
+	void DisplayColor() const;
 
 	iqtCallbackHelper *mCallbackHelper;
 
-	QLabel *mLabel;
 	QPushButton *mButton;
+	mutable QColor mColor;
+	const int mSize;
 };
 
 #endif  // IQTWIDGETKEYCOLORSELECTIONSUBJECT_H
