@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -123,6 +123,12 @@ namespace iqtWidgetEntrySubject_Private
 	
 	protected:
 
+		virtual void mouseDoubleClickEvent(QMouseEvent *e)
+		{
+			e->accept();
+			emit returnPressed();
+		}
+
 		virtual void keyPressEvent(QKeyEvent *e)
 		{
 			if(mDelayed && !this->text().isEmpty() && e->key()!=Qt::Key_Up && e->key()!=Qt::Key_Down)
@@ -176,7 +182,7 @@ namespace iqtWidgetEntrySubject_Private
 };
 
 
-iqtWidgetEntrySubject::iqtWidgetEntrySubject(iggWidget *owner, bool slider, int numdig, const iString &label, iggWidgetRenderModeButton* rmb) : QWidget(iqtHelper::Convert(owner->GetParent())), ibgWidgetEntrySubject(owner,slider,numdig,label,rmb)
+iqtWidgetEntrySubject::iqtWidgetEntrySubject(iggWidget *owner, bool slider, int numdig, const iString &label) : QWidget(iqtHelper::Convert(owner->GetParent())), ibgWidgetEntrySubject(owner,slider,numdig,label)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 
@@ -233,17 +239,7 @@ iqtWidgetEntrySubject::iqtWidgetEntrySubject(iggWidget *owner, bool slider, int
 	iqtHelper::SetBackground(mView,0);
 	if(numdig <= 0)	mView->hide();
 
-	if(rmb != 0)
-	{
-		iqtWidgetButtonSubject *rmbs = iDynamicCast<iqtWidgetButtonSubject,ibgWidgetButtonSubject>(INFO,rmb->GetSubject());
-		iqtHelper::SetParent(rmbs,this);
-#ifdef IQT_3
-		w->expand(1,4);
-		w->addWidget(rmbs,0,3);
-#else
-		w->addWidget(rmbs,0,4);
-#endif
-	}
+	mNumButtons = 0;
 
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Minimum));
 }
@@ -254,6 +250,25 @@ iqtWidgetEntrySubject::~iqtWidgetEntrySubject()
 }
 
 
+void iqtWidgetEntrySubject::AddButton(ibgWidgetButtonSubject* button)
+{
+	if(button != 0)
+	{
+		QGridLayout *w = iDynamicCast<QGridLayout,QLayout>(INFO,this->layout());
+		iqtWidgetButtonSubject *bs = iDynamicCast<iqtWidgetButtonSubject,ibgWidgetButtonSubject>(INFO,button);
+		iqtHelper::SetParent(bs,this);
+
+		mNumButtons++;
+#ifdef IQT_3
+		w->expand(1,mNumButtons+3);
+		w->addWidget(bs,0,mNumButtons+2);
+#else
+		w->addWidget(bs,0,mNumButtons+3);
+#endif
+	}
+}
+
+
 int iqtWidgetEntrySubject::GetValue() const
 {
 	return mSlider->value();
@@ -366,6 +381,12 @@ void iqtWidgetEntrySubject::SetRange(int smin, int smax, int pagestep)
 }
 
 
+void iqtWidgetEntrySubject::ShowTail()
+{
+	mEdit->end(false);
+}
+
+
 void iqtWidgetEntrySubject::SetStretch(int label, int slider, int number)
 {
 	QGridLayout *l = iDynamicCast<QGridLayout,QLayout>(INFO,this->layout());
