@@ -4,7 +4,7 @@
   Language:  C++
 
 
-Copyright (c) 2002-2011 Nick Gnedin 
+Copyright (c) 2002-2012 Nick Gnedin 
 All rights reserved.
 
 This file may be distributed and/or modified under the terms of the
@@ -82,11 +82,11 @@ using namespace iqtWidgetTrackBall_Private;
 //
 // Constructs a iTrackball.
 //
-iqtWidgetTrackBallSubject::iqtWidgetTrackBallSubject(iggWidget *owner, bool followCamera, iggWidgetRenderModeButton* rmb) : QWidget(iqtHelper::Convert(owner->GetParent())
+iqtWidgetTrackBallSubject::iqtWidgetTrackBallSubject(iggWidget *owner, bool followCamera) : QWidget(iqtHelper::Convert(owner->GetParent())
 #ifdef IQT_3
 																																	,0,Qt::WRepaintNoErase
 #endif
-																																	), ibgWidgetTrackBallSubject(owner,followCamera,rmb)
+																																	), ibgWidgetTrackBallSubject(owner,followCamera)
 {
 	mWidgetHelper = new iqtWidgetHelper(this,owner); IERROR_ASSERT(mWidgetHelper);
 	//
@@ -103,22 +103,6 @@ iqtWidgetTrackBallSubject::iqtWidgetTrackBallSubject(iggWidget *owner, bool foll
 	this->setSizePolicy(QSizePolicy(QSizePolicy::Expanding,QSizePolicy::Expanding));
 	this->setMinimumSize(mFixedSize,mFixedSize);
 
-	if(rmb != 0)
-	{
-#ifdef IQT_3
-		l->expand(2,2);
-#endif
-		iqtWidgetButtonSubject *rmbs = iDynamicCast<iqtWidgetButtonSubject,ibgWidgetButtonSubject>(INFO,rmb->GetSubject());
-		iqtHelper::SetParent(rmbs,this);
-		l->addWidget(rmbs,0,1);
-#ifdef IQT_3
-		l->setColStretch(0,10);
-#else
-		l->setColumnStretch(0,10);
-#endif
-		l->setRowStretch(1,10);
-	}
-
 	mInUpdate = false;
 }
 
@@ -142,6 +126,27 @@ void iqtWidgetTrackBallSubject::GetSizes(int &w0, int &h0, int &rad, int &cor)
 }
 
 
+void iqtWidgetTrackBallSubject::AddButton(ibgWidgetButtonSubject* button)
+{
+	if(button != 0)
+	{
+		QGridLayout *l = iDynamicCast<QGridLayout,QLayout>(INFO,this->layout());
+#ifdef IQT_3
+		l->expand(2,2);
+#endif
+		iqtWidgetButtonSubject *bs = iDynamicCast<iqtWidgetButtonSubject,ibgWidgetButtonSubject>(INFO,button);
+		iqtHelper::SetParent(bs,this);
+		l->addWidget(bs,0,1);
+#ifdef IQT_3
+		l->setColStretch(0,10);
+#else
+		l->setColumnStretch(0,10);
+#endif
+		l->setRowStretch(1,10);
+	}
+}
+
+
 void iqtWidgetTrackBallSubject::Repaint()
 {
 	this->update();
